<?php /* Smarty version 2.6.2, created on 2012-05-23 20:13:04
         compiled from details_button.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'details_button.tpl', 4, false),)), $this); ?>
<table cellspacing=0 cellpadding=2 border=0 width="100%">
<tr><td class=title align=center><br>Monitor Button of <b><?php echo $this->_tpl_vars['listing']['name']; ?>
</b></td></tr>
<tr><td align="center" colspan="4">
<a href="<?php echo ((is_array($_tmp="?a=details&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">
<img src="<?php echo ((is_array($_tmp="?a=image&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" border="0" alt="Monitored by <?php echo $this->_tpl_vars['settings']['site_name']; ?>
"></a></td></tr>
<tr><td align=center colspan="4"><strong>To Place above Button on your site click on box below and copy the code.</strong></td>
</tr>
<tr><td align="center" colspan="4"><textarea name="logo_txt" class="inpts" cols="75" rows="4" onmouseover="this.select()"><a href="<?php echo ((is_array($_tmp="?a=details&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><img src="<?php echo ((is_array($_tmp="?a=image&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" border="0" alt="Monitored by <?php echo $this->_tpl_vars['settings']['site_name']; ?>
"></a></textarea></td></tr>

<tr>
<td width="25%">Top - Left</td>
<td width="25%">Top - Right</td>
<td width="25%">Bottom - Left</td>
<td width="25%">Bottom - Right</td>
</tr>
<tr>
<td><textarea class="inpts" cols="30" rows="5" onmouseover="this.select()">
<script language="JavaScript" src="<?php echo ((is_array($_tmp="getstatus.js")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" type="text/javascript"></script>
<script type="text/javascript">showdetails("<?php echo $this->_tpl_vars['listing']['id']; ?>
","tl","top","left");</script>
</textarea></td>
<td><textarea class="inpts" cols="30" rows="5" onmouseover="this.select()">
<script language="JavaScript" src="<?php echo ((is_array($_tmp="getstatus.js")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" type="text/javascript"></script>
<script type="text/javascript">showdetails("<?php echo $this->_tpl_vars['listing']['id']; ?>
","tr","top","right");</script>
</textarea></td>
<td><textarea class="inpts" cols="30" rows="5" onmouseover="this.select()">
<script language="JavaScript" src="<?php echo ((is_array($_tmp="getstatus.js")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" type="text/javascript"></script>
<script type="text/javascript">showdetails("<?php echo $this->_tpl_vars['listing']['id']; ?>
","bl","bottom","left");</script>
</textarea></td>
<td><textarea class="inpts" cols="30" rows="5" onmouseover="this.select()">
<script language="JavaScript" src="<?php echo ((is_array($_tmp="getstatus.js")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" type="text/javascript"></script>
<script type="text/javascript">showdetails("<?php echo $this->_tpl_vars['listing']['id']; ?>
","br","bottom","right");</script>
</textarea></td>
</tr>
</table>
