<div class="box">
<div class="box_title" id="tba">Header {if $banners.2_type}Non-{/if}Rotating Banner </div>
<div class="box_body">	

<table width=100% border="0" cellspacing="0" cellpadding="1">
{section name=b2 loop=$ads.2}
{if $ads.2[b2].no}<tr class="adlight"><td width="468" height="60" align="center" class="ad">
<a href="{"?a=goads&aid=2&id=`$ads.2[b2].no`"|encurl}" target="_blank" title="{$ads.2[b2].desc}">{if $ads.2[b2].format == 'flash'}<embed width="468" height="60" src="{$ads.2[b2].imgurl}"><noembed>{"?a=goads&aid=2&id=`$ads.2[b2].no`"|encurl}</noembed>{else}<img src="{$ads.2[b2].imgurl}" alt="{$ads.2[b2].desc}" width="468" height="60" border="2" style="border-color:#C9C6C6">{/if}</a></td>
<td class="ad"><a href="{"?a=goads&aid=2&id=`$ads.2[b2].no`"|encurl}" target="_blank"><b>{$ads.2[b2].name}</b></a><br>{$ads.2[b2].desc}<br><font color="#666666">${$ads.2[b2].price}/Week | Expires: {$ads.2[b2].expired}</font></td></tr>

{else}

<tr class="adlight"><td width="468" height="60" align="center" class="ad">
<table width=468 height=60  border="0" cellspacing="1" cellpadding="0" class="adblack" style=word-break:break-all><tr><td align="center" class="adlight" style=word-break:break-all>
<div align=center><a href="{"?a=advertise&ad=2"|encurl}"><img src="{"images/468.gif"|encurl}" width="468" height="60" alt="Your Ad Here" border="0"></a></td></a></div></td></tr></table></td>
<td class="ad" style=word-break:break-all><a href="{"?a=advertise&ad=2"|encurl}"><strong>Your Ad Here</strong></a><br>
Your Program Description<br><font color="#666666">${$ads.2[b2].price}/Week | Available Now!</font></td></tr>
{/if}
{/section}
</table>

	</div></div>