<?php /* Smarty version 2.6.2, created on 2012-05-23 22:17:53
         compiled from details_vote.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'details_vote.tpl', 5, false),)), $this); ?>
<table width=100% border=0 align="center" cellpadding=3 cellspacing=0>
<tr><td colspan="2"><b>Ratings stats of <?php echo $this->_tpl_vars['listing']['name']; ?>
</b></td>
</tr>
<tr>
  <td width="12%" align="right">Very Good:</td><td width="13%"><img src="<?php echo ((is_array($_tmp="images/r3.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Very Good" title="Very Good" align="absmiddle"> <?php echo $this->_tpl_vars['listing']['votes_summary']['3']['count']; ?>
 votes</td>
  <td><img src="<?php echo ((is_array($_tmp="images/r_dot.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="<?php echo $this->_tpl_vars['listing']['votes_summary']['3']['percent']; ?>
" height="10" align="absmiddle" title="<?php echo $this->_tpl_vars['listing']['votes_summary']['3']['count']; ?>
 votes (<?php echo $this->_tpl_vars['listing']['votes_summary']['3']['percent']; ?>
%)"> (<?php echo $this->_tpl_vars['listing']['votes_summary']['3']['percent']; ?>
%)</td>
</tr>
<tr>
  <td align="right">Good:</td><td><img src="<?php echo ((is_array($_tmp="images/r2.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Good" title="Good" align="absmiddle"> <?php echo $this->_tpl_vars['listing']['votes_summary']['2']['count']; ?>
 votes</td>
  <td><img src="<?php echo ((is_array($_tmp="images/y_dot.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="<?php echo $this->_tpl_vars['listing']['votes_summary']['2']['percent']; ?>
" height="10" align="absmiddle" title="<?php echo $this->_tpl_vars['listing']['votes_summary']['2']['count']; ?>
 votes (<?php echo $this->_tpl_vars['listing']['votes_summary']['2']['percent']; ?>
%)"> (<?php echo $this->_tpl_vars['listing']['votes_summary']['2']['percent']; ?>
%)</td>
  </tr>
  <tr>
    <td align="right">bad:</td><td><img src="<?php echo ((is_array($_tmp="images/r1.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Bad" title="Bad" align="absmiddle"> <?php echo $this->_tpl_vars['listing']['votes_summary']['1']['count']; ?>
 votes</td>
    <td><img src="<?php echo ((is_array($_tmp="images/g_dot.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="<?php echo $this->_tpl_vars['listing']['votes_summary']['1']['percent']; ?>
" height="10" align="absmiddle" title="<?php echo $this->_tpl_vars['listing']['votes_summary']['1']['count']; ?>
 votes (<?php echo $this->_tpl_vars['listing']['votes_summary']['1']['percent']; ?>
%)"> (<?php echo $this->_tpl_vars['listing']['votes_summary']['1']['percent']; ?>
%)</td>
  </tr>
  <tr>
    <td align="right">very bad:</td><td><img src="<?php echo ((is_array($_tmp="images/r0.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Very Bad" title="Very Bad" align="absmiddle"> <?php echo $this->_tpl_vars['listing']['votes_summary']['0']['count']; ?>
 votes</td>
    <td><img src="<?php echo ((is_array($_tmp="images/b_dot.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="<?php echo $this->_tpl_vars['listing']['votes_summary']['0']['percent']; ?>
" height="10" align="absmiddle" title="<?php echo $this->_tpl_vars['listing']['votes_summary']['0']['count']; ?>
 votes (<?php echo $this->_tpl_vars['listing']['votes_summary']['0']['percent']; ?>
%)"> (<?php echo $this->_tpl_vars['listing']['votes_summary']['0']['percent']; ?>
%)</td>
</tr>
</table>

<br />
<form method=post name="vote" onsubmit="return procVote()">
<input type="hidden" name="a" value="add_vote">
<input type="hidden" name="action" value="save">
<input type="hidden" name="lid" value="<?php echo $this->_tpl_vars['listing']['id']; ?>
">

<table cellspacing=1 cellpadding=2 border=0 width=99% style="border: 1px dotted #CCCCCC;" align=center>
<tr>
 <td class=title align=center><br>Your rating for <b><?php echo $this->_tpl_vars['listing']['name']; ?>
</b></td></tr>
<tr>
  <td><table width="100%" border="0" cellspacing="1" cellpadding="2">
    <tr>
      <td width=25% height=50 align=center><img src="<?php echo ((is_array($_tmp="images/r3.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Very Good" title="Very Good"><br>
          <input type="radio" name="vote" value=3>
    Very Good<br>
      </td>
      <td width=25% align=center><img src="<?php echo ((is_array($_tmp="images/r2.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Good" title="Good"><br>
          <input type="radio" name="vote" value=2 checked>
    Good<br>
      </td>
      <td width=25% align=center><img src="<?php echo ((is_array($_tmp="images/r1.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Bad" title="Bad"><br>
          <input type="radio" name="vote" value=1>
    Bad<br>
      </td>
      <td width=25% align=center><img src="<?php echo ((is_array($_tmp="images/r0.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Very Bad" title="Very Bad"><br>
          <input type="radio" name="vote" value=0>
    Very Bad<br>
      </td>
    </tr>
    <tr><td colspan="4">&nbsp;</td></tr>
  </table></td>
</tr>
<?php if ($this->_tpl_vars['frm']['err']): ?><tr><td>
<ul style="color:red">
<?php if ($this->_tpl_vars['frm']['err'] == 'turing'): ?><li> Invalid turing image provided.</li><?php endif; ?>
<?php if ($this->_tpl_vars['frm']['err'] == 'email'): ?><li> Please, enter your valid email</li><?php endif; ?>
</ul>  </td>
</tr>
<?php endif; ?>
<tr>
<td align=center>
You can write short comment (max. 255 chars): <input readonly type="text" name="Len" size="3" value="255" class="inpts"><br>
<textarea name="comment" class="inpts" cols=65 rows=5 onKeyDown="textCounter(this.form.comment,this.form.Len,255);" onKeyUp="textCounter(this.form.comment,this.form.Len,255);"></textarea>
  </td>
</tr>
<?php if ($this->_tpl_vars['userinfo']['logged']): ?>
<tr>
  <td align="center">Username: <b><?php echo $this->_tpl_vars['userinfo']['username']; ?>
</b></td>
</tr>
<?php else: ?>
<tr>
  <td align="center">
Your e-mail<?php if ($this->_tpl_vars['settings']['vote_confirmation_require']): ?> (we will send you your vote confirmation code)<?php endif; ?>:<br>
<input type="text" name="email" class="inpts" size="50"></td></tr>
<?php endif; ?>
<?php if ($this->_tpl_vars['settings']['use_turing']): ?>
<tr>
  <td align="center"><img src="<?php echo ((is_array($_tmp="?a=turing&".($this->_tpl_vars['sesname'])."=".($this->_tpl_vars['sesid'])."&r=".($this->_tpl_vars['rand']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="turing code" align="absmiddle">  <input type=text name="turing" maxlength="6" size="10" class="inpts"></td>
</tr>
<?php endif; ?>
<tr>

  <td align=center><input type="submit" value="Add Vote" class=sbmt></td>
</tr>
<tr><td>&nbsp;</td></tr>
</table></form>
<div class="dline"></div>
<?php if ($this->_tpl_vars['votes']): ?>
<table cellspacing=0 cellpadding=2 border=0 width=100%>
<tr><td colspan="4" class="newlistingsdatetitle"><strong>User Votes</strong></td>
</tr>
<tr>
  <td align=center class=title><strong>Rating</strong></td>
  <td align=center class=title><strong>Voter IP</strong></td>
  <td align=center class=title><strong>User/E-Mail</strong></td>
  <td align=center class=title><strong>Vote Date</strong></td>
</tr>

<?php if (isset($this->_sections['v'])) unset($this->_sections['v']);
$this->_sections['v']['name'] = 'v';
$this->_sections['v']['loop'] = is_array($_loop=$this->_tpl_vars['votes']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['v']['show'] = true;
$this->_sections['v']['max'] = $this->_sections['v']['loop'];
$this->_sections['v']['step'] = 1;
$this->_sections['v']['start'] = $this->_sections['v']['step'] > 0 ? 0 : $this->_sections['v']['loop']-1;
if ($this->_sections['v']['show']) {
    $this->_sections['v']['total'] = $this->_sections['v']['loop'];
    if ($this->_sections['v']['total'] == 0)
        $this->_sections['v']['show'] = false;
} else
    $this->_sections['v']['total'] = 0;
if ($this->_sections['v']['show']):

            for ($this->_sections['v']['index'] = $this->_sections['v']['start'], $this->_sections['v']['iteration'] = 1;
                 $this->_sections['v']['iteration'] <= $this->_sections['v']['total'];
                 $this->_sections['v']['index'] += $this->_sections['v']['step'], $this->_sections['v']['iteration']++):
$this->_sections['v']['rownum'] = $this->_sections['v']['iteration'];
$this->_sections['v']['index_prev'] = $this->_sections['v']['index'] - $this->_sections['v']['step'];
$this->_sections['v']['index_next'] = $this->_sections['v']['index'] + $this->_sections['v']['step'];
$this->_sections['v']['first']      = ($this->_sections['v']['iteration'] == 1);
$this->_sections['v']['last']       = ($this->_sections['v']['iteration'] == $this->_sections['v']['total']);
?>
<tr class=<?php if ($this->_sections['v']['rownum'] % 2 == 0): ?>detailsbg1<?php else: ?>detailsbg2<?php endif; ?>>
  <td align=center>
   <?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 0): ?><img src="<?php echo ((is_array($_tmp="images/r0.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Very Bad" title="Very Bad"><?php endif; ?>
   <?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 1): ?><img src="<?php echo ((is_array($_tmp="images/r1.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Bad" title="Bad"><?php endif; ?>
   <?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 2): ?><img src="<?php echo ((is_array($_tmp="images/r2.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Good" title="Good"><?php endif; ?>
   <?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 3): ?><img src="<?php echo ((is_array($_tmp="images/r3.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Very Good" title="Very Good"><?php endif; ?>
  </td>
  <td align=center><img src="<?php echo ((is_array($_tmp="images/c/".($this->_tpl_vars['votes'][$this->_sections['v']['index']]['flag']).".gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" align="absmiddle" alt="<?php echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['flag']; ?>
" title="<?php echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['flag']; ?>
" style="cursor:help;"> <?php echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['ip']; ?>
</td>
  <td align=center><?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['username']):  echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['username'];  else:  echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['email'];  endif; ?></td>
  <td align=center><?php echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['fdate']; ?>
</td>
</tr>
<?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['comment']): ?>
<tr>
  <td colspan=4><img src="<?php echo ((is_array($_tmp="images/vcom.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt=""> <font color="<?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 0): ?>red<?php endif;  if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 1): ?>orange<?php endif;  if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 2): ?>#CBA903<?php endif;  if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 3): ?>#008800<?php endif; ?>"><?php echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['comment']; ?>
</td>
</tr>
<?php endif; ?>
<?php endfor; endif; ?>
</table>
<?php endif; ?>

