{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">Payment Status</div>
<div class="box_body"><br><br>

{if $frm.say eq 'ok'}
<b style="color:green">Thank you. Your payment was accepted.</b><br>
<br>

{elseif $frm.say eq 'no'}
<b style="color:red">Sorry! Your payment is not successful!</b><br><br>
If you need some help please use our online contact form:<a href="{"?a=support"|encurl}">CLICK HERE!</a><br>
<br>
{/if}


<div style="padding-bottom:25px;"></div>
</div></div>

{include file="footer.tpl"}


