{if $ec == 'LR'}
<h2>Redirecting to Liberty Reserve Payment Processing page...</h2>
<form name="lrpaid" method="POST" action="https://sci.libertyreserve.com">
<input type="hidden" name="type" value="{$group.id}">
<input type="hidden" name="code" value="{$code}">
<input type="hidden" name="action" value="checkstatus">
<input type="hidden" name="lr_acc" value="{$settings.lracc}">
<input type="hidden" name="lr_store" value="{$settings.lr_storename}">
<input type="hidden" name="lr_amnt" value="{$amount}">
<input type="hidden" name="lr_currency" value="LRUSD">
<input type="hidden" name="lr_comments" value="List: {$group.name}">
<input type="hidden" name="lr_success_url" value="{$settings.site_url}?a=addprogram&step=2">
<input type="hidden" name="lr_success_url_method" value="POST">
<input type="hidden" name="lr_fail_url" value="{$settings.site_url}?a=addprogram">
<input type="hidden" name="lr_fail_url_method" value="POST">
<input type="hidden" name="lr_status_url" value="{$settings.site_url}LR_processing.php">
<input type="hidden" name="lr_status_url_method" value="POST">
</form>
<script language="JavaScript">
document.lrpaid.submit();
</script>

{elseif $ec == 'PM'}
<h2>Redirecting to Perfect Money Payment Processing page...</h2>
<form name="pmpaid" action="https://perfectmoney.com/api/step1.asp" method="POST">
    <input type="hidden" name="action" value="checkstatus">
    <input type="hidden" name="type" value="{$group.id}">
    <input type="hidden" name="code" value="{$code}">
    <input type="hidden" name="PAYEE_ACCOUNT" value="{$settings.perfectmoney_acc}">
    <input type="hidden" name="PAYEE_NAME" value="{$settings.site_name}">
    <input type="hidden" name="PAYMENT_AMOUNT" value="{$amount}">
    <input type="hidden" name="PAYMENT_UNITS" value="USD">
    <input type="hidden" name="PAYMENT_URL" value="{$settings.site_url}?a=addprogram&step=2">
    <input type="hidden" name="NOPAYMENT_URL" value="{$settings.site_url}?a=addprogram"">
    <input type="hidden" name="STATUS_URL"  value="{$settings.site_url}PM_processing.php">
    <input type="hidden" name="SUGGESTED_MEMO" value="List: {$group.name}">
    <input type="hidden" name="BAGGAGE_FIELDS"  value="type action code">
</form>
<script language="JavaScript">
document.pmpaid.submit();
</script>

{else}
<script language="JavaScript">
alert("Please choose a Processor!");
history.go(-1);
</script>
{/if}