<?php /* Smarty version 2.6.2, created on 2012-05-24 22:26:22
         compiled from details_exclusive.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'details_exclusive.tpl', 6, false),array('modifier', 'escape', 'details_exclusive.tpl', 68, false),)), $this); ?>
<div class="dpz">
  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <tr>
      <td colspan="2" class="dp_title">  	  
	  <table width="100%" border="0" cellspacing="0" cellpadding="0">
          <tr><td align="left"><a href="<?php echo ((is_array($_tmp="?a=go&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" target="_blank" class="do_tlink"><b><?php echo $this->_tpl_vars['listing']['name']; ?>
</b></a><?php if ($this->_tpl_vars['listing']['new']): ?> <i style="color:red">new</i><?php endif; ?> &nbsp; <?php if (isset($this->_sections['r'])) unset($this->_sections['r']);
$this->_sections['r']['name'] = 'r';
$this->_sections['r']['loop'] = is_array($_loop=$this->_tpl_vars['listing']['hhot']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['r']['show'] = true;
$this->_sections['r']['max'] = $this->_sections['r']['loop'];
$this->_sections['r']['step'] = 1;
$this->_sections['r']['start'] = $this->_sections['r']['step'] > 0 ? 0 : $this->_sections['r']['loop']-1;
if ($this->_sections['r']['show']) {
    $this->_sections['r']['total'] = $this->_sections['r']['loop'];
    if ($this->_sections['r']['total'] == 0)
        $this->_sections['r']['show'] = false;
} else
    $this->_sections['r']['total'] = 0;
if ($this->_sections['r']['show']):

            for ($this->_sections['r']['index'] = $this->_sections['r']['start'], $this->_sections['r']['iteration'] = 1;
                 $this->_sections['r']['iteration'] <= $this->_sections['r']['total'];
                 $this->_sections['r']['index'] += $this->_sections['r']['step'], $this->_sections['r']['iteration']++):
$this->_sections['r']['rownum'] = $this->_sections['r']['iteration'];
$this->_sections['r']['index_prev'] = $this->_sections['r']['index'] - $this->_sections['r']['step'];
$this->_sections['r']['index_next'] = $this->_sections['r']['index'] + $this->_sections['r']['step'];
$this->_sections['r']['first']      = ($this->_sections['r']['iteration'] == 1);
$this->_sections['r']['last']       = ($this->_sections['r']['iteration'] == $this->_sections['r']['total']);
 if ($this->_tpl_vars['listing']['hhot'][$this->_sections['r']['index']]['star']): ?><img src="<?php echo ((is_array($_tmp="images/hot1.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" align="absmiddle"><?php endif;  endfor; endif; ?></td>
<td class="rankz" align="right">Rank: <b><?php echo $this->_tpl_vars['listing']['ordering']; ?>
</b></td></tr>
</table></td><td class="dp_title" align="right"><?php if (isset($this->_sections['p'])) unset($this->_sections['p']);
$this->_sections['p']['name'] = 'p';
$this->_sections['p']['loop'] = is_array($_loop=$this->_tpl_vars['listing']['options']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['p']['show'] = true;
$this->_sections['p']['max'] = $this->_sections['p']['loop'];
$this->_sections['p']['step'] = 1;
$this->_sections['p']['start'] = $this->_sections['p']['step'] > 0 ? 0 : $this->_sections['p']['loop']-1;
if ($this->_sections['p']['show']) {
    $this->_sections['p']['total'] = $this->_sections['p']['loop'];
    if ($this->_sections['p']['total'] == 0)
        $this->_sections['p']['show'] = false;
} else
    $this->_sections['p']['total'] = 0;
if ($this->_sections['p']['show']):

            for ($this->_sections['p']['index'] = $this->_sections['p']['start'], $this->_sections['p']['iteration'] = 1;
                 $this->_sections['p']['iteration'] <= $this->_sections['p']['total'];
                 $this->_sections['p']['index'] += $this->_sections['p']['step'], $this->_sections['p']['iteration']++):
$this->_sections['p']['rownum'] = $this->_sections['p']['iteration'];
$this->_sections['p']['index_prev'] = $this->_sections['p']['index'] - $this->_sections['p']['step'];
$this->_sections['p']['index_next'] = $this->_sections['p']['index'] + $this->_sections['p']['step'];
$this->_sections['p']['first']      = ($this->_sections['p']['iteration'] == 1);
$this->_sections['p']['last']       = ($this->_sections['p']['iteration'] == $this->_sections['p']['total']);
?><img src="<?php echo ((is_array($_tmp="images/".($this->_tpl_vars['listing']['options'][$this->_sections['p']['index']]['name']).".gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="<?php echo $this->_tpl_vars['listing']['options'][$this->_sections['p']['index']]['name']; ?>
" title="<?php echo $this->_tpl_vars['listing']['options'][$this->_sections['p']['index']]['name']; ?>
" align="absmiddle"> <?php endfor; endif; ?>&nbsp;</td>
    </tr>
<tr><td colspan="3" valign="top" class="dp_imgz"><img src="<?php echo ((is_array($_tmp="images/spacer.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="1" height="5" /></td></tr>
    <tr>
      <td rowspan="2" valign="top" class="dp_imgz"><table width="100%" border="0" cellspacing="0" cellpadding="2">
  <tr>
    <td align="center"><a href="<?php echo ((is_array($_tmp="?a=go&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" target="_blank"><img src="http://mozshot.nemui.org/shot/?<?php echo $this->_tpl_vars['listing']['url']; ?>
" width=160 height=100 class="pimg"></a></td></tr>
  <tr>
    <td align="center"><img src="<?php echo ((is_array($_tmp="images/stat".($this->_tpl_vars['listing']['hyip_status']).".png")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="132" height="27" /></td>
  </tr>
  <tr>
    <td align="center" class="dp_text"><div align="center">Added: <?php echo $this->_tpl_vars['listing']['added']; ?>
</div></td>
  </tr>
</table></td>
      <td valign="top" class="dp_info1z"><table width="100%" border="0" cellspacing="0" cellpadding="0">
        <tr>
          <td class="dp_text"><strong>Our Rating:</strong> <img src="<?php echo ((is_array($_tmp="images/".($this->_tpl_vars['listing']['rating'])."star.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" border="0" align="absmiddle" title="<?php echo $this->_tpl_vars['listing']['rating']; ?>
 star"></td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Interest:</strong> <?php echo $this->_tpl_vars['listing']['percents']; ?>
</td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Our Investment:</strong> <?php if ($this->_tpl_vars['listing']['spend'] > 0): ?>$<?php echo $this->_tpl_vars['listing']['spend'];  else: ?>No<?php endif; ?></td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Payout Ratio:</strong> <?php echo $this->_tpl_vars['listing']['ratio']*100; ?>
% <?php if ($this->_tpl_vars['listing']['ratio'] >= 1): ?><font color="green"><i>in profit</i></font><?php endif; ?></td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Payment methods:</strong></td>
        </tr>
        <tr>
          <td class="dp_text"><?php if (isset($this->_sections['p'])) unset($this->_sections['p']);
$this->_sections['p']['name'] = 'p';
$this->_sections['p']['loop'] = is_array($_loop=$this->_tpl_vars['listing']['payments']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['p']['show'] = true;
$this->_sections['p']['max'] = $this->_sections['p']['loop'];
$this->_sections['p']['step'] = 1;
$this->_sections['p']['start'] = $this->_sections['p']['step'] > 0 ? 0 : $this->_sections['p']['loop']-1;
if ($this->_sections['p']['show']) {
    $this->_sections['p']['total'] = $this->_sections['p']['loop'];
    if ($this->_sections['p']['total'] == 0)
        $this->_sections['p']['show'] = false;
} else
    $this->_sections['p']['total'] = 0;
if ($this->_sections['p']['show']):

            for ($this->_sections['p']['index'] = $this->_sections['p']['start'], $this->_sections['p']['iteration'] = 1;
                 $this->_sections['p']['iteration'] <= $this->_sections['p']['total'];
                 $this->_sections['p']['index'] += $this->_sections['p']['step'], $this->_sections['p']['iteration']++):
$this->_sections['p']['rownum'] = $this->_sections['p']['iteration'];
$this->_sections['p']['index_prev'] = $this->_sections['p']['index'] - $this->_sections['p']['step'];
$this->_sections['p']['index_next'] = $this->_sections['p']['index'] + $this->_sections['p']['step'];
$this->_sections['p']['first']      = ($this->_sections['p']['iteration'] == 1);
$this->_sections['p']['last']       = ($this->_sections['p']['iteration'] == $this->_sections['p']['total']);
?><img src="<?php echo ((is_array($_tmp="images/".($this->_tpl_vars['listing']['payments'][$this->_sections['p']['index']]['system']).".gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" align="absmiddle" alt="<?php echo $this->_tpl_vars['listing']['payments'][$this->_sections['p']['index']]['system']; ?>
" title="<?php echo $this->_tpl_vars['listing']['payments'][$this->_sections['p']['index']]['system']; ?>
" /> <?php endfor; endif; ?></td>
        </tr>
      </table></td>
      <td valign="top" class="dp_info2z">
<table width="100%" border="0" cellspacing="0" cellpadding="0">
<tr><td>
<table width="100%" border="0" cellspacing="0" cellpadding="0">
<tr><td class="dp_text" width="30%"><b>User Rating: </b></td>
<td> <span class="emptystars"><span class="fullstars" style="width: <?php echo $this->_tpl_vars['listing']['usrrating']; ?>
%" title="<?php echo $this->_tpl_vars['listing']['avg_vote']; ?>
 / <?php echo $this->_tpl_vars['listing']['cvotes']; ?>
 votes"></span></span></td>
        </tr>
</table></td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Monitored:</strong> <?php echo $this->_tpl_vars['listing']['monitored']; ?>
 days</td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Minimal/Maximal Spend:</strong> <?php echo $this->_tpl_vars['listing']['min_spend']; ?>
/<?php if ($this->_tpl_vars['listing']['max_spend']):  echo $this->_tpl_vars['listing']['max_spend'];  else: ?>No Limit<?php endif; ?></td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Withdrawal:</strong>  <?php if ($this->_tpl_vars['listing']['withdrawal_type'] == 1): ?>Manual<?php endif;  if ($this->_tpl_vars['listing']['withdrawal_type'] == 2): ?>Instant<?php endif;  if ($this->_tpl_vars['listing']['withdrawal_type'] == 3): ?>Automatic<?php endif; ?></td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Referral:</strong> <?php if ($this->_tpl_vars['listing']['referral']):  echo $this->_tpl_vars['listing']['referral'];  else: ?>No<?php endif; ?></td>
        </tr>
        <?php if ($this->_tpl_vars['listing']['support_email'] || $this->_tpl_vars['listing']['support_form'] || $this->_tpl_vars['listing']['support_phone'] || $this->_tpl_vars['listing']['support_aim']): ?>
        <tr>
          <td class="dp_text"><strong>Support:</strong> <?php if ($this->_tpl_vars['listing']['support_email']): ?><a href="mailto:<?php echo $this->_tpl_vars['listing']['support_email']; ?>
"><img src="<?php echo ((is_array($_tmp="images/smail.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" border=0 alt="Support E-Mail" title="Support E-Mail" align=absmiddle></a><?php endif; ?> <?php if ($this->_tpl_vars['listing']['support_form']): ?><a href="<?php echo $this->_tpl_vars['listing']['support_form']; ?>
" target=_blank><img src="<?php echo ((is_array($_tmp="images/sform.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" border=0 alt="Support Form" title="Support Form" align=absmiddle></a><?php endif; ?> <?php if ($this->_tpl_vars['listing']['support_phone']): ?><img src="<?php echo ((is_array($_tmp="images/sphone.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" border=0 alt="Phone: <?php echo $this->_tpl_vars['listing']['support_phone']; ?>
" title="Phone: <?php echo $this->_tpl_vars['listing']['support_phone']; ?>
" align=absmiddle><?php endif; ?> <?php if ($this->_tpl_vars['listing']['support_aim']): ?><img src="<?php echo ((is_array($_tmp="images/smsn.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" border=0 alt="<?php echo $this->_tpl_vars['listing']['support_aim']; ?>
" title="<?php echo $this->_tpl_vars['listing']['support_aim']; ?>
" align=absmiddle><?php endif; ?></td>
        </tr><?php endif;  if ($this->_tpl_vars['listing']['forums']): ?>
        <tr>
          <td class="dp_text"><strong>Forum:</strong> <?php if (isset($this->_sections['p'])) unset($this->_sections['p']);
$this->_sections['p']['name'] = 'p';
$this->_sections['p']['loop'] = is_array($_loop=$this->_tpl_vars['listing']['forums']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['p']['show'] = true;
$this->_sections['p']['max'] = $this->_sections['p']['loop'];
$this->_sections['p']['step'] = 1;
$this->_sections['p']['start'] = $this->_sections['p']['step'] > 0 ? 0 : $this->_sections['p']['loop']-1;
if ($this->_sections['p']['show']) {
    $this->_sections['p']['total'] = $this->_sections['p']['loop'];
    if ($this->_sections['p']['total'] == 0)
        $this->_sections['p']['show'] = false;
} else
    $this->_sections['p']['total'] = 0;
if ($this->_sections['p']['show']):

            for ($this->_sections['p']['index'] = $this->_sections['p']['start'], $this->_sections['p']['iteration'] = 1;
                 $this->_sections['p']['iteration'] <= $this->_sections['p']['total'];
                 $this->_sections['p']['index'] += $this->_sections['p']['step'], $this->_sections['p']['iteration']++):
$this->_sections['p']['rownum'] = $this->_sections['p']['iteration'];
$this->_sections['p']['index_prev'] = $this->_sections['p']['index'] - $this->_sections['p']['step'];
$this->_sections['p']['index_next'] = $this->_sections['p']['index'] + $this->_sections['p']['step'];
$this->_sections['p']['first']      = ($this->_sections['p']['iteration'] == 1);
$this->_sections['p']['last']       = ($this->_sections['p']['iteration'] == $this->_sections['p']['total']);
?><a href="<?php echo ((is_array($_tmp=$this->_tpl_vars['listing']['forums'][$this->_sections['p']['index']]['url'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" target=_blank><?php echo $this->_tpl_vars['listing']['forums'][$this->_sections['p']['index']]['name']; ?>
</a> <?php endfor; endif; ?></td>
        </tr><?php endif; ?>
      </table></td>
    </tr>
    <tr>
      <td colspan="2" class="dp_subz">
       <table border="0" cellspacing="0" cellpadding="7">
        <tr>
          
<?php if ($this->_tpl_vars['detailed']): ?>
<td class="arr"><a href="#" class="dp_link" onclick="GetData('','votes','<?php echo $this->_tpl_vars['listing']['id']; ?>
','');return false;">Vote</a></td>
<td class="arr"><a href="#" class="dp_link" onclick="GetData('','paystat','<?php echo $this->_tpl_vars['listing']['id']; ?>
','');return false;">Payouts</a></td>
<td class="arr"><a href="#" class="dp_link" onclick="GetData('','whois','<?php echo $this->_tpl_vars['listing']['id']; ?>
','');return false;">Whois</a></td>                   
<td class="arr"><a href="#" class="dp_link" onclick="GetData('','button','<?php echo $this->_tpl_vars['listing']['id']; ?>
','');return false;">Button</a></td>
<?php if ($this->_tpl_vars['listing']['rcb'] > 0): ?><td class="arr"><a href="#" class="dp_link" style="color:green" onclick="GetData('','rcb','<?php echo $this->_tpl_vars['listing']['id']; ?>
','');return false;">RCB <?php echo $this->_tpl_vars['listing']['rcb']; ?>
%</a></td><?php endif; ?>
<td class="arr"><a href="#" class="dp_link" style="color:red" onclick="GetData('','report_scam','<?php echo $this->_tpl_vars['listing']['id']; ?>
','');return false;">Report Scam</a></td>
<?php else: ?>

<td class="arr"><a href="<?php echo ((is_array($_tmp="?a=details&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="dp_link">Program Details</a></td>
<td class="arr"><a href="<?php echo ((is_array($_tmp="?a=details&aj=paystat&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="dp_link">Payouts</a></td>
<td class="arr"><a href="<?php echo ((is_array($_tmp="?a=details&aj=votes&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="dp_link">Vote</a></td>

<?php if ($this->_tpl_vars['listing']['rcb'] > 0): ?><td class="arr"><a href="<?php echo ((is_array($_tmp="?a=details&aj=rcb&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="dp_link" style="color:green">RCB <?php echo $this->_tpl_vars['listing']['rcb']; ?>
%</a></td><?php endif; ?>
<td class="arr"><a href="<?php echo ((is_array($_tmp="?a=details&aj=report_scam&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="dp_link" style="color:red">Report Scam</a></td>
<?php endif; ?>

<td class="arr"><?php if ($this->_tpl_vars['listing']['bookmark']): ?><a href="<?php echo ((is_array($_tmp="?a=bookmarks&action=remove&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" onclick="return confirm('Do you really want to remove the program from bookmarks?')" class="dp_link">Remove</a><?php else: ?><a href="<?php echo ((is_array($_tmp="?a=bookmarks&action=add&lid=".($this->_tpl_vars['listing']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="dp_link">Bookmark</a><?php endif; ?></td>

</tr>
      </table></td>
    </tr>
  </table>
</div>
<?php if ($this->_tpl_vars['detailed']): ?><div align="left"><strong>Program Discription:</strong><br><?php echo $this->_tpl_vars['listing']['description']; ?>
</div><?php endif; ?>