<?php /* Smarty version 2.6.2, created on 2012-03-23 20:12:39
         compiled from ads_bottomright_banners.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'ads_bottomright_banners.tpl', 1, false),)), $this); ?>
<script src="<?php echo ((is_array($_tmp="js/ads_box_r.js")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"></script>
<?php if ($this->_tpl_vars['ads']['10'][0]['no']): ?>
<script>right_ads("<?php echo ((is_array($_tmp="?a=goads&aid=10&id=".($this->_tpl_vars['ads']['10'][0]['no']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
","<?php echo $this->_tpl_vars['ads']['10'][0]['imgurl']; ?>
","<?php echo $this->_tpl_vars['ads']['10'][0]['desc']; ?>
","<?php if ($this->_tpl_vars['ads']['10'][0]['format'] == 'flash'): ?>f<?php else: ?>p<?php endif; ?>")</script>
<?php else: ?>
<script>right_ads("<?php echo ((is_array($_tmp="?a=advertise&ad=10")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
","images/125.png","Advertise your banner here","p")</script>
<?php endif; ?>

