<?php /* Smarty version 2.6.2, created on 2012-05-23 21:14:37
         compiled from details_rcb.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'details_rcb.tpl', 36, false),array('modifier', 'escape', 'details_rcb.tpl', 59, false),array('modifier', 'default', 'details_rcb.tpl', 60, false),)), $this); ?>
<?php if ($this->_tpl_vars['say'] == 'added'): ?>
<br><table cellspacing=2 cellpadding=3 border=0 width="100%">
<tr><td><strong style="color:green">Thank you. Your request has been sent to administrator. You will receive commission back after admininstrator approve the request.</td></tr>
</table><br><br>
<?php else: ?>
<?php if ($this->_tpl_vars['rcbrates']): ?>
<table cellspacing=0 cellpadding=3 border=0 width="100%">  
<tr><td><b>RCB For <?php echo $this->_tpl_vars['listing']['name']; ?>
</b></td></tr>
<tr><td><table cellspacing=1 cellpadding=2 width="99%" style="border: 1px dotted #CCCCCC;" align="center">
<tr bgcolor="#EEEEEE">
<td width=25% align="center" rowspan="2">Deposit Amount</td>
<td width=15% align="center" rowspan="2">Referral</td>
<td width="30%" align="center" colspan="2">1st Deposit</td>
<td width="30%" align="center" colspan="2">Re-Invested</td>
</tr>
<tr bgcolor="#EEEEEE">
<td width=15% align="center">RCB</td>
<td width=15% align="center">BONUS</td>
<td width=15% align="center">RCB</td>
<td width=15% align="center">BONUS</td>
</tr>
<?php if (isset($this->_sections['l'])) unset($this->_sections['l']);
$this->_sections['l']['name'] = 'l';
$this->_sections['l']['loop'] = is_array($_loop=$this->_tpl_vars['rcbrates']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['l']['show'] = true;
$this->_sections['l']['max'] = $this->_sections['l']['loop'];
$this->_sections['l']['step'] = 1;
$this->_sections['l']['start'] = $this->_sections['l']['step'] > 0 ? 0 : $this->_sections['l']['loop']-1;
if ($this->_sections['l']['show']) {
    $this->_sections['l']['total'] = $this->_sections['l']['loop'];
    if ($this->_sections['l']['total'] == 0)
        $this->_sections['l']['show'] = false;
} else
    $this->_sections['l']['total'] = 0;
if ($this->_sections['l']['show']):

            for ($this->_sections['l']['index'] = $this->_sections['l']['start'], $this->_sections['l']['iteration'] = 1;
                 $this->_sections['l']['iteration'] <= $this->_sections['l']['total'];
                 $this->_sections['l']['index'] += $this->_sections['l']['step'], $this->_sections['l']['iteration']++):
$this->_sections['l']['rownum'] = $this->_sections['l']['iteration'];
$this->_sections['l']['index_prev'] = $this->_sections['l']['index'] - $this->_sections['l']['step'];
$this->_sections['l']['index_next'] = $this->_sections['l']['index'] + $this->_sections['l']['step'];
$this->_sections['l']['first']      = ($this->_sections['l']['iteration'] == 1);
$this->_sections['l']['last']       = ($this->_sections['l']['iteration'] == $this->_sections['l']['total']);
?>
<tr bgcolor="#CCFF99">
<td align="center">$<?php echo $this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['min_deposit']; ?>
-$<?php echo $this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['max_deposit']; ?>
</td>
<td align="center"><?php if ($this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['ref'] > 0):  echo $this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['ref']; ?>
%<?php else: ?> -- <?php endif; ?></td>
<td align="center"><?php if ($this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['rcb'] > 0):  echo $this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['rcb']; ?>
%<?php else: ?> -- <?php endif; ?></td>
<td align="center"><?php if ($this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['bonus'] > 0): ?>$<?php echo $this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['bonus'];  else: ?> -- <?php endif; ?></td>
<td align="center"><?php if ($this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['rcb2'] > 0):  echo $this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['rcb2']; ?>
%<?php else: ?> -- <?php endif; ?></td>
<td align="center"><?php if ($this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['bonus2'] > 0): ?>$<?php echo $this->_tpl_vars['rcbrates'][$this->_sections['l']['index']]['bonus2'];  else: ?> -- <?php endif; ?></td>
</tr>
<?php endfor; endif; ?>
<tr bgcolor="#fbfbfb"><td colspan="6">
<ul>
<li>Please fill in the form and submit to us. We will process it Asap.</li>
<?php if (! $this->_tpl_vars['userinfo']['logged']): ?>
<li>You can <a href="<?php echo ((is_array($_tmp="?a=signup")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" style="color:red">signup</a> and <a href="<?php echo ((is_array($_tmp="?a=login")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" style="color:red">login</a> into our site to track your refbacks.</li>
</ul>
<?php endif; ?>

<?php if ($this->_tpl_vars['errors']): ?>
<ul style="color:red">
<?php if ($this->_tpl_vars['errors']['turing']): ?><li> Invalid turing image.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['email']): ?><li> Please enter your e-mail addresss.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['invalid_email']): ?><li> Please enter valid e-mail address.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['username']): ?><li> Please enter your program username.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['account']): ?><li> Please enter your payment system account.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['amount']): ?><li> Wrong deposit amount, please check again.</li><?php endif; ?>
</ul>
<?php endif; ?>
</td></tr>

<tr><td colspan=6><form method=post name="rcb_form" onsubmit="return vrcbdate()">
<input type="hidden" name="a" value="details">
<input type="hidden" name="aj" value="rcb">
<input type="hidden" name="lid" value="<?php echo $this->_tpl_vars['listing']['id']; ?>
">
<input type="hidden" name="action" value="savercb">
<input type="hidden" name="program" value="<?php echo $this->_tpl_vars['listing']['name']; ?>
">
<table cellspacing=1 cellpadding=2 border=0 width="90%">
<tr><td width="40%">* Program Username:</td><td><input type="text" name="username" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['username'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
" class=inpts size="30"></td></tr>
<tr><td>* Invested Amount:</td><td><input type="text" name="deposit" value="<?php echo ((is_array($_tmp=@$this->_tpl_vars['frm']['deposit'])) ? $this->_run_mod_handler('default', true, $_tmp, 1) : smarty_modifier_default($_tmp, 1)); ?>
" class=inpts size="15"> USD</td></tr>
<tr><td>* Deposited Date:</td><td><select name=dpdate_year class=inpts>
<?php if (isset($this->_sections['dpdate_year'])) unset($this->_sections['dpdate_year']);
$this->_sections['dpdate_year']['name'] = 'dpdate_year';
$this->_sections['dpdate_year']['loop'] = is_array($_loop=$this->_tpl_vars['year']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['dpdate_year']['show'] = true;
$this->_sections['dpdate_year']['max'] = $this->_sections['dpdate_year']['loop'];
$this->_sections['dpdate_year']['step'] = 1;
$this->_sections['dpdate_year']['start'] = $this->_sections['dpdate_year']['step'] > 0 ? 0 : $this->_sections['dpdate_year']['loop']-1;
if ($this->_sections['dpdate_year']['show']) {
    $this->_sections['dpdate_year']['total'] = $this->_sections['dpdate_year']['loop'];
    if ($this->_sections['dpdate_year']['total'] == 0)
        $this->_sections['dpdate_year']['show'] = false;
} else
    $this->_sections['dpdate_year']['total'] = 0;
if ($this->_sections['dpdate_year']['show']):

            for ($this->_sections['dpdate_year']['index'] = $this->_sections['dpdate_year']['start'], $this->_sections['dpdate_year']['iteration'] = 1;
                 $this->_sections['dpdate_year']['iteration'] <= $this->_sections['dpdate_year']['total'];
                 $this->_sections['dpdate_year']['index'] += $this->_sections['dpdate_year']['step'], $this->_sections['dpdate_year']['iteration']++):
$this->_sections['dpdate_year']['rownum'] = $this->_sections['dpdate_year']['iteration'];
$this->_sections['dpdate_year']['index_prev'] = $this->_sections['dpdate_year']['index'] - $this->_sections['dpdate_year']['step'];
$this->_sections['dpdate_year']['index_next'] = $this->_sections['dpdate_year']['index'] + $this->_sections['dpdate_year']['step'];
$this->_sections['dpdate_year']['first']      = ($this->_sections['dpdate_year']['iteration'] == 1);
$this->_sections['dpdate_year']['last']       = ($this->_sections['dpdate_year']['iteration'] == $this->_sections['dpdate_year']['total']);
?>
<option value=<?php echo $this->_tpl_vars['year'][$this->_sections['dpdate_year']['index']];  if ($this->_tpl_vars['year'][$this->_sections['dpdate_year']['index']] == $this->_tpl_vars['date']['year']): ?> selected<?php endif; ?>><?php echo $this->_tpl_vars['year'][$this->_sections['dpdate_year']['index']]; ?>
</option><?php endfor; endif; ?>
</select> <select name=dpdate_month class=inpts>
<?php if (isset($this->_sections['dpdate_month'])) unset($this->_sections['dpdate_month']);
$this->_sections['dpdate_month']['name'] = 'dpdate_month';
$this->_sections['dpdate_month']['loop'] = is_array($_loop=$this->_tpl_vars['month']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['dpdate_month']['show'] = true;
$this->_sections['dpdate_month']['max'] = $this->_sections['dpdate_month']['loop'];
$this->_sections['dpdate_month']['step'] = 1;
$this->_sections['dpdate_month']['start'] = $this->_sections['dpdate_month']['step'] > 0 ? 0 : $this->_sections['dpdate_month']['loop']-1;
if ($this->_sections['dpdate_month']['show']) {
    $this->_sections['dpdate_month']['total'] = $this->_sections['dpdate_month']['loop'];
    if ($this->_sections['dpdate_month']['total'] == 0)
        $this->_sections['dpdate_month']['show'] = false;
} else
    $this->_sections['dpdate_month']['total'] = 0;
if ($this->_sections['dpdate_month']['show']):

            for ($this->_sections['dpdate_month']['index'] = $this->_sections['dpdate_month']['start'], $this->_sections['dpdate_month']['iteration'] = 1;
                 $this->_sections['dpdate_month']['iteration'] <= $this->_sections['dpdate_month']['total'];
                 $this->_sections['dpdate_month']['index'] += $this->_sections['dpdate_month']['step'], $this->_sections['dpdate_month']['iteration']++):
$this->_sections['dpdate_month']['rownum'] = $this->_sections['dpdate_month']['iteration'];
$this->_sections['dpdate_month']['index_prev'] = $this->_sections['dpdate_month']['index'] - $this->_sections['dpdate_month']['step'];
$this->_sections['dpdate_month']['index_next'] = $this->_sections['dpdate_month']['index'] + $this->_sections['dpdate_month']['step'];
$this->_sections['dpdate_month']['first']      = ($this->_sections['dpdate_month']['iteration'] == 1);
$this->_sections['dpdate_month']['last']       = ($this->_sections['dpdate_month']['iteration'] == $this->_sections['dpdate_month']['total']);
?>
<option value=<?php echo $this->_sections['dpdate_month']['index']+1;  if ($this->_sections['dpdate_month']['index']+1 == $this->_tpl_vars['date']['month']): ?> selected<?php endif; ?>><?php echo $this->_tpl_vars['month'][$this->_sections['dpdate_month']['index']]; ?>
</option>
<?php endfor; endif; ?>
</select> <select name=dpdate_day class=inpts>
<?php if (isset($this->_sections['dpdate_day'])) unset($this->_sections['dpdate_day']);
$this->_sections['dpdate_day']['name'] = 'dpdate_day';
$this->_sections['dpdate_day']['loop'] = is_array($_loop=$this->_tpl_vars['day']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['dpdate_day']['show'] = true;
$this->_sections['dpdate_day']['max'] = $this->_sections['dpdate_day']['loop'];
$this->_sections['dpdate_day']['step'] = 1;
$this->_sections['dpdate_day']['start'] = $this->_sections['dpdate_day']['step'] > 0 ? 0 : $this->_sections['dpdate_day']['loop']-1;
if ($this->_sections['dpdate_day']['show']) {
    $this->_sections['dpdate_day']['total'] = $this->_sections['dpdate_day']['loop'];
    if ($this->_sections['dpdate_day']['total'] == 0)
        $this->_sections['dpdate_day']['show'] = false;
} else
    $this->_sections['dpdate_day']['total'] = 0;
if ($this->_sections['dpdate_day']['show']):

            for ($this->_sections['dpdate_day']['index'] = $this->_sections['dpdate_day']['start'], $this->_sections['dpdate_day']['iteration'] = 1;
                 $this->_sections['dpdate_day']['iteration'] <= $this->_sections['dpdate_day']['total'];
                 $this->_sections['dpdate_day']['index'] += $this->_sections['dpdate_day']['step'], $this->_sections['dpdate_day']['iteration']++):
$this->_sections['dpdate_day']['rownum'] = $this->_sections['dpdate_day']['iteration'];
$this->_sections['dpdate_day']['index_prev'] = $this->_sections['dpdate_day']['index'] - $this->_sections['dpdate_day']['step'];
$this->_sections['dpdate_day']['index_next'] = $this->_sections['dpdate_day']['index'] + $this->_sections['dpdate_day']['step'];
$this->_sections['dpdate_day']['first']      = ($this->_sections['dpdate_day']['iteration'] == 1);
$this->_sections['dpdate_day']['last']       = ($this->_sections['dpdate_day']['iteration'] == $this->_sections['dpdate_day']['total']);
?>
<option value=<?php echo $this->_sections['dpdate_day']['index']+1;  if ($this->_sections['dpdate_day']['index']+1 == $this->_tpl_vars['date']['day']): ?> selected<?php endif; ?>><?php echo $this->_tpl_vars['day'][$this->_sections['dpdate_day']['index']]; ?>
</option>
<?php endfor; endif; ?></select></td></tr>
<tr><td>* Contact E-mail:</td><td><input type="text" name="email" value="<?php echo ((is_array($_tmp=((is_array($_tmp=@$this->_tpl_vars['frm']['email'])) ? $this->_run_mod_handler('default', true, $_tmp, @$this->_tpl_vars['userinfo']['email']) : smarty_modifier_default($_tmp, @$this->_tpl_vars['userinfo']['email'])))) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
" class=inpts size="30"></td></tr>
<tr><td >* Deposit Payment System: </td>
<td><select name="paysystem" class="inpts" onchange="setDefAccount()">
<?php if (isset($this->_sections['rp'])) unset($this->_sections['rp']);
$this->_sections['rp']['name'] = 'rp';
$this->_sections['rp']['loop'] = is_array($_loop=$this->_tpl_vars['rcbpayments']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['rp']['show'] = true;
$this->_sections['rp']['max'] = $this->_sections['rp']['loop'];
$this->_sections['rp']['step'] = 1;
$this->_sections['rp']['start'] = $this->_sections['rp']['step'] > 0 ? 0 : $this->_sections['rp']['loop']-1;
if ($this->_sections['rp']['show']) {
    $this->_sections['rp']['total'] = $this->_sections['rp']['loop'];
    if ($this->_sections['rp']['total'] == 0)
        $this->_sections['rp']['show'] = false;
} else
    $this->_sections['rp']['total'] = 0;
if ($this->_sections['rp']['show']):

            for ($this->_sections['rp']['index'] = $this->_sections['rp']['start'], $this->_sections['rp']['iteration'] = 1;
                 $this->_sections['rp']['iteration'] <= $this->_sections['rp']['total'];
                 $this->_sections['rp']['index'] += $this->_sections['rp']['step'], $this->_sections['rp']['iteration']++):
$this->_sections['rp']['rownum'] = $this->_sections['rp']['iteration'];
$this->_sections['rp']['index_prev'] = $this->_sections['rp']['index'] - $this->_sections['rp']['step'];
$this->_sections['rp']['index_next'] = $this->_sections['rp']['index'] + $this->_sections['rp']['step'];
$this->_sections['rp']['first']      = ($this->_sections['rp']['iteration'] == 1);
$this->_sections['rp']['last']       = ($this->_sections['rp']['iteration'] == $this->_sections['rp']['total']);
?>
<option value="<?php echo $this->_tpl_vars['rcbpayments'][$this->_sections['rp']['index']]['name']; ?>
" <?php if ($this->_tpl_vars['frm']['paysystem'] == $this->_tpl_vars['rcbpayments'][$this->_sections['rp']['index']]['name']): ?>selected<?php endif; ?>><?php echo $this->_tpl_vars['rcbpayments'][$this->_sections['rp']['index']]['name']; ?>
</option>
<?php endfor; endif; ?></select></td></tr>
<tr><td>* Your Payment System Account:</td><td><input type="text" name="psaccount" value="<?php echo ((is_array($_tmp=((is_array($_tmp=@$this->_tpl_vars['frm']['psaccount'])) ? $this->_run_mod_handler('default', true, $_tmp, @$this->_tpl_vars['userinfo']['libertyreserve_account']) : smarty_modifier_default($_tmp, @$this->_tpl_vars['userinfo']['libertyreserve_account'])))) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
" class=inpts size="30"></td></tr>
<tr>
 <td>&nbsp;&nbsp;Your Comments</td>
 <td><textarea name="comments" cols="35" rows="4" class="inpts"><?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['comments'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
</textarea></td>
</tr>
<?php if ($this->_tpl_vars['settings']['use_turing']): ?>
<tr>
  <td>* Turing</td>
  <td><img src="<?php echo ((is_array($_tmp="?a=turing&".($this->_tpl_vars['sesname'])."=".($this->_tpl_vars['sesid'])."&r=".($this->_tpl_vars['rand']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="turing code"><br><input type=text name="turing" maxlength="6" size="10" class="inpts"></td>
</tr>
<?php endif; ?>

<tr><td></td><td><input type="submit" value="Request Now &gt;&gt;" class="sbmt"></td></tr>
</table></form>
</td></tr></table>
</td></tr></table><br>
<script>setDefAccount();</script>
<?php else: ?>
<table cellspacing=0 cellpadding=0 border=0 width=100% class="listbody">
<tr><td><strong> RCB For <?php echo $this->_tpl_vars['listing']['name']; ?>
</strong></td></tr>
<tr><td>Unfortunately ,We don't offer RCB for this Program at present .<br>
Please check it later or try other programs.<br>
Thanks for your support.<br>
</td></tr></table><br><br>
<?php endif;  endif; ?>

<?php if ($this->_tpl_vars['rcbdata']): ?>
<fieldset><legend><b>RCB Requested History</b></legend>
<table cellspacing=1 cellpadding=2 border=0 width=100%>  
<tr bgcolor="green">
 <th><b>Date</b></th>
 <th><b>User</b></th>
 <th><b>Deposit/RCB</b></th>
 <th><b>EC(A/C)</b></th>
 <th><b>Status</b></th>
</tr>
<?php if (isset($this->_sections['l'])) unset($this->_sections['l']);
$this->_sections['l']['name'] = 'l';
$this->_sections['l']['loop'] = is_array($_loop=$this->_tpl_vars['rcbdata']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['l']['show'] = true;
$this->_sections['l']['max'] = $this->_sections['l']['loop'];
$this->_sections['l']['step'] = 1;
$this->_sections['l']['start'] = $this->_sections['l']['step'] > 0 ? 0 : $this->_sections['l']['loop']-1;
if ($this->_sections['l']['show']) {
    $this->_sections['l']['total'] = $this->_sections['l']['loop'];
    if ($this->_sections['l']['total'] == 0)
        $this->_sections['l']['show'] = false;
} else
    $this->_sections['l']['total'] = 0;
if ($this->_sections['l']['show']):

            for ($this->_sections['l']['index'] = $this->_sections['l']['start'], $this->_sections['l']['iteration'] = 1;
                 $this->_sections['l']['iteration'] <= $this->_sections['l']['total'];
                 $this->_sections['l']['index'] += $this->_sections['l']['step'], $this->_sections['l']['iteration']++):
$this->_sections['l']['rownum'] = $this->_sections['l']['iteration'];
$this->_sections['l']['index_prev'] = $this->_sections['l']['index'] - $this->_sections['l']['step'];
$this->_sections['l']['index_next'] = $this->_sections['l']['index'] + $this->_sections['l']['step'];
$this->_sections['l']['first']      = ($this->_sections['l']['iteration'] == 1);
$this->_sections['l']['last']       = ($this->_sections['l']['iteration'] == $this->_sections['l']['total']);
?>
<tr bgcolor=<?php if ($this->_sections['l']['rownum'] % 2 == 0): ?>#F8F8F8<?php else: ?>#FFFFF2<?php endif; ?>>
 <td><?php echo $this->_tpl_vars['rcbdata'][$this->_sections['l']['index']]['rdate']; ?>
</td>
 <td><?php echo $this->_tpl_vars['rcbdata'][$this->_sections['l']['index']]['username']; ?>
</td>
 <td>$<?php echo $this->_tpl_vars['rcbdata'][$this->_sections['l']['index']]['deposit']; ?>
/<font color="green">$<?php echo $this->_tpl_vars['rcbdata'][$this->_sections['l']['index']]['rcb']; ?>
</font></td>
 <td><?php echo $this->_tpl_vars['rcbdata'][$this->_sections['l']['index']]['ec']; ?>
(<?php echo $this->_tpl_vars['rcbdata'][$this->_sections['l']['index']]['ecno']; ?>
)</td>
 <td><?php if ($this->_tpl_vars['rcbdata'][$this->_sections['l']['index']]['status'] == 0): ?>Waiting For Check...<?php elseif ($this->_tpl_vars['rcbdata'][$this->_sections['l']['index']]['status'] == 1): ?>Paid<?php if ($this->_tpl_vars['rcbdata'][$this->_sections['l']['index']]['batch']): ?>(batch=<?php echo $this->_tpl_vars['rcbdata'][$this->_sections['l']['index']]['batch']; ?>
)<?php endif;  else: ?>Declined<?php endif; ?></td>
</tr>
<?php endfor; endif; ?>
<?php else: ?>
<tr><td>No Data Yet</td></tr>
<?php endif; ?>
</table></fieldset>