<div class="box">
<div class="box_title">Sidebar Banner(125x125)</div>
<div class="box_body">
<div style="text-align: center">
{section name=b7 loop=$ads.7}
{if $ads.7[b7].no}
<a href="{"?a=goads&aid=7&id=`$ads.7[b7].no`"|encurl}" target="_blank" title="{$ads.7[b7].desc}">{if $ads.7[b7].format == 'flash'}<embed width="125" height="125" src="{$ads.7[b7].imgurl}"><noembed>{"?a=goads&aid=7&id=`$ads.7[b7].no`"|encurl}</noembed>{else}<img src="{$ads.7[b7].imgurl}" width="125" height="125" alt="{$ads.7[b7].desc}" border="0">{/if}</a><br><a href="{"?a=advertise&ad=7"|encurl}">Cost of Ad - ${$ads.7[b7].price}</a><br>Expires: {$ads.7[b7].expired}
{else}
<a href="{"?a=advertise&ad=7"|encurl}" title="Advertise your banner here."><img src="{"images/125.png"|encurl}" width="125" height="125" alt="Place Your AD Here" border="0"></a><br><a href="{"?a=advertise&ad=7"|encurl}">Place AD Here - ${$ads.7[b7].price}</a>
{/if}<br><br>
{/section}

</div></div>
</div>