<div class="box">
<div class="box_title">Change Language</div>
<div class="box_body">
<div align="center">
<div id="google_translate_element"></div>
<script language="javascript">
{literal}
function googleTranslateElementInit() {
new google.translate.TranslateElement({
pageLanguage: 'en',
includedLanguages: 'zh-CN,es,fr,de,id,it,ja,ms,ru',
autoDisplay: false,
layout: google.translate.TranslateElement.InlineLayout.SIMPLE}, 
'google_translate_element');
}
{/literal}
</script>
<script src="https://translate.google.com/translate_a/element.js?cb=googleTranslateElementInit"></script>
</div></div></div>