{literal}<script language=javascript>
function validate_sub()
{
  if (!document.subscribe.email.value)
  {
    alert('Please, enter your E-Mail address!');
    document.subscribe.email.focus();
    return false;
  }
  else
  {
    a = document.subscribe.email.value.indexOf('@');
    b = document.subscribe.email.value.indexOf('@', a+1);
    c = document.subscribe.email.value.indexOf('.', a+1);
    if (a == -1 || b != -1 || c <= a + 2 || a < 1 || c + 2 >= document.subscribe.email.value.length || c + 4 < document.subscribe.email.value.length)
    {
      alert('Please, enter a valid E-Mail Address');
      document.subscribe.email.focus();
      return false;
    }
  }
  return true;
}
</script>{/literal}
<div class="box">
<div class="box_title">Join our mail list</div>
<div class="box_body">

<table width="100%" border="0" align="center" cellpadding="3" cellspacing="0">
<form method=post onsubmit="return validate_sub()" name="subscribe">
<input type="hidden" name="a" value="maillist">
<input type="hidden" name="display" value="">
<tr><td>
<table cellpadding="0" cellspacing="1" width="100%" align="center" border="0">
<tr><td width="30%" align="right">E-mail:</td>
<td><input name="email" type="text" class=inpts size="20"></td>
</tr>
<tr>
 <td align="right"><input type="radio" name="action" value="subscribe" checked></td><td>Subscribe</td>
</tr>
<tr>
 <td align="right"><input type="radio" name="action" value="unsubscribe"></td><td>Unsubscribe</td>
</tr>
<tr>
 <td colspan=2 align="center"><input type="submit" value="Submit" class=sbmt></td>
</tr>
<tr>
<td colspan="2" align="center"><font color="#FF0000">We never send SPAM and hate SPAMers.Please don't trust in any e-mail that appeared to be from us and not stated on our Newsletters Archive! </font>
</td></tr>
</table></form>
</td></tr>
</table></div></div>