{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">Unsubscribed:</div>
<div class="box_body">
<table cellspacing=1 cellpadding=2 border=0 width=100%>
<tr><td align="center"><b style="color:green">
Thank you for using our services.<br>
Your have been successfully unsubscribed.</b>
 <br><br>
<a href="{$settings.site_url}">Return to the home page</a>
 </td>
</tr>
</table>
</div></div>
{include file="footer.tpl"}