<div class="banz_b">
{section name=b4 loop=$ads.4}
{if $ads.4[b4].no}
<a href="{"?a=goads&aid=4&id=`$ads.4[b4].no`"|encurl}" target="_blank" title="{$ads.4[b4].desc}">{if $ads.4[b4].format == 'flash'}<embed width="468" height="60" src="{$ads.4[b4].imgurl}"><noembed>{"?a=goads&aid=4&id=`$ads.4[b4].no`"|encurl}</noembed>{else}<img src="{$ads.4[b4].imgurl}" width="468" height="60" alt="{$ads.4[b4].desc}" border="0">{/if}</a><br><a href="{"?a=advertise&ad=4"|encurl}">Advertise your banner here</a> | Expires: {$ads.4[b4].expired}
{else}
<a href="{"?a=advertise&ad=4"|encurl}" title="Advertise your banner here."><img src="{"images/468.gif"|encurl}" width="468" height="60" alt="Advertise your banner here." border="0"></a><br><a href="{"?a=advertise&ad=4"|encurl}">Advertise your banner here</a> | Available Now!</font>
{/if}<br>
{/section}
</div>