{include file="header_install.tpl"}
{if $wrong_license == 1}
</center>
<font color="red"><B>Wrong license.</b><br><br>
Please contact <a href="http://www.hothyipscript.com">HotHyipScript.com</a> if you bought license to this host.</font>
<br><br>
<center>
{/if}

{if $wrong_server_comm == 1}
</center>
<font color="red"><B>HHS Server Error.</B><br><br>
Please contact <a href="http://www.hothyipscript.com">HotHyipScript.com</a>  to inform us about this error.We'll activate manually your license.</font>
<br><br>
<center>
{/if}


{if $wrong_mysql_data}
</center>
<font color="red"><B>Wrong mysql data.</B><br><br>
Please be sure you entered right mysql host, mysql database name, mysql login, mysql password.<br>
Ask this information your hosting provider if you're not sure.</font>
<br><br>
<center>
{/if}

{if $installed != 1}
<form method=post>
<input type=hidden name=a value=install>
<table cellspacing=2 cellpadding=2 border=0>
<tr>
 <td colspan=2>MySQL data</td>
</tr><tr>
 <td>Mysql host:</td>
 <td><input type=text name=mysql_host value='{if $form_data.mysql_host}{$form_data.mysql_host}{else}localhost{/if}' class=inpts size=30></td>
</tr><tr>
 <td>Mysql database name:</td>
 <td><input type=text name=mysql_db value='{$form_data.mysql_db}' class=inpts size=30></td>
</tr><tr>
 <td>Mysql username:</td>
 <td><input type=text name=mysql_username value='{$form_data.mysql_username}' class=inpts size=30></td>
</tr><tr>
 <td>Mysql password:</td>
 <td><input type=text name=mysql_password value='{$form_data.mysql_password}' class=inpts size=30></td>
</tr><tr>
 <td colspan=2>License data:</td>
</tr><tr>
 <td>Host:</td>
 <td>{$hostname}</td>
</tr>  <tr>
   <td><B>Your License key is:</B></td>
   <br>{$hostname}
   <td><input type=text name="license_string" value='{$form_data.license_string}' class=inpts size=30></td>
  </tr><tr>
 <th colspan=2>System Settings:</th>
</tr><tr>
 <td>Administrator E-mail:</td>
 <td><input type=text name=admin_email value='{$form_data.admin_email}' class=inpts size=30></td>
</tr><tr>
 <td>System E-mail:</td>
 <td><input type=text name=system_email value='{$form_data.system_email}' class=inpts size=30></td>
</tr><tr>
 <td>Login:</td>
 <td><input type=text name=admin_login value='' class=inpts size=30></td>
</tr><tr>
 <td>Password:</td>
 <td><input type=password name=admin_password value='' class=inpts size=30></td>
</tr><tr>
 <td>&nbsp;</td>
 <td><input type=submit value='Install' class=sbmt></td>

</tr></table>
</form>
{else}
<h1>The script has been successfully installed!</h1>
<br><br>
<table cellspacing=0 cellpadding=1 border=0 width=400><tr><td>
Please delete the install.php file for security reasons.<br><br>

Path to the list: <a href="{$script_path}" target=_blank>{$script_path}</a><br>
Path to the Admin Panel: <a href="{$script_path}admin.php" target=_blank>{$script_path}admin.php</a><br>
Administrator login: {$form_data.admin_login}<br>
Administrator password: {$form_data.admin_password}<br><br>

Login to the admin area, go to the settings screen and specify your sitename and other information.<br>
</td></tr></table>
{/if}
{include file="footer_install.tpl"}
