{if $topmonitored}
<table border="0">
{section name=tm loop=$topmonitored}
<tr><td align="left"><font color="#999999">{$topmonitored[tm].no}.</font> <a href="{"?a=details&lid=`$topmonitored[tm].id`"|encurl}"><b>{$topmonitored[tm].sub_name}</b></a></td>
<td align="right"><font color="#009900">{$topmonitored[tm].monitored} days</font></td></tr>
{/section}
</table><br>
{else}
No data find in database<br>
{/if}
