<?php /* Smarty version 2.6.2, created on 2012-03-23 20:12:39
         compiled from ads_top728banners.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'ads_top728banners.tpl', 7, false),)), $this); ?>
<div class="banz_a">
<table width=100% border="0" cellspacing="0" cellpadding="2">
<?php if (isset($this->_sections['b1'])) unset($this->_sections['b1']);
$this->_sections['b1']['name'] = 'b1';
$this->_sections['b1']['loop'] = is_array($_loop=$this->_tpl_vars['ads']['1']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['b1']['show'] = true;
$this->_sections['b1']['max'] = $this->_sections['b1']['loop'];
$this->_sections['b1']['step'] = 1;
$this->_sections['b1']['start'] = $this->_sections['b1']['step'] > 0 ? 0 : $this->_sections['b1']['loop']-1;
if ($this->_sections['b1']['show']) {
    $this->_sections['b1']['total'] = $this->_sections['b1']['loop'];
    if ($this->_sections['b1']['total'] == 0)
        $this->_sections['b1']['show'] = false;
} else
    $this->_sections['b1']['total'] = 0;
if ($this->_sections['b1']['show']):

            for ($this->_sections['b1']['index'] = $this->_sections['b1']['start'], $this->_sections['b1']['iteration'] = 1;
                 $this->_sections['b1']['iteration'] <= $this->_sections['b1']['total'];
                 $this->_sections['b1']['index'] += $this->_sections['b1']['step'], $this->_sections['b1']['iteration']++):
$this->_sections['b1']['rownum'] = $this->_sections['b1']['iteration'];
$this->_sections['b1']['index_prev'] = $this->_sections['b1']['index'] - $this->_sections['b1']['step'];
$this->_sections['b1']['index_next'] = $this->_sections['b1']['index'] + $this->_sections['b1']['step'];
$this->_sections['b1']['first']      = ($this->_sections['b1']['iteration'] == 1);
$this->_sections['b1']['last']       = ($this->_sections['b1']['iteration'] == $this->_sections['b1']['total']);
?>
<?php if ($this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['no']): ?>
<tr class="adlight">
<td width="728" height="90" align="center" class="ad">
<a href="<?php echo ((is_array($_tmp="?a=goads&aid=1&id=".($this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['no']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" target="_blank" title="<?php echo $this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['desc']; ?>
"><?php if ($this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['format'] == 'flash'): ?><embed width="728" height="90" src="<?php echo $this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['imgurl']; ?>
"><noembed><?php echo ((is_array($_tmp="?a=goads&aid=1&id=".($this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['no']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
</noembed><?php else: ?><img src="<?php echo $this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['imgurl']; ?>
" alt="<?php echo $this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['desc']; ?>
" width="728" height="90" border="2" style="border-color:#C9C6C6"><?php endif; ?></a></td><td class="ad"><a href="<?php echo ((is_array($_tmp="?a=goads&aid=1&id=".($this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['no']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" target="_blank"><b><?php echo $this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['name']; ?>
</b></a><br><?php echo $this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['desc']; ?>
<br><font color="#666666">$<?php echo $this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['price']; ?>
/Week | Expires: <?php echo $this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['expired']; ?>
</font></td></tr>
<?php else: ?>
<tr class="adlight"><td width="730" height="92" align="center" class="ad">
<table width=728 height=90  border="0" cellspacing="1" cellpadding="0" class="adblack" style=word-break:break-all><tr><td align="center" class="adlight" style=word-break:break-all>
<div align=center><a href="<?php echo ((is_array($_tmp="?a=advertise&ad=1")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><img src="<?php echo ((is_array($_tmp="images/728.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="728" height="90" alt="Your Ad Here" border="0"></a></td></a></div></td></tr></table></td><td class="ad" style=word-break:break-all><a href="<?php echo ((is_array($_tmp="?a=advertise&ad=1")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><strong>Your Ad Here</strong></a><br>
Your Program Description<br><font color="#666666">$<?php echo $this->_tpl_vars['ads']['1'][$this->_sections['b1']['index']]['price']; ?>
/Week | Available Now!</font></td></tr>
<?php endif; ?>
<?php endfor; endif; ?>
</table>
</div>