{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">All RCB Requests History</div>
<div class="box_body">
<div style="background:gold;padding:4px 0 6px 1px;">Total User Deposited: <b style="color:green">${$deposits}</b> &nbsp; Total RCB: <b style="color:green">${$rcbs}</b> &nbsp; Total Paid RCB: <b style="color:green">${$paidrcb}</b></div><br>
{if $allrcbdata}
{section name=d loop=$allrcbdata}
<table cellspacing=0 cellpadding=0 border=0 width=100%>  
<tr><td width=50% align="left"><font color="green">{$allrcbdata[d].rdate}</font></td></tr>
</table>
<table cellspacing=0 cellpadding=0 width=100% style="border: 1px dotted #CCCCCC;">
<tr bgcolor="#EEEEEE">
<td align="center">#</td>
<td align="center">Program</td>
<td align="center">Deposit/RCB</td>
<td align="center">User</td>
<td align="center">eCurrency A/C</td>
<td align="center">Status</td>
</tr>
{section name=t loop=$allrcbdata[d].data}
<tr bgcolor={if $smarty.section.t.rownum % 2 == 0}#FFFFF2{else}#CCFF99{/if}>
<td align="center">{$allrcbdata[d].data[t].no}.</td>
<td align="center"><a href="{"?a=go&lid=`$allrcbdata[d].data[t].lid`"|encurl}" target="_blank">{$allrcbdata[d].data[t].name}</td>
<td align="center">${$allrcbdata[d].data[t].deposit}/<font color="green">${$allrcbdata[d].data[t].rcb}</font></td>
<td align="center">{$allrcbdata[d].data[t].username}</td>
<td align="center">{$allrcbdata[d].data[t].ec}({$allrcbdata[d].data[t].ecno})</td>
<td align="center">{if $allrcbdata[d].data[t].status == 0}Waiting For Check...{elseif $allrcbdata[d].data[t].status == 1}Paid{if $allrcbdata[d].data[t].batch}(batch={$allrcbdata[d].data[t].batch}){/if}{else}Declined{/if}</td>
</tr>
{/section}
</table>
<br>
{/section}
{else}
<table cellspacing=0 cellpadding=0 border=0 width=100%>  
<tr><td align="center">Currently there are no data in database</td></tr>
</table>
{/if}

{if $colpages > 1}
<center>
{if $prev_page > 0} <a href="/?a=allrcbrequestinfo&page={$prev_page}">&lt;&lt;</a> {/if}
{section name=p loop=$pages}
{if $pages[p].current == 1}
 {$pages[p].page}
{else} <a href="/?a=allrcbrequestinfo&page={$pages[p].page}">{$pages[p].page}</a> {/if}
{/section}
{if $next_page > 0} <a href="/?a=allrcbrequestinfo&page={$next_page}">&gt;&gt;</a> {/if}
</center>
{/if}

</div></div>
{include file="footer.tpl"}