<?php /* Smarty version 2.6.2, created on 2012-03-23 20:29:26
         compiled from advertise.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'advertise.tpl', 5, false),array('modifier', 'default', 'advertise.tpl', 48, false),array('modifier', 'escape', 'advertise.tpl', 51, false),)), $this); ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div class="box">
<div class="box_title" id="tba">Advertise Your Banner With Us</div>
<div class="box_body">
<script type="text/javascript" src="<?php echo ((is_array($_tmp="js/advertise.js")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"></script>
<table cellspacing=1 cellpadding=2 border=0 width=100%>
<tr><td colspan="5"><b style="color:green">We Currently Offers Banner Advertising:</b><br></td></tr>
<tr><th class="title">Ads Type</th>
<th class="title" align="center">Type</th>
<th class="title" align="center">Price / 7 days</th>
<th class="title" align="center">Available Slots</th>
<th class="title" align="center">Max Slots</th></tr>
<?php if (isset($this->_sections['ad'])) unset($this->_sections['ad']);
$this->_sections['ad']['name'] = 'ad';
$this->_sections['ad']['loop'] = is_array($_loop=$this->_tpl_vars['allads']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['ad']['show'] = true;
$this->_sections['ad']['max'] = $this->_sections['ad']['loop'];
$this->_sections['ad']['step'] = 1;
$this->_sections['ad']['start'] = $this->_sections['ad']['step'] > 0 ? 0 : $this->_sections['ad']['loop']-1;
if ($this->_sections['ad']['show']) {
    $this->_sections['ad']['total'] = $this->_sections['ad']['loop'];
    if ($this->_sections['ad']['total'] == 0)
        $this->_sections['ad']['show'] = false;
} else
    $this->_sections['ad']['total'] = 0;
if ($this->_sections['ad']['show']):

            for ($this->_sections['ad']['index'] = $this->_sections['ad']['start'], $this->_sections['ad']['iteration'] = 1;
                 $this->_sections['ad']['iteration'] <= $this->_sections['ad']['total'];
                 $this->_sections['ad']['index'] += $this->_sections['ad']['step'], $this->_sections['ad']['iteration']++):
$this->_sections['ad']['rownum'] = $this->_sections['ad']['iteration'];
$this->_sections['ad']['index_prev'] = $this->_sections['ad']['index'] - $this->_sections['ad']['step'];
$this->_sections['ad']['index_next'] = $this->_sections['ad']['index'] + $this->_sections['ad']['step'];
$this->_sections['ad']['first']      = ($this->_sections['ad']['iteration'] == 1);
$this->_sections['ad']['last']       = ($this->_sections['ad']['iteration'] == $this->_sections['ad']['total']);
?>
<tr bgcolor=<?php if ($this->_sections['ad']['rownum'] % 2 == 0): ?>#FFFFFF<?php else: ?>#F2F2F2<?php endif; ?>>
<td><b><?php echo $this->_tpl_vars['allads'][$this->_sections['ad']['index']]['name']; ?>
</b></td>
<td align="center"><?php echo $this->_tpl_vars['allads'][$this->_sections['ad']['index']]['type']; ?>
</td>
<td align="center"><font color="green"><?php if ($this->_tpl_vars['allads'][$this->_sections['ad']['index']]['minprice']): ?>$<?php echo $this->_tpl_vars['allads'][$this->_sections['ad']['index']]['minprice']; ?>
-<?php endif; ?>$<?php echo $this->_tpl_vars['allads'][$this->_sections['ad']['index']]['price']; ?>
</font></td>
<td align="center"><?php echo $this->_tpl_vars['allads'][$this->_sections['ad']['index']]['available']; ?>
</td>
<td align="center"><?php echo $this->_tpl_vars['allads'][$this->_sections['ad']['index']]['slot']; ?>
</td>
</tr>
<?php endfor; endif; ?>
<tr><td colspan="5" align="center" style="padding:15px 0 15px 0;">We accept <img src="<?php echo ((is_array($_tmp="images/LibertyReserve.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><b><?php echo $this->_tpl_vars['settings']['lracc']; ?>
</b>  
 &nbsp; <img src="<?php echo ((is_array($_tmp="images/PerfectMoney.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><b><?php echo $this->_tpl_vars['settings']['perfectmoney_acc']; ?>
</b></td></tr>
</table>
<?php if ($this->_tpl_vars['errors']): ?>
<ul style="color:red">
<?php if ($this->_tpl_vars['errors']['turing']): ?><li> Invalid turing image.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['email']): ?><li> Please enter your e-mail addresss.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['invalid_email']): ?><li> Please enter valid e-mail address.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['busy']): ?><li> Sorry, This Ad place is not available now.</li><?php endif; ?>
</ul>
<?php endif; ?>
<table cellSpacing=0 cellPadding=3 width="100%" style="border: 1px dotted #CCCCCC;">
<form name="frm" method="post" onsubmit="return validate(this)"> 
<input type=hidden name="a" value="advertise">
<input type=hidden name="action" value="preview">
<tr><td align="right"><b>Ad Type: </b></td>
<td><select name="ad_type" id="ad_type" class="inpts" onchange="change_AD(this.value);">
<?php if (isset($this->_sections['ads'])) unset($this->_sections['ads']);
$this->_sections['ads']['name'] = 'ads';
$this->_sections['ads']['loop'] = is_array($_loop=$this->_tpl_vars['allads']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['ads']['show'] = true;
$this->_sections['ads']['max'] = $this->_sections['ads']['loop'];
$this->_sections['ads']['step'] = 1;
$this->_sections['ads']['start'] = $this->_sections['ads']['step'] > 0 ? 0 : $this->_sections['ads']['loop']-1;
if ($this->_sections['ads']['show']) {
    $this->_sections['ads']['total'] = $this->_sections['ads']['loop'];
    if ($this->_sections['ads']['total'] == 0)
        $this->_sections['ads']['show'] = false;
} else
    $this->_sections['ads']['total'] = 0;
if ($this->_sections['ads']['show']):

            for ($this->_sections['ads']['index'] = $this->_sections['ads']['start'], $this->_sections['ads']['iteration'] = 1;
                 $this->_sections['ads']['iteration'] <= $this->_sections['ads']['total'];
                 $this->_sections['ads']['index'] += $this->_sections['ads']['step'], $this->_sections['ads']['iteration']++):
$this->_sections['ads']['rownum'] = $this->_sections['ads']['iteration'];
$this->_sections['ads']['index_prev'] = $this->_sections['ads']['index'] - $this->_sections['ads']['step'];
$this->_sections['ads']['index_next'] = $this->_sections['ads']['index'] + $this->_sections['ads']['step'];
$this->_sections['ads']['first']      = ($this->_sections['ads']['iteration'] == 1);
$this->_sections['ads']['last']       = ($this->_sections['ads']['iteration'] == $this->_sections['ads']['total']);
?><option value="<?php echo $this->_tpl_vars['allads'][$this->_sections['ads']['index']]['id']; ?>
"<?php if ($this->_tpl_vars['frm']['ad'] == $this->_tpl_vars['allads'][$this->_sections['ads']['index']]['id'] || $this->_tpl_vars['frm']['ad_type'] == $this->_tpl_vars['allads'][$this->_sections['ads']['index']]['id']): ?> selected<?php endif; ?>><?php echo $this->_tpl_vars['allads'][$this->_sections['ads']['index']]['name']; ?>
</option><?php endfor; endif; ?></select></td></tr>

<?php if (isset($this->_sections['x'])) unset($this->_sections['x']);
$this->_sections['x']['name'] = 'x';
$this->_sections['x']['loop'] = is_array($_loop=$this->_tpl_vars['allads']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['x']['show'] = true;
$this->_sections['x']['max'] = $this->_sections['x']['loop'];
$this->_sections['x']['step'] = 1;
$this->_sections['x']['start'] = $this->_sections['x']['step'] > 0 ? 0 : $this->_sections['x']['loop']-1;
if ($this->_sections['x']['show']) {
    $this->_sections['x']['total'] = $this->_sections['x']['loop'];
    if ($this->_sections['x']['total'] == 0)
        $this->_sections['x']['show'] = false;
} else
    $this->_sections['x']['total'] = 0;
if ($this->_sections['x']['show']):

            for ($this->_sections['x']['index'] = $this->_sections['x']['start'], $this->_sections['x']['iteration'] = 1;
                 $this->_sections['x']['iteration'] <= $this->_sections['x']['total'];
                 $this->_sections['x']['index'] += $this->_sections['x']['step'], $this->_sections['x']['iteration']++):
$this->_sections['x']['rownum'] = $this->_sections['x']['iteration'];
$this->_sections['x']['index_prev'] = $this->_sections['x']['index'] - $this->_sections['x']['step'];
$this->_sections['x']['index_next'] = $this->_sections['x']['index'] + $this->_sections['x']['step'];
$this->_sections['x']['first']      = ($this->_sections['x']['iteration'] == 1);
$this->_sections['x']['last']       = ($this->_sections['x']['iteration'] == $this->_sections['x']['total']);
 if ($this->_tpl_vars['allads'][$this->_sections['x']['index']]['type'] == 'Non-Rotating'): ?>
<tr id="pos_<?php echo $this->_tpl_vars['allads'][$this->_sections['x']['index']]['id']; ?>
"><td align="right"><b>Ad Place:</b></td><td>
<select name="position[<?php echo $this->_tpl_vars['allads'][$this->_sections['x']['index']]['id']; ?>
]" class="inpts" onchange="SetPrice();">
<?php if (isset($this->_sections['y'])) unset($this->_sections['y']);
$this->_sections['y']['name'] = 'y';
$this->_sections['y']['loop'] = is_array($_loop=$this->_tpl_vars['allads'][$this->_sections['x']['index']]['slot']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['y']['show'] = true;
$this->_sections['y']['max'] = $this->_sections['y']['loop'];
$this->_sections['y']['step'] = 1;
$this->_sections['y']['start'] = $this->_sections['y']['step'] > 0 ? 0 : $this->_sections['y']['loop']-1;
if ($this->_sections['y']['show']) {
    $this->_sections['y']['total'] = $this->_sections['y']['loop'];
    if ($this->_sections['y']['total'] == 0)
        $this->_sections['y']['show'] = false;
} else
    $this->_sections['y']['total'] = 0;
if ($this->_sections['y']['show']):

            for ($this->_sections['y']['index'] = $this->_sections['y']['start'], $this->_sections['y']['iteration'] = 1;
                 $this->_sections['y']['iteration'] <= $this->_sections['y']['total'];
                 $this->_sections['y']['index'] += $this->_sections['y']['step'], $this->_sections['y']['iteration']++):
$this->_sections['y']['rownum'] = $this->_sections['y']['iteration'];
$this->_sections['y']['index_prev'] = $this->_sections['y']['index'] - $this->_sections['y']['step'];
$this->_sections['y']['index_next'] = $this->_sections['y']['index'] + $this->_sections['y']['step'];
$this->_sections['y']['first']      = ($this->_sections['y']['iteration'] == 1);
$this->_sections['y']['last']       = ($this->_sections['y']['iteration'] == $this->_sections['y']['total']);
 if (in_array ( $this->_sections['y']['rownum'] , $this->_tpl_vars['allads'][$this->_sections['x']['index']]['sold'] )): ?><option value="Sold"><?php echo $this->_sections['y']['rownum']; ?>
</option><?php else: ?><option value="<?php echo $this->_sections['y']['rownum']; ?>
"><?php echo $this->_sections['y']['rownum']; ?>
</option><?php endif;  endfor; endif; ?></select><span id="sold_<?php echo $this->_tpl_vars['allads'][$this->_sections['x']['index']]['id']; ?>
"></span></td></tr>
<?php endif;  endfor; endif; ?>

<tr><td align="right"><b>Ad Period :</b></td>
<td><input type="text" class="inpts" onchange="SetPrice();" size="4" value="<?php echo ((is_array($_tmp=@$this->_tpl_vars['frm']['ad_time'])) ? $this->_run_mod_handler('default', true, $_tmp, 1) : smarty_modifier_default($_tmp, 1)); ?>
" name="ad_time" style="text-align:center">&nbsp;&nbsp; 
<input name="ad_time_type" type="radio" onclick="SetPrice();" value="Week" checked> &nbsp;<b>Weeks</b>&nbsp;&nbsp;&nbsp;&nbsp;<input onclick="SetPrice();" type="radio" value="Month" name="ad_time_type">&nbsp;<b>Months</b></td></tr>
<tr><td align="right"><b>Program Name :</b></td>
<td><input type="text" class="inpts" size="40" name="ad_site_name" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['ad_site_name'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
"></td></tr>
<tr><td align="right"><b>Website Url :</b></td>
<td><input type="text" class="inpts" size="45" name="ad_site_url" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['ad_site_url'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
"></td></tr>
<tr><td align="right"><b>Banner Url :</b></td>
<td><input type="text" class="inpts" size="45" name="ad_banner_url" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['ad_banner_url'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
"> <span id="bsize"></span></td></tr>
<tr><td align="right"><b>Program Description :</b></td>
<td><textarea class="inpts" name="ad_desc" rows="5" cols="42"><?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['ad_desc'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
</textarea></td></tr>
<tr><td align="right"><b>Advertiser Email :</b></td>
<td><input type=text class="inpts" size="45" name="ader_mail" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['ader_mail'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
"></td></tr>
<tr><td align="right"><b>Payment Options:</b></td>
<td><select name="processor" class="inpts">
<option value="LibertyReserve">LibertyReserve</option>
<option value="PerfectMoney">PerfectMoney</option>
</select></td></tr>
<tr><td align="right"><b>Price :</b></td><td><b>$&nbsp;<span id="total_price"></span> (USD)</b></td></tr>
<input type="hidden" name="total_prices">
<?php if ($this->_tpl_vars['settings']['use_turing']): ?>
<tr>
  <td align="right"><img src="<?php echo ((is_array($_tmp="?a=turing&".($this->_tpl_vars['sesname'])."=".($this->_tpl_vars['sesid'])."&r=".($this->_tpl_vars['rand']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="turing code"></td>
  <td><input type=text name="turing" maxlength="6" size="10" class="inpts"></td>
</tr>
<?php endif; ?>
<tr><td>&nbsp;</td><td><input class="sbmt" type="submit" value="Preview"></td></tr>
<tr><td>&nbsp;</td></tr></form></table></td></tr>
<tr><td align=center><div id="show_ad_site"></div></td></tr>
</table>
</div></div>
<script type="text/javascript">
<?php echo '
function SetPrice(){
'; ?>

var adstep = new Array();
<?php if (isset($this->_sections['stp'])) unset($this->_sections['stp']);
$this->_sections['stp']['name'] = 'stp';
$this->_sections['stp']['loop'] = is_array($_loop=$this->_tpl_vars['allads']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['stp']['show'] = true;
$this->_sections['stp']['max'] = $this->_sections['stp']['loop'];
$this->_sections['stp']['step'] = 1;
$this->_sections['stp']['start'] = $this->_sections['stp']['step'] > 0 ? 0 : $this->_sections['stp']['loop']-1;
if ($this->_sections['stp']['show']) {
    $this->_sections['stp']['total'] = $this->_sections['stp']['loop'];
    if ($this->_sections['stp']['total'] == 0)
        $this->_sections['stp']['show'] = false;
} else
    $this->_sections['stp']['total'] = 0;
if ($this->_sections['stp']['show']):

            for ($this->_sections['stp']['index'] = $this->_sections['stp']['start'], $this->_sections['stp']['iteration'] = 1;
                 $this->_sections['stp']['iteration'] <= $this->_sections['stp']['total'];
                 $this->_sections['stp']['index'] += $this->_sections['stp']['step'], $this->_sections['stp']['iteration']++):
$this->_sections['stp']['rownum'] = $this->_sections['stp']['iteration'];
$this->_sections['stp']['index_prev'] = $this->_sections['stp']['index'] - $this->_sections['stp']['step'];
$this->_sections['stp']['index_next'] = $this->_sections['stp']['index'] + $this->_sections['stp']['step'];
$this->_sections['stp']['first']      = ($this->_sections['stp']['iteration'] == 1);
$this->_sections['stp']['last']       = ($this->_sections['stp']['iteration'] == $this->_sections['stp']['total']);
?>
adstep[<?php echo $this->_tpl_vars['allads'][$this->_sections['stp']['index']]['id']; ?>
] = '<?php echo $this->_tpl_vars['allads'][$this->_sections['stp']['index']]['step']; ?>
';
<?php endfor; endif; ?>
var adfee = new Array();
<?php if (isset($this->_sections['fe'])) unset($this->_sections['fe']);
$this->_sections['fe']['name'] = 'fe';
$this->_sections['fe']['loop'] = is_array($_loop=$this->_tpl_vars['allads']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['fe']['show'] = true;
$this->_sections['fe']['max'] = $this->_sections['fe']['loop'];
$this->_sections['fe']['step'] = 1;
$this->_sections['fe']['start'] = $this->_sections['fe']['step'] > 0 ? 0 : $this->_sections['fe']['loop']-1;
if ($this->_sections['fe']['show']) {
    $this->_sections['fe']['total'] = $this->_sections['fe']['loop'];
    if ($this->_sections['fe']['total'] == 0)
        $this->_sections['fe']['show'] = false;
} else
    $this->_sections['fe']['total'] = 0;
if ($this->_sections['fe']['show']):

            for ($this->_sections['fe']['index'] = $this->_sections['fe']['start'], $this->_sections['fe']['iteration'] = 1;
                 $this->_sections['fe']['iteration'] <= $this->_sections['fe']['total'];
                 $this->_sections['fe']['index'] += $this->_sections['fe']['step'], $this->_sections['fe']['iteration']++):
$this->_sections['fe']['rownum'] = $this->_sections['fe']['iteration'];
$this->_sections['fe']['index_prev'] = $this->_sections['fe']['index'] - $this->_sections['fe']['step'];
$this->_sections['fe']['index_next'] = $this->_sections['fe']['index'] + $this->_sections['fe']['step'];
$this->_sections['fe']['first']      = ($this->_sections['fe']['iteration'] == 1);
$this->_sections['fe']['last']       = ($this->_sections['fe']['iteration'] == $this->_sections['fe']['total']);
?>
adfee[<?php echo $this->_tpl_vars['allads'][$this->_sections['fe']['index']]['id']; ?>
] = '<?php echo $this->_tpl_vars['allads'][$this->_sections['fe']['index']]['price']; ?>
';
<?php endfor; endif; ?>
<?php echo '
var adtime = document.frm.ad_time;
var adtype = document.frm.ad_time_type;
var adtp = document.frm.ad_type.value;
if (isNaN(adtime.value)) {alert("Please Enter Numeric Value for Ad Time.");	
adtime.value=1;	 adtime.focus(); return (false);
}
'; ?>


<?php if (isset($this->_sections['cl'])) unset($this->_sections['cl']);
$this->_sections['cl']['name'] = 'cl';
$this->_sections['cl']['loop'] = is_array($_loop=$this->_tpl_vars['allads']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['cl']['show'] = true;
$this->_sections['cl']['max'] = $this->_sections['cl']['loop'];
$this->_sections['cl']['step'] = 1;
$this->_sections['cl']['start'] = $this->_sections['cl']['step'] > 0 ? 0 : $this->_sections['cl']['loop']-1;
if ($this->_sections['cl']['show']) {
    $this->_sections['cl']['total'] = $this->_sections['cl']['loop'];
    if ($this->_sections['cl']['total'] == 0)
        $this->_sections['cl']['show'] = false;
} else
    $this->_sections['cl']['total'] = 0;
if ($this->_sections['cl']['show']):

            for ($this->_sections['cl']['index'] = $this->_sections['cl']['start'], $this->_sections['cl']['iteration'] = 1;
                 $this->_sections['cl']['iteration'] <= $this->_sections['cl']['total'];
                 $this->_sections['cl']['index'] += $this->_sections['cl']['step'], $this->_sections['cl']['iteration']++):
$this->_sections['cl']['rownum'] = $this->_sections['cl']['iteration'];
$this->_sections['cl']['index_prev'] = $this->_sections['cl']['index'] - $this->_sections['cl']['step'];
$this->_sections['cl']['index_next'] = $this->_sections['cl']['index'] + $this->_sections['cl']['step'];
$this->_sections['cl']['first']      = ($this->_sections['cl']['iteration'] == 1);
$this->_sections['cl']['last']       = ($this->_sections['cl']['iteration'] == $this->_sections['cl']['total']);
?>
var aid = '<?php echo $this->_tpl_vars['allads'][$this->_sections['cl']['index']]['id']; ?>
';
<?php echo '
if(adtp == aid){
if(adtype[0].checked) { 
var eledf = document.frm.elements["position["+aid+"]"];
if (eledf) 
 { 
  var mypos = eledf.value;
  if (mypos == \'Sold\'){
document.getElementById("sold_"+aid).innerHTML = \'&nbsp; <font color="red">Sold</font>\';
mypos = eledf.options[eledf.selectedIndex].text;
  } else { document.getElementById("sold_"+aid).innerHTML = \'&nbsp; <font color="green">Available</font>\'; }
  jsprice = parseFloat(adtime.value*(adfee[aid]-(mypos-1)*adstep[aid]));
 }
  else { jsprice = parseFloat(adtime.value*adfee[aid]); }
 }
else if(adtype[1].checked) {
var eledf = document.frm.elements["position["+aid+"]"];
if (eledf)
 { 
  var mypos = eledf.value;
  if (mypos == \'Sold\'){
document.getElementById("sold_"+aid).innerHTML = \'&nbsp;  <font color="red">Sold</font>\';
mypos = eledf.options[eledf.selectedIndex].text;
  } else { document.getElementById("sold_"+aid).innerHTML = \'&nbsp; <font color="green">Available</font>\'; }
  jsprice = parseFloat(adtime.value*4*(adfee[aid]-(mypos-1)*adstep[aid]));
 }
  else { jsprice = parseFloat(adtime.value*4*adfee[aid]);  }
 }

}
'; ?>

<?php endfor; endif; ?>
<?php echo '
document.getElementById("total_price").innerHTML = jsprice.toFixed(2);
document.frm.total_prices.value=jsprice.toFixed(2);
}
'; ?>

change_AD(<?php echo $this->_tpl_vars['frm']['ad_type']; ?>
);
</script>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>