<?php /* Smarty version 2.6.2, created on 2012-03-23 21:00:56
         compiled from partners.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'partners.tpl', 21, false),)), $this); ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>

<div class="box">
<div class="box_title" id="tba">Our Partners</div>
<div class="box_body">
<table width="100%" border="0" cellspacing="2" cellpadding="0">

<?php if ($this->_tpl_vars['partners']): ?>
<?php if (isset($this->_sections['pa'])) unset($this->_sections['pa']);
$this->_sections['pa']['name'] = 'pa';
$this->_sections['pa']['loop'] = is_array($_loop=$this->_tpl_vars['partners']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['pa']['show'] = true;
$this->_sections['pa']['max'] = $this->_sections['pa']['loop'];
$this->_sections['pa']['step'] = 1;
$this->_sections['pa']['start'] = $this->_sections['pa']['step'] > 0 ? 0 : $this->_sections['pa']['loop']-1;
if ($this->_sections['pa']['show']) {
    $this->_sections['pa']['total'] = $this->_sections['pa']['loop'];
    if ($this->_sections['pa']['total'] == 0)
        $this->_sections['pa']['show'] = false;
} else
    $this->_sections['pa']['total'] = 0;
if ($this->_sections['pa']['show']):

            for ($this->_sections['pa']['index'] = $this->_sections['pa']['start'], $this->_sections['pa']['iteration'] = 1;
                 $this->_sections['pa']['iteration'] <= $this->_sections['pa']['total'];
                 $this->_sections['pa']['index'] += $this->_sections['pa']['step'], $this->_sections['pa']['iteration']++):
$this->_sections['pa']['rownum'] = $this->_sections['pa']['iteration'];
$this->_sections['pa']['index_prev'] = $this->_sections['pa']['index'] - $this->_sections['pa']['step'];
$this->_sections['pa']['index_next'] = $this->_sections['pa']['index'] + $this->_sections['pa']['step'];
$this->_sections['pa']['first']      = ($this->_sections['pa']['iteration'] == 1);
$this->_sections['pa']['last']       = ($this->_sections['pa']['iteration'] == $this->_sections['pa']['total']);
?>
<?php if ($this->_sections['pa']['first'] == 1): ?><tr align="center" valign="middle"><?php endif; ?>
<td width="25%"><a href="<?php echo $this->_tpl_vars['partners'][$this->_sections['pa']['index']]['url']; ?>
" target="_blank"><?php if ($this->_tpl_vars['partners'][$this->_sections['pa']['index']]['logo']): ?><img src="<?php echo $this->_tpl_vars['partners'][$this->_sections['pa']['index']]['logo']; ?>
" border="0" alt="<?php echo $this->_tpl_vars['partners'][$this->_sections['pa']['index']]['name']; ?>
"><?php else:  echo $this->_tpl_vars['partners'][$this->_sections['pa']['index']]['name'];  endif; ?></a></td>
<?php if (( $this->_sections['pa']['index']+1 ) % 4 == 0): ?></tr><?php if (! $this->_sections['pa']['last']): ?><tr align="center" valign="middle"><?php endif;  endif;  if (( $this->_sections['pa']['index']+1 ) % 4 != 0 && $this->_sections['pa']['last']): ?></tr><?php endif; ?>
<?php endfor; endif; ?>
<?php endif; ?>

<tr><td colspan="4">&nbsp;</td></tr>
<tr><th class="title" colspan="4"><a name=logo></a>Links Exchange</th></tr>
<tr>
 <td colspan="4" align="center">
   <p><br>
     You can place our logo on your site, and send us <a href="<?php echo ((is_array($_tmp="?a=support")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><font color="#FF0000"><strong><u>(Support)</u></strong></font></a> your site url and your html code: <br><br>
     <textarea name="logo_txt" wrap="physical" cols="80" rows="4" class="inpts" onmouseover="this.select()"><a href="<?php echo $this->_tpl_vars['settings']['site_url']; ?>
" target="_blank"><img src="<?php echo ((is_array($_tmp=($this->_tpl_vars['settings']['site_logo_url']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="<?php echo $this->_tpl_vars['settings']['site_name']; ?>
 - Best Hyips Monitoring and Rating" width="120" height="60" border="0"></a></textarea>
   </p>
   <p><img src="<?php echo ((is_array($_tmp=($this->_tpl_vars['settings']['site_logo_url']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="<?php echo $this->_tpl_vars['settings']['site_name']; ?>
 - Best Hyips Monitoring and Rating" width="120" height="60" border="0"/><br>
         <br>
     </p>
</td>
</tr>
 </table></div>
</div>


<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
