<?php /* Smarty version 2.6.2, created on 2012-05-23 22:19:06
         compiled from user_fp.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'user_fp.tpl', 22, false),)), $this); ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>

<?php echo '
<script type="text/javascript">
function checkform() {
  if (document.forgotform.email.value == \'\') {
    alert("Please type your username or email!");
    document.forgotform.email.focus();
    return false;
  }
  return true;
}
</script>
'; ?>

<div class="box">
<div class="box_title" id="tba">Password Remind</div>
<div class="box_body">

<?php if ($this->_tpl_vars['frm']['display'] == 'confirmation_sent'): ?>
<div style="color:green">Confirmation link was sent to your e-mail address. Please follow the link to reset your password.</div>
<?php elseif ($this->_tpl_vars['frm']['display'] == 'password_sent'): ?>
<div style="color:green">Your login info was sent to your e-mail. You can <a href="<?php echo ((is_array($_tmp="?a=login")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">login</a> now.</div>
<?php elseif ($this->_tpl_vars['frm']['display'] == 'invalid_code'): ?>
<div style="color:red">The code you have provided is invalid. It means you have used broken link or password was already sent to you.</div>
<?php else: ?>

<?php if ($this->_tpl_vars['errors']): ?>
<ul style="color:red">
<?php if ($this->_tpl_vars['errors']['turing']): ?><li> Invalid turing image.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['no_input']): ?><li> Please enter your username or e-mail addresss.</li><?php endif; ?>
</ul>
<?php endif; ?>


<form method="post" name="forgotform" onsubmit="return checkform()" action="">
<input type=hidden name=a value="forgot_password">
<input type=hidden name=action value="forgot_password">
<table width="100%" border="0" cellspacing="1" cellpadding="3">
<tr>
 <td>Username or E-mail:</td>
 <td><input type=text name="email" class="inpts" size="45"></td>
</tr>
<?php if ($this->_tpl_vars['settings']['use_turing']): ?>
<tr>
  <td><img src="<?php echo ((is_array($_tmp="?a=turing&".($this->_tpl_vars['sesname'])."=".($this->_tpl_vars['sesid'])."&r=".($this->_tpl_vars['rand']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="turing code"></td>
  <td><input type=text name="turing" maxlength="6" size="10" class="inpts"></td>
</tr>
<?php endif; ?>
<tr>
 <th></th>
 <td><input type=submit value="Remind" class="sbmt"></td>
</tr>
</table>
</form>
<?php endif; ?>
</div></div>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
