var timer_hide1, timer_show1;

var bannersad_width1 = '120';
var bannersad_height1 = '120';

if (typeof document.compatMode!='undefined' && document.compatMode!='BackCompat') {
	banners_css21 = "_top:expression(document.documentElement.scrollTop+document.documentElement.clientHeight-this.clientHeight);_right:expression(document.documentElement.scrollRight + document.documentElement.clientWidth - offsetWidth);";
} else {
	banners_css21 = "_top:expression(document.body.scrollTop+document.body.clientHeight-this.clientHeight);_right:expression(document.body.scrollRight + document.body.clientWidth - offsetWidth);";
}

var	banners_css1  = '#bannersad1 {position:fixed;';
	banners_css1 += '_position:absolute;';
	banners_css1 += 'bottom:0px;';
	banners_css1 += 'left:0px;';
	banners_css1 += banners_css21;
	banners_css1 += '}';

document.write('<style type="text/css">'+banners_css1+'</style>');
function left_ads(ix,id,ia,it)
{
    var cot_tl_myLocation=location.host;
    var cot_tl_miniBaseURL='';
    var cot_tl_bigBaseURL='';

    document.write('<div id="bannersad1">');
   document.write('<a onfocus="this.blur()" href="' +ix+ '" target="_blank"><img object.style.filter="progid:DXImageTransform.Microsoft.AlphaImageLoader(sProperties)" border=0 hspace=0 '+'vspace=0 src="' +id+ '" alt="' +ia+ '"');
    document.write('</a>');
    document.write('</div>');
}