{include file="header.tpl"}

<div class="box">
<div class="box_title" id="tba">Our Partners</div>
<div class="box_body">
<table width="100%" border="0" cellspacing="2" cellpadding="0">

{if $partners}
{section name=pa loop=$partners}
{if $smarty.section.pa.first == 1}<tr align="center" valign="middle">{/if}
<td width="25%"><a href="{$partners[pa].url}" target="_blank">{if $partners[pa].logo}<img src="{$partners[pa].logo}" border="0" alt="{$partners[pa].name}">{else}{$partners[pa].name}{/if}</a></td>
{if ($smarty.section.pa.index+1) % 4 == 0}</tr>{if !$smarty.section.pa.last}<tr align="center" valign="middle">{/if}{/if}{if ($smarty.section.pa.index+1) % 4 != 0 && $smarty.section.pa.last}</tr>{/if}
{/section}
{/if}

<tr><td colspan="4">&nbsp;</td></tr>
<tr><th class="title" colspan="4"><a name=logo></a>Links Exchange</th></tr>
<tr>
 <td colspan="4" align="center">
   <p><br>
     You can place our logo on your site, and send us <a href="{"?a=support"|encurl}"><font color="#FF0000"><strong><u>(Support)</u></strong></font></a> your site url and your html code: <br><br>
     <textarea name="logo_txt" wrap="physical" cols="80" rows="4" class="inpts" onmouseover="this.select()"><a href="{$settings.site_url}" target="_blank"><img src="{"`$settings.site_logo_url`"|encurl}" alt="{$settings.site_name} - Best Hyips Monitoring and Rating" width="120" height="60" border="0"></a></textarea>
   </p>
   <p><img src="{"`$settings.site_logo_url`"|encurl}" alt="{$settings.site_name} - Best Hyips Monitoring and Rating" width="120" height="60" border="0"/><br>
         <br>
     </p>
</td>
</tr>
 </table></div>
</div>


{include file="footer.tpl"}
