{if $latestvotes}
{section name=lv loop=$latestvotes}
<img src="{"images/c/`$latestvotes[lv].flag`.gif"|encurl}" align="absmiddle" alt="{$latestvotes[lv].flag}" title="{$latestvotes[lv].flag}" style="cursor:help;"> <img src="{"images/r`$latestvotes[lv].vote`.gif"|encurl}" align="absmiddle" alt="{$latestvotes[lv].comment}" title="{$latestvotes[lv].comment}" style="cursor:help;"> <a href="{"?a=details&lid=`$latestvotes[lv].id`"|encurl}"><b>{$latestvotes[lv].sub_name}</b></a><br>
{/section}<br>
{else}No data find in database
{/if}






