<?php /* Smarty version 2.6.2, created on 2012-05-23 20:10:53
         compiled from ads_exclusive_banners.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'ads_exclusive_banners.tpl', 4, false),)), $this); ?>
<div class="banz_b">
<?php if (isset($this->_sections['b3'])) unset($this->_sections['b3']);
$this->_sections['b3']['name'] = 'b3';
$this->_sections['b3']['loop'] = is_array($_loop=$this->_tpl_vars['ads']['3']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['b3']['show'] = true;
$this->_sections['b3']['max'] = $this->_sections['b3']['loop'];
$this->_sections['b3']['step'] = 1;
$this->_sections['b3']['start'] = $this->_sections['b3']['step'] > 0 ? 0 : $this->_sections['b3']['loop']-1;
if ($this->_sections['b3']['show']) {
    $this->_sections['b3']['total'] = $this->_sections['b3']['loop'];
    if ($this->_sections['b3']['total'] == 0)
        $this->_sections['b3']['show'] = false;
} else
    $this->_sections['b3']['total'] = 0;
if ($this->_sections['b3']['show']):

            for ($this->_sections['b3']['index'] = $this->_sections['b3']['start'], $this->_sections['b3']['iteration'] = 1;
                 $this->_sections['b3']['iteration'] <= $this->_sections['b3']['total'];
                 $this->_sections['b3']['index'] += $this->_sections['b3']['step'], $this->_sections['b3']['iteration']++):
$this->_sections['b3']['rownum'] = $this->_sections['b3']['iteration'];
$this->_sections['b3']['index_prev'] = $this->_sections['b3']['index'] - $this->_sections['b3']['step'];
$this->_sections['b3']['index_next'] = $this->_sections['b3']['index'] + $this->_sections['b3']['step'];
$this->_sections['b3']['first']      = ($this->_sections['b3']['iteration'] == 1);
$this->_sections['b3']['last']       = ($this->_sections['b3']['iteration'] == $this->_sections['b3']['total']);
?>
<?php if ($this->_tpl_vars['ads']['3'][$this->_sections['b3']['index']]['no']): ?>
<a href="<?php echo ((is_array($_tmp="?a=goads&aid=3&id=".($this->_tpl_vars['ads']['3'][$this->_sections['b3']['index']]['no']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" target="_blank" title="<?php echo $this->_tpl_vars['ads']['3'][$this->_sections['b3']['index']]['desc']; ?>
"><?php if ($this->_tpl_vars['ads']['3'][$this->_sections['b3']['index']]['format'] == 'flash'): ?><embed width="468" height="60" src="<?php echo $this->_tpl_vars['ads']['3'][$this->_sections['b3']['index']]['imgurl']; ?>
"><noembed><?php echo ((is_array($_tmp="?a=goads&aid=3&id=".($this->_tpl_vars['ads']['3'][$this->_sections['b3']['index']]['no']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
</noembed><?php else: ?><img src="<?php echo $this->_tpl_vars['ads']['3'][$this->_sections['b3']['index']]['imgurl']; ?>
" width="468" height="60" alt="<?php echo $this->_tpl_vars['ads']['3'][$this->_sections['b3']['index']]['desc']; ?>
" border="0"><?php endif; ?></a><br><a href="<?php echo ((is_array($_tmp="?a=advertise&ad=3")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">Advertise your banner here</a> | Expires: <?php echo $this->_tpl_vars['ads']['3'][$this->_sections['b3']['index']]['expired']; ?>

<?php else: ?>
<a href="<?php echo ((is_array($_tmp="?a=advertise&ad=3")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" title="Advertise your banner here."><img src="<?php echo ((is_array($_tmp="images/468.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="468" height="60" alt="Advertise your banner here." border="0"></a><br><a href="<?php echo ((is_array($_tmp="?a=advertise&ad=3")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">Advertise your banner here</a> | Available Now!</font>
<?php endif; ?><br>
<?php endfor; endif; ?>
