<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8895-1">
<meta name="keywords" content="hyip monitor, listing, rating, polling, listings">
<title>{$settings.site_name} - HYIP Monitor Site.</title>
<link href="{"style.css"|encurl}" rel="stylesheet" type="text/css">
<script type="text/javascript" src="{"js/main.js"|encurl}"></script>
</head>
<body>
<div style="background:#FFFFFF;padding:0px;border:1px solid #AAAAAA;visibility:hidden;z-index:1000;position:absolute;" id="divPic"></div>
<center>
<div class="wall">
<div class="topz">
<table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td width="435"><img src="{"images/toplogo.png"|encurl}" width="435" height="101"></td>
<td align="center">{if !$settings.hidehn0}{include file="ads_topbanners.tpl"}{/if}</td></tr>
</table>
</div>
<div class="menuz">
<a href="{$settings.site_url}" class="menulink">Home</a>
<span onmouseover="getElementById('Rl').style.visibility='visible';" onmouseout="getElementById('Rl').style.visibility='hidden';"><a href="{"?a=home"|encurl}" class="menulink">Listings</a>
  <ul id="Rl" onmouseout="getElementById('Rl').style.visibility='hidden'">
    <li><a href="{"?a=new"|encurl}" class="submenulink">New Listing</a></li>
    {section name=g loop=$groups_nav}
   <li><a href="{"?type=`$groups_nav[g].id`"|encurl}" class="submenulink">{$groups_nav[g].nav_name}</a></li>
   {/section}</ul></span>	
<a href="{"?a=news"|encurl}" class="menulink">News</a>	  
<a href="{"?a=addprogram"|encurl}" class="menulink">Add Program</a>
<a href="{"?a=advertise"|encurl}" class="menulink">Advertise</a>
<span onmouseover="getElementById('Rr').style.visibility='visible';" onmouseout="getElementById('Rr').style.visibility='hidden';"><a href="{"?a=allrcblist"|encurl}" class="menulink">RefBacks</a>
  <ul id="Rr" onmouseout="getElementById('Rr').style.visibility='hidden'">
    <li><a href="{"?a=allrcblist"|encurl}" class="submenulink">All RCB Programs</a></li>
    <li><a href="{"?a=allrcbrequest"|encurl}" class="submenulink">All RCB Requests</a></li>
</ul></span>	
<a href="{"?a=directory"|encurl}" class="menulink">Directory</a>
<a href="{"?a=partners"|encurl}" class="menulink">Partners</a>
<a href="{"?a=support"|encurl}" class="menulink">Support</a>
<span class="search">
  <form action="{"?"|encurl}"><input type="text" name="search" value="{$frm.search|escape:html}"><input type="submit" value="Search"></form>
 </span>
</div>
<div style="padding-top: 3px;background-color:#154873;"></div>
<div class="bodyz">
{if !$settings.hidehn1}{include file="ads_top728banners.tpl"}{/if}
<div class="mainz">
<table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr><td valign="top" class="leftbar">
{include file="login_box.tpl"}
{if !$settings.hidehn7}{include file="ads_side125_banners.tpl"}{/if}
{if $settings.support_box}{include file="onlinesupport_box.tpl"}{/if}
{if $settings.languages_box}{include file="languages_box.tpl"}{/if}
{if !$settings.hidehn8}{include file="ads_side600_banners.tpl"}{/if}
{if $settings.newlistings_box && $frm.a != 'new'}{include file="newlistings_box.tpl"}{/if}
{if $settings.subscribe_box}{include file="subscribe_box.tpl"}{/if}
{if $settings.toprcb_box}{include file="toprcb_box.tpl"}{/if}	
{include file="monitorstats_box.tpl"}
{if $settings.news_box && $frm.a != 'news'}{include file="news_box.tpl"}{/if}	
{if $settings.logo_box}{include file="logo_box.tpl"}{/if}				   
{if $settings.paysystems_box}{include file="paysystems_box.tpl"}{/if}
{if $settings.partners_box}{include file="partners_box.tpl"}{/if}
</td>
    <td class="mspace"><img src="{"images/spacer.gif"|encurl}" width="1" height="1" /></td>
    <td valign="top" class="mainbar">{if !$settings.hidehn2}{include file="ads_headerbanners.tpl"}{/if}		
