<div class="banz_a">
<table width=100% border="0" cellspacing="0" cellpadding="2">
{section name=b1 loop=$ads.1}
{if $ads.1[b1].no}
<tr class="adlight">
<td width="728" height="90" align="center" class="ad">
<a href="{"?a=goads&aid=1&id=`$ads.1[b1].no`"|encurl}" target="_blank" title="{$ads.1[b1].desc}">{if $ads.1[b1].format == 'flash'}<embed width="728" height="90" src="{$ads.1[b1].imgurl}"><noembed>{"?a=goads&aid=1&id=`$ads.1[b1].no`"|encurl}</noembed>{else}<img src="{$ads.1[b1].imgurl}" alt="{$ads.1[b1].desc}" width="728" height="90" border="2" style="border-color:#C9C6C6">{/if}</a></td><td class="ad"><a href="{"?a=goads&aid=1&id=`$ads.1[b1].no`"|encurl}" target="_blank"><b>{$ads.1[b1].name}</b></a><br>{$ads.1[b1].desc}<br><font color="#666666">${$ads.1[b1].price}/Week | Expires: {$ads.1[b1].expired}</font></td></tr>
{else}
<tr class="adlight"><td width="730" height="92" align="center" class="ad">
<table width=728 height=90  border="0" cellspacing="1" cellpadding="0" class="adblack" style=word-break:break-all><tr><td align="center" class="adlight" style=word-break:break-all>
<div align=center><a href="{"?a=advertise&ad=1"|encurl}"><img src="{"images/728.gif"|encurl}" width="728" height="90" alt="Your Ad Here" border="0"></a></td></a></div></td></tr></table></td><td class="ad" style=word-break:break-all><a href="{"?a=advertise&ad=1"|encurl}"><strong>Your Ad Here</strong></a><br>
Your Program Description<br><font color="#666666">${$ads.1[b1].price}/Week | Available Now!</font></td></tr>
{/if}
{/section}
</table>
</div>