<table cellspacing=1 cellpadding=2 border=0 width="100%">
<tr><td><b style="color:red">Report scam</b></td></tr>
<tr><td>
{if $errors}
<ul style="color:red">
{if $errors.turing}<li> Invalid turing image.</li>{/if}
{if $errors.email}<li> Please enter your e-mail addresss.</li>{/if}
{if $errors.invalid_email}<li> Please enter valid e-mail address.</li>{/if}
</ul>
{elseif $frm.display == 'sent'}
<div style="color:green">Thank you. Your report has been sent to administrator.</div>
<br><br>
{/if}
</td></tr>
</table>

<form method="post" name="reportscam">
<input type="hidden" name="a" value="details">
<input type=hidden name="aj" value="report_scam">
<input type=hidden name="action" value="send">
<input type=hidden name="lid" value="{$listing.id}">
<table cellspacing=1 cellpadding=2 border=0 width="100%">
<tr>
 <td>Your E-mail</td>
 <td><input type="text" name="email" value="{$frm.email|default:$userinfo.email|escape:html}" class="inpts" size="45"></td>
</tr>
<tr>
 <td>Report</td>
 <td><textarea name="report" cols="50" rows="4" class="inpts">{$frm.report|escape:html}</textarea></td>
</tr>
{if $settings.use_turing}
<tr>
  <td><img src="{"?a=turing&`$sesname`=`$sesid`&r=`$rand`"|encurl}" alt="turing code"></td>
  <td><input type="text" name="turing" maxlength=6 size="10" class="inpts"></td>
</tr>
{/if}
<tr>
 <td></td>
 <td><input type="submit" value="Submit" class="sbmt"></td>
</tr>
</form>
</table>
