
var Ovr2='';

if (typeof document.compatMode!='undefined'&&document.compatMode!='BackCompat') 
{
    cot_t1_DOCtp="_top:expression(document.documentElement.scrollTop+document.documentElement.clientHeight-this.clientHeight);_left:expression(document.documentElement.scrollLeft + document.documentElement.clientWidth - offsetWidth);}";
} 
else 
{
    cot_t1_DOCtp="_top:expression(document.body.scrollTop+document.body.clientHeight-this.clientHeight);_left:expression(document.body.scrollLeft + document.body.clientWidth - offsetWidth);}";
}
if(typeof document.compatMode!='undefined'&&document.compatMode!='BackCompat')
{
		cot_t1_DOCtp2="_top:expression(document.documentElement.scrollTop-20+document.documentElement.clientHeight-this.clientHeight);}";
}
else
{
		cot_t1_DOCtp2="_top:expression(document.body.scrollTop-20+document.body.clientHeight-this.clientHeight);}";
}
    
var cot_bgf0=(window.location.protocol.toLowerCase()=="https:") ? "pix.gif": "pix.gif";

var cot_tl_bodyCSS='* html {background:url('+cot_bgf0+') fixed;background-repeat: repeat;background-position: right bottom;}';
var cot_tl_fixedCSS='#cot_tl_fixed{position:fixed;';
var cot_tl_fixedCSS=cot_tl_fixedCSS+'_position:absolute;';
var cot_tl_fixedCSS=cot_tl_fixedCSS+'bottom:5px;';
var cot_tl_fixedCSS=cot_tl_fixedCSS+'right:5px;';
var cot_tl_fixedCSS=cot_tl_fixedCSS+'clip:rect(0 125 125 0);';
var cot_tl_fixedCSS=cot_tl_fixedCSS+cot_t1_DOCtp;
var cot_tl_popCSS='#cot_tl_pop {background-color: transparent;';
var cot_tl_popCSS=cot_tl_popCSS+'position:fixed;';
var cot_tl_popCSS=cot_tl_popCSS+'_position:absolute;';
var cot_tl_popCSS=cot_tl_popCSS+'height: 200px;';
var cot_tl_popCSS=cot_tl_popCSS+'width: 125px;';
var cot_tl_popCSS=cot_tl_popCSS+'right: 100px;';
var cot_tl_popCSS=cot_tl_popCSS+'bottom: 1px;';
var cot_tl_popCSS=cot_tl_popCSS+'overflow: hidden;';
var cot_tl_popCSS=cot_tl_popCSS+'visibility: hidden;';
var cot_tl_popCSS=cot_tl_popCSS+'z-index: 100;';
var cot_tl_popCSS=cot_tl_popCSS+cot_t1_DOCtp2;

document.write('<style type="text/css">'+cot_tl_bodyCSS+cot_tl_fixedCSS+cot_tl_popCSS+'</style>');

function right_ads(ix,id,ia,it)
{
    var cot_tl_myLocation=location.host;
    var cot_tl_miniBaseURL='';
    var cot_tl_bigBaseURL='';

    document.write('<div id="cot_tl_fixed">');

    
    var data, p;
    var agt=navigator.userAgent.toLowerCase();
    p='http';
    if((location.href.substr(0,6)=='https:')||(location.href.substr(0,6)=='HTTPS:')) {p='https';} data = '&r=' + escape(document.referrer) + '&n=' + escape(navigator.userAgent) + '&p=' + escape(navigator.userAgent)
    if(navigator.userAgent.substring(0,1)>'3') {data = data + '&sd=' + screen.colorDepth + '&sw=' + escape(screen.width+ 'x'+screen.height)};
    
  document.write('<a onfocus="this.blur()" href="' +ix+ '" target="_blank"><img object.style.filter="progid:DXImageTransform.Microsoft.AlphaImageLoader(sProperties)" border=0 hspace=0 '+'vspace=0 src="' +id+ '" alt="' +ia+ '"');
    document.write('</a>');
    document.write('</div>');
}