<div class="box">
<div class="box_title">MONITOR STATISTICS</div>
<div class="box_body">
{if $settings.topprofitable_box}
<b><a href="#" onclick="GetData('info','troi','','mstROI');return false;">TOP {if $settings.topprofitable_count}{$settings.topprofitable_count}{else}10{/if} PROFITABLE</a></b><div style="padding-top:6px;" id="mstROI"></div>
{/if}

{if $settings.topmonitored_box}
<b><a href="#" onclick="GetData('info','tmonitors','','mstMT');return false;">TOP {if $settings.topmonitored_count}{$settings.topmonitored_count}{else}10{/if} MONITORED</a></b><div style="padding-top:6px;" id="mstMT"></div>
{/if}

{if $settings.latestpayout_box}
<b><a href="#" onclick="GetData('info','lpayouts','','mstPT');return false;">LATEST PAYOUTS</a></b><div style="padding-top:6px;" id="mstPT"></div>
{/if}

{if $settings.latestvote_box}
<b><a href="#" onclick="GetData('info','lvotes','','mstVT');return false;">LATEST VOTES</a></b><div style="padding-top:6px;" id="mstVT"></div>
{/if}

{if $settings.latestscam_box}
<b><a href="#" onclick="GetData('info','lscams','','mstSM');return false;">LATEST SCAMS</a></b><div style="padding-top:6px;" id="mstSM"></div>
{/if}
</div>
</div>
