<table cellspacing=0 cellpadding=2 border=0 width="100%">
<tr><td class=title align=center><br>Monitor Button of <b>{$listing.name}</b></td></tr>
<tr><td align="center" colspan="4">
<a href="{"?a=details&lid=`$listing.id`"|encurl}">
<img src="{"?a=image&lid=`$listing.id`"|encurl}" border="0" alt="Monitored by {$settings.site_name}"></a></td></tr>
<tr><td align=center colspan="4"><strong>To Place above Button on your site click on box below and copy the code.</strong></td>
</tr>
<tr><td align="center" colspan="4"><textarea name="logo_txt" class="inpts" cols="75" rows="4" onmouseover="this.select()"><a href="{"?a=details&lid=`$listing.id`"|encurl}"><img src="{"?a=image&lid=`$listing.id`"|encurl}" border="0" alt="Monitored by {$settings.site_name}"></a></textarea></td></tr>

<tr>
<td width="25%">Top - Left</td>
<td width="25%">Top - Right</td>
<td width="25%">Bottom - Left</td>
<td width="25%">Bottom - Right</td>
</tr>
<tr>
<td><textarea class="inpts" cols="30" rows="5" onmouseover="this.select()">
<script language="JavaScript" src="{"getstatus.js"|encurl}" type="text/javascript"></script>
<script type="text/javascript">showdetails("{$listing.id}","tl","top","left");</script>
</textarea></td>
<td><textarea class="inpts" cols="30" rows="5" onmouseover="this.select()">
<script language="JavaScript" src="{"getstatus.js"|encurl}" type="text/javascript"></script>
<script type="text/javascript">showdetails("{$listing.id}","tr","top","right");</script>
</textarea></td>
<td><textarea class="inpts" cols="30" rows="5" onmouseover="this.select()">
<script language="JavaScript" src="{"getstatus.js"|encurl}" type="text/javascript"></script>
<script type="text/javascript">showdetails("{$listing.id}","bl","bottom","left");</script>
</textarea></td>
<td><textarea class="inpts" cols="30" rows="5" onmouseover="this.select()">
<script language="JavaScript" src="{"getstatus.js"|encurl}" type="text/javascript"></script>
<script type="text/javascript">showdetails("{$listing.id}","br","bottom","right");</script>
</textarea></td>
</tr>
</table>
