{if $latestpayouts}
<table border="0">
{section name=lp loop=$latestpayouts}
<tr><td align="left"><img src="{"images/left.png"|encurl}" border="0"> <a href="{"?a=details&aj=paystat&lid=`$latestpayouts[lp].id`"|encurl}"><b>{$latestpayouts[lp].sub_name}</b></a></td>
<td align="right"><font color="#009900" style="font-size:7pt">${$latestpayouts[lp].amount}</font></td></tr>
<tr><td colspan="2"><small style="color:#999999">Date: {$latestpayouts[lp].pdate}</small></td></tr>
{/section}
</table><br>
{else}No data find in database<br>
{/if}







