<?php /* Smarty version 2.6.2, created on 2012-03-23 20:09:12
         compiled from header_install.tpl */ ?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>HOT HYIP Lister. Install Script.</title>
<link href="style.css" rel="stylesheet" type="text/css">
</head>

<body leftmargin="0" topmargin="0" marginwidth="0" marginheight="0">
<center>
<table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr>
<td width="435"><img src="images/toplogo.png" width="435" height="101"></td>
    <td align="center"></td>
</tr>
</table>

<table width="100%" border="0" cellpadding="0" cellspacing="0" height="100%">
<tr bgcolor="#FFFFFF" valign="top"><td bgcolor="#FFFFFF" valign="top" width=99%>
            <!-- Main: Start -->
<table width="100%" border="0" cellpadding="10" cellspacing="0" class="forTexts">
<tr><td width=100% valign=top> <b>HOT HYIP Lister. Install script.</b> 
                <br>
                <br>
<center>