<div class="box">
<div class="box_title">Live Support</div>
<div class="box_body">
<div align="center"><a mce_href="ymsgr:sendim?{$settings.ym_support}" href="ymsgr:sendim?{$settings.ym_support}" target="_blank"><img src="http://opi.yahoo.com/online?u={$settings.ym_support}&m=g&t=14" alt="" border="0"></a></div>
</div></div>