<div class="box">
<div class="box_title">News</div>
<div class="box_body">
<table cellspacing="0" border="0" width="100%" style="word-break:break-all">
{section name=s loop=$news}
<tr><td class="adblack">
<table cellpadding="2" width="100%" cellspacing="0" border="0" style="word-break:break-all">
<tr><td class="smallnewsspons">  
<span class="smallnewstitle">{$news[s].title}</span><br>
<span class=smallnewstext>{$news[s].small_text}</span> <a href="{"?a=news#`$news[s].id`"|encurl}" class=smalllink>more</a>
</td></tr></table>
</td></tr>			
<tr><td align="center"><span class=smallnewsdate>{$news[s].d}</span></td></tr>
{/section}
<tr><td><a href="{"?a=news"|encurl}">All news</a></td></tr>
</table>
</div>
</div>