<div class="box">
<div class="box_title">Our Logo</div>
<div class="box_body">
<div align=center><a href="{$settings.site_url}"><img src="{"`$settings.site_logo_url`"|encurl}" border="0"></a><br><a href="{"?a=partners"|encurl}" class=smalllink>Put this logo on your site!</a></div>
</div>
</div>