{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">Add Your Program (1/2)</div>
<div class="box_body">
{if $msg eq 'error'}
<div align="center"><b style="color:red">Sorry, your confirmation code has expired.</b></div>
{else}
<script language="JavaScript">
var listfee = new Array();
{section name=fe loop=$lfees}
listfee[{$lfees[fe].id}] = '{$lfees[fe].fee}';
{/section}
{literal}
function DoChe(S) { document.getElementById("amount_").value=listfee[S]; }
{/literal}
</script>
<table cellspacing=0 cellpadding=2 border=0 width=100%>
<tr><td><b>Your Description here</b></td></tr>
<tr><td width="96%">
<form name="addsite" method="POST">
<input type="hidden" name="a" value="send_payment">
<fieldset>
<legend><b style="color:#A70000">&nbsp;Listing Options&nbsp;</b></legend>
<table width="100%" border="0" cellpadding="1" cellspacing="8">
<tr><td align="right" width="40%"><b>List Type:</b></td>
<td><select name="type" class="inpts" onchange="DoChe(this.value);">
{section name=ga loop=$groups_nav}
{if $groups_nav[ga].reg_enabled}
<option value="{$groups_nav[ga].id}">{$groups_nav[ga].nav_name} Listing</option>
{/if}
{/section}</select></td></tr>
<tr><td align="right"><b>Processor:</b></td>
<td>{if $settings.lr_enable}<input type='radio' name='payec' value='LR' checked>LibertyReserve &nbsp;{/if}{if $settings.pm_enable}  <input type='radio' name='payec' value='PM'>PerfectMoney{/if}
</td></tr>
<tr><td align="right"><b>Spend Amount:</b></td>
<td align=left><input readonly type="text" name="amount" id="amount_" value="{$fee1}" size="8" class="inpts"> <font color="#45BA00">USD</font></td></tr>
<tr><td></td><td><input type="submit" name="spend" value=" Pay Now " class="sbmt"></td></tr>
</table></fieldset>
</form>
</td></tr>
</table>
{/if}
</div></div>
{include file="footer.tpl"}