<div class="box">
<div class="box_title">Sidebar Banner(160x600)</div>
<div class="box_body">
<div style="text-align: center">
{section name=b8 loop=$ads.8}
{if $ads.8[b8].no}
<a href="{"?a=goads&aid=8&id=`$ads.8[b8].no`"|encurl}" target="_blank" title="{$ads.8[b8].desc}">{if $ads.8[b8].format == 'flash'}<embed width="125" height="125" src="{$ads.8[b8].imgurl}"><noembed>{"?a=goads&aid=8&id=`$ads.8[b8].no`"|encurl}</noembed>{else}<img src="{$ads.8[b8].imgurl}" alt="{$ads.8[b8].desc}" border="0">{/if}</a><br><a href="{"?a=advertise&ad=8"|encurl}">Cost of Ad - ${$ads.8[b8].price}</a><br>Expires: {$ads.8[b8].expired}
{else}
<a href="{"?a=advertise&ad=8"|encurl}" title="Advertise your banner here."><img src="{"images/125.png"|encurl}" width="125" height="125" alt="Place Your AD Here" border="0"></a><br><a href="{"?a=advertise&ad=8"|encurl}">Place AD Here - ${$ads.8[b8].price}</a>
{/if}<br><br>
{/section}
</div></div>
</div>