<?xml version="1.0" encoding="windows-1251"?>
<rss version="2.0" xmlns:content="http://purl.org/rss/1.0/modules/content/">
<channel>
<title>HYIP Monitor - {$settings.site_name}:</title>
<link>{$settings.site_url}/?a=rss</link>
<description>New Hyips</description>
<language>en</language>
	
{section name=i loop=$items}
<item>
<title>{$items[i].title}</title>
<percents><![CDATA[{$items[i].percents}]]></percents>
<link><![CDATA[{$settings.site_url}/{$items[i].link}]]></link>
<description><![CDATA[{$items[i].description}]]></description>
<pubDate>{$items[i].date}</pubDate>
</item>
{/section}
</channel>
</rss>