<script src="{"js/ads_box_r.js"|encurl}"></script>
{if $ads.10[0].no}
<script>right_ads("{"?a=goads&aid=10&id=`$ads.10[0].no`"|encurl}","{$ads.10[0].imgurl}","{$ads.10[0].desc}","{if $ads.10[0].format == 'flash'}f{else}p{/if}")</script>
{else}
<script>right_ads("{"?a=advertise&ad=10"|encurl}","images/125.png","Advertise your banner here","p")</script>
{/if}

