<?php /* Smarty version 2.6.2, created on 2012-05-23 21:06:46
         compiled from directory_add.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'directory_add.tpl', 7, false),array('modifier', 'escape', 'directory_add.tpl', 32, false),array('modifier', 'default', 'directory_add.tpl', 32, false),)), $this); ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div class="box">
<div class="box_title" id="tba">Add Directory Link</div>
<div class="box_body">

<table width="100%" border="0" cellspacing="0" cellpadding="0">
<tr><td><b><a href="<?php echo ((is_array($_tmp="?a=directory")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">Main</a> <?php if (count($_from = (array)$this->_tpl_vars['path'])):
    foreach ($_from as $this->_tpl_vars['p']):
?> :: <a href="<?php echo ((is_array($_tmp="?a=directory&cat=".($this->_tpl_vars['p']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><?php echo $this->_tpl_vars['p']['name']; ?>
</a><?php endforeach; unset($_from); endif; ?></b>
</td></tr>
</table><br>
<div style="font-weight:bold">
To add link into our directory you should place our  <a href="<?php echo ((is_array($_tmp="?a=codes")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">link code</a> on your site.
</div>
<br>
<?php if ($this->_tpl_vars['errors']): ?>
<ul style="color:red">
<?php if ($this->_tpl_vars['errors']['turing']): ?><li> Invalid turing image provided.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['category']): ?><li> Please, select links category</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['title']): ?><li> Please, enter your site title</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['url']): ?><li> Please, enter your site URL, it should starts from http:// or https://</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['back_link']): ?><li> Please, enter your Back Link, it should starts from http:// or https://</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['email']): ?><li> Please, enter your valid email</li><?php endif; ?>
</ul>
<?php endif; ?>

<form method="post" action="">
<input type=hidden name="a" value="directory">
<input type=hidden name="action" value="add">
<input type=hidden name="cat" value="<?php echo $this->_tpl_vars['cat']['id']; ?>
">
<table width="100%" border="0" cellspacing="1" cellpadding="2">
<tr>
  <td>Category</td>
  <td><b><?php echo ((is_array($_tmp=((is_array($_tmp=$this->_tpl_vars['cat']['name'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')))) ? $this->_run_mod_handler('default', true, $_tmp, 'Main') : smarty_modifier_default($_tmp, 'Main')); ?>
</b></td>
</tr>
<tr>
  <td>Site Title</td>
  <td><input type=text name="title" maxlength="255" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['title'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
  <td>Site Description</td>
  <td><input type=text name="description" maxlength="1024" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['description'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
  <td>Site URL</td>
  <td><input type=text name="url" maxlength="255" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['url'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
  <td>Button URL</td>
  <td><input type=text name="button_url" maxlength="255" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['button_url'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
  <td>Back Link</td>
  <td><input type=text name="back_link" maxlength="255" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['back_link'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
  <td>E-mail</td>
  <td><input type=text name="email" maxlength="255" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['email'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<?php if ($this->_tpl_vars['settings']['use_turing']): ?>
<tr>
  <th><img src="<?php echo ((is_array($_tmp="?a=turing&".($this->_tpl_vars['sesname'])."=".($this->_tpl_vars['sesid'])."&r=".($this->_tpl_vars['rand']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="turing code"></th>
  <td><input type=text name="turing" maxlength=6 size="10" class="inpts"></td>
</tr>
<?php endif; ?>
<tr>
  <td></td>
  <td><input type=submit value="Add Site" class="sbmt"></td>
</tr>
</table>
</form>
</div></div>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>