<?php /* Smarty version 2.6.2, created on 2012-03-23 20:12:39
         compiled from header.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'header.tpl', 7, false),array('modifier', 'escape', 'header.tpl', 41, false),)), $this); ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8895-1">
<meta name="keywords" content="hyip monitor, listing, rating, polling, listings">
<title><?php echo $this->_tpl_vars['settings']['site_name']; ?>
 - HYIP Monitor Site.</title>
<link href="<?php echo ((is_array($_tmp="style.css")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" rel="stylesheet" type="text/css">
<script type="text/javascript" src="<?php echo ((is_array($_tmp="js/main.js")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"></script>
</head>
<body>
<div style="background:#FFFFFF;padding:0px;border:1px solid #AAAAAA;visibility:hidden;z-index:1000;position:absolute;" id="divPic"></div>
<center>
<div class="wall">
<div class="topz">
<table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td width="435"><img src="<?php echo ((is_array($_tmp="images/toplogo.png")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="435" height="101"></td>
<td align="center"><?php if (! $this->_tpl_vars['settings']['hidehn0']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "ads_topbanners.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?></td></tr>
</table>
</div>
<div class="menuz">
<a href="<?php echo $this->_tpl_vars['settings']['site_url']; ?>
" class="menulink">Home</a>
<span onmouseover="getElementById('Rl').style.visibility='visible';" onmouseout="getElementById('Rl').style.visibility='hidden';"><a href="<?php echo ((is_array($_tmp="?a=home")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="menulink">Listings</a>
  <ul id="Rl" onmouseout="getElementById('Rl').style.visibility='hidden'">
    <li><a href="<?php echo ((is_array($_tmp="?a=new")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="submenulink">New Listing</a></li>
    <?php if (isset($this->_sections['g'])) unset($this->_sections['g']);
$this->_sections['g']['name'] = 'g';
$this->_sections['g']['loop'] = is_array($_loop=$this->_tpl_vars['groups_nav']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['g']['show'] = true;
$this->_sections['g']['max'] = $this->_sections['g']['loop'];
$this->_sections['g']['step'] = 1;
$this->_sections['g']['start'] = $this->_sections['g']['step'] > 0 ? 0 : $this->_sections['g']['loop']-1;
if ($this->_sections['g']['show']) {
    $this->_sections['g']['total'] = $this->_sections['g']['loop'];
    if ($this->_sections['g']['total'] == 0)
        $this->_sections['g']['show'] = false;
} else
    $this->_sections['g']['total'] = 0;
if ($this->_sections['g']['show']):

            for ($this->_sections['g']['index'] = $this->_sections['g']['start'], $this->_sections['g']['iteration'] = 1;
                 $this->_sections['g']['iteration'] <= $this->_sections['g']['total'];
                 $this->_sections['g']['index'] += $this->_sections['g']['step'], $this->_sections['g']['iteration']++):
$this->_sections['g']['rownum'] = $this->_sections['g']['iteration'];
$this->_sections['g']['index_prev'] = $this->_sections['g']['index'] - $this->_sections['g']['step'];
$this->_sections['g']['index_next'] = $this->_sections['g']['index'] + $this->_sections['g']['step'];
$this->_sections['g']['first']      = ($this->_sections['g']['iteration'] == 1);
$this->_sections['g']['last']       = ($this->_sections['g']['iteration'] == $this->_sections['g']['total']);
?>
   <li><a href="<?php echo ((is_array($_tmp="?type=".($this->_tpl_vars['groups_nav'][$this->_sections['g']['index']]['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="submenulink"><?php echo $this->_tpl_vars['groups_nav'][$this->_sections['g']['index']]['nav_name']; ?>
</a></li>
   <?php endfor; endif; ?></ul></span>	
<a href="<?php echo ((is_array($_tmp="?a=news")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="menulink">News</a>	  
<a href="<?php echo ((is_array($_tmp="?a=addprogram")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="menulink">Add Program</a>
<a href="<?php echo ((is_array($_tmp="?a=advertise")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="menulink">Advertise</a>
<span onmouseover="getElementById('Rr').style.visibility='visible';" onmouseout="getElementById('Rr').style.visibility='hidden';"><a href="<?php echo ((is_array($_tmp="?a=allrcblist")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="menulink">RefBacks</a>
  <ul id="Rr" onmouseout="getElementById('Rr').style.visibility='hidden'">
    <li><a href="<?php echo ((is_array($_tmp="?a=allrcblist")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="submenulink">All RCB Programs</a></li>
    <li><a href="<?php echo ((is_array($_tmp="?a=allrcbrequest")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="submenulink">All RCB Requests</a></li>
</ul></span>	
<a href="<?php echo ((is_array($_tmp="?a=directory")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="menulink">Directory</a>
<a href="<?php echo ((is_array($_tmp="?a=partners")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="menulink">Partners</a>
<a href="<?php echo ((is_array($_tmp="?a=support")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class="menulink">Support</a>
<span class="search">
  <form action="<?php echo ((is_array($_tmp="?")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><input type="text" name="search" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['search'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
"><input type="submit" value="Search"></form>
 </span>
</div>
<div style="padding-top: 3px;background-color:#154873;"></div>
<div class="bodyz">
<?php if (! $this->_tpl_vars['settings']['hidehn1']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "ads_top728banners.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>
<div class="mainz">
<table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr><td valign="top" class="leftbar">
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "login_box.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php if (! $this->_tpl_vars['settings']['hidehn7']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "ads_side125_banners.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>
<?php if ($this->_tpl_vars['settings']['support_box']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "onlinesupport_box.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>
<?php if ($this->_tpl_vars['settings']['languages_box']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "languages_box.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>
<?php if (! $this->_tpl_vars['settings']['hidehn8']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "ads_side600_banners.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>
<?php if ($this->_tpl_vars['settings']['newlistings_box'] && $this->_tpl_vars['frm']['a'] != 'new'):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "newlistings_box.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>
<?php if ($this->_tpl_vars['settings']['subscribe_box']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "subscribe_box.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>
<?php if ($this->_tpl_vars['settings']['toprcb_box']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "toprcb_box.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>	
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "monitorstats_box.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php if ($this->_tpl_vars['settings']['news_box'] && $this->_tpl_vars['frm']['a'] != 'news'):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "news_box.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>	
<?php if ($this->_tpl_vars['settings']['logo_box']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "logo_box.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>				   
<?php if ($this->_tpl_vars['settings']['paysystems_box']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "paysystems_box.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>
<?php if ($this->_tpl_vars['settings']['partners_box']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "partners_box.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>
</td>
    <td class="mspace"><img src="<?php echo ((is_array($_tmp="images/spacer.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="1" height="1" /></td>
    <td valign="top" class="mainbar"><?php if (! $this->_tpl_vars['settings']['hidehn2']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "ads_headerbanners.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>		
