{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">Program Added:</div>
<div class="box_body">
<table cellspacing=1 cellpadding=3 border=0 width=100%>
<tr>
 <td align=center>
   <p><strong style="color:green">Thank you for using our system.<br>
     Your listing has been successfully added and approved!</strong>
   </p>
</td>
</tr>

<tr><td align=center ><a href="{"?a=details&lid=`$lid`"|encurl}"><img src="{"?a=image&lid=`$lid`"|encurl}" border="0" alt="Monitored by {$settings.site_name}"></a></td></tr>

<tr><td align=center><strong>To Place above Button on your site click on box below and copy the code.</strong></td></tr>

<tr><td align=center>
<textarea name="logo_txt" cols="60" rows="6" onmouseover="this.select()" class="inpts"><a href="{"?a=details&lid=`$lid`"|encurl}"><img src="{"?a=image&lid=`$lid`"|encurl}" border="0" alt="Monitored by {$settings.site_name}"></a></textarea>
</td></tr>
</table>
   
</div></div>
{include file="footer.tpl"}