{section name=b loop=$ads.0}
{if $ads.0[b].no}
<a href="{"?a=goads&aid=0&id=`$ads.0[b].no`"|encurl}" target="_blank" title="{$ads.0[b].desc}">{if $ads.1.format == 'flash'}<embed width="468" height="60" src="{$ads.0[b].imgurl}"><noembed>{"?a=goads&aid=0&id=`$ads.0[b].no`"|encurl}</noembed>{else}<img src="{$ads.0[b].imgurl}" width="468" height="60" alt="{$ads.0[b].desc}" border="0">{/if}</a><br><a href="{"?a=advertise&ad=0"|encurl}" style="color:#EEEEEE;">Advertise your banner here</a> <font color="#E8E8E8">| Expires: {$ads.0[b].expired}</font>
{else}
<a href="{"?a=advertise&ad=0"|encurl}" title="Advertise your banner here."><img src="{"images/468.gif"|encurl}" width="468" height="60" alt="Advertise your banner here." border="0"></a><br><a href="{"?a=advertise&ad=0"|encurl}" style="color:#ffffff;">Advertise your banner here</a> <font color="#f2f2f2">| Available Now!</font>
{/if}<br>
{/section}
