<?php /* Smarty version 2.6.2, created on 2012-03-23 20:09:12
         compiled from footer_install.tpl */ ?>

              </td>
              </tr>
            </table>
            <!-- Main: END -->

 

	 </td>
  </tr>

<tr> 
    <td height="19" bgcolor="fff3cb"><div align="center">&copy; Copyright 2011 by <a href="http://www.cobrascripts.com">HyipScript</a> -
all rights reserved</div></td>
  </tr>
</table>
</center></body>
</html>
