<?php /* Smarty version 2.6.2, created on 2012-05-23 20:12:48
         compiled from directory.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'directory.tpl', 6, false),array('modifier', 'escape', 'directory.tpl', 18, false),)), $this); ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div class="box">
<div class="box_title" id="tba">Links Directory:</div>
<div class="box_body">
<table width="100%" border="0" cellspacing="2" cellpadding="3">
<tr bgcolor="#FFFFC2"><td><b><a href="<?php echo ((is_array($_tmp="?a=directory")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">Main</a> <?php if (count($_from = (array)$this->_tpl_vars['path'])):
    foreach ($_from as $this->_tpl_vars['p']):
?> :: <a href="<?php echo ((is_array($_tmp="?a=directory&cat=".($this->_tpl_vars['p']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><?php echo $this->_tpl_vars['p']['name']; ?>
</a><?php endforeach; unset($_from); endif; ?></b></td>
<td align="right"><a href="<?php echo ((is_array($_tmp="?a=directory&action=add_form&cat=".($this->_tpl_vars['cat']['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" style="color:#A70000">Add Your Link</a>
</td></tr>
</table><br>

<?php if ($this->_tpl_vars['frm']['say'] == 'added'): ?>
<div style="color:green" align="center"><b>Thank you. Your link has been accepted and will be alive after admin approve it.</b></div>
<?php endif; ?>

<table width="100%" border="0" cellspacing="1" cellpadding="2">
<tr>
<?php if (isset($this->_sections['c'])) unset($this->_sections['c']);
$this->_sections['c']['name'] = 'c';
$this->_sections['c']['loop'] = is_array($_loop=$this->_tpl_vars['cats']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['c']['show'] = true;
$this->_sections['c']['max'] = $this->_sections['c']['loop'];
$this->_sections['c']['step'] = 1;
$this->_sections['c']['start'] = $this->_sections['c']['step'] > 0 ? 0 : $this->_sections['c']['loop']-1;
if ($this->_sections['c']['show']) {
    $this->_sections['c']['total'] = $this->_sections['c']['loop'];
    if ($this->_sections['c']['total'] == 0)
        $this->_sections['c']['show'] = false;
} else
    $this->_sections['c']['total'] = 0;
if ($this->_sections['c']['show']):

            for ($this->_sections['c']['index'] = $this->_sections['c']['start'], $this->_sections['c']['iteration'] = 1;
                 $this->_sections['c']['iteration'] <= $this->_sections['c']['total'];
                 $this->_sections['c']['index'] += $this->_sections['c']['step'], $this->_sections['c']['iteration']++):
$this->_sections['c']['rownum'] = $this->_sections['c']['iteration'];
$this->_sections['c']['index_prev'] = $this->_sections['c']['index'] - $this->_sections['c']['step'];
$this->_sections['c']['index_next'] = $this->_sections['c']['index'] + $this->_sections['c']['step'];
$this->_sections['c']['first']      = ($this->_sections['c']['iteration'] == 1);
$this->_sections['c']['last']       = ($this->_sections['c']['iteration'] == $this->_sections['c']['total']);
?>
<td width="50%" class="arr"><a href="<?php echo ((is_array($_tmp="?a=directory&cat=".($this->_tpl_vars['cats'][$this->_sections['c']['index']]['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><b><?php echo ((is_array($_tmp=$this->_tpl_vars['cats'][$this->_sections['c']['index']]['name'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
</b></a></td>
<?php if ($this->_sections['c']['index'] % 2 == 1): ?></tr><?php if (! $this->_sections['c']['last']): ?><tr><?php endif;  endif; ?>
<?php if (( $this->_sections['c']['index'] ) % 2 != 1 && $this->_sections['c']['last']): ?></tr><?php endif; ?>
<?php endfor; endif; ?>
</table>
<br>

<?php if ($this->_tpl_vars['links']): ?>
<table width="100%" border="0" cellspacing="0" cellpadding="0">
<?php if (isset($this->_sections['l'])) unset($this->_sections['l']);
$this->_sections['l']['name'] = 'l';
$this->_sections['l']['loop'] = is_array($_loop=$this->_tpl_vars['links']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['l']['show'] = true;
$this->_sections['l']['max'] = $this->_sections['l']['loop'];
$this->_sections['l']['step'] = 1;
$this->_sections['l']['start'] = $this->_sections['l']['step'] > 0 ? 0 : $this->_sections['l']['loop']-1;
if ($this->_sections['l']['show']) {
    $this->_sections['l']['total'] = $this->_sections['l']['loop'];
    if ($this->_sections['l']['total'] == 0)
        $this->_sections['l']['show'] = false;
} else
    $this->_sections['l']['total'] = 0;
if ($this->_sections['l']['show']):

            for ($this->_sections['l']['index'] = $this->_sections['l']['start'], $this->_sections['l']['iteration'] = 1;
                 $this->_sections['l']['iteration'] <= $this->_sections['l']['total'];
                 $this->_sections['l']['index'] += $this->_sections['l']['step'], $this->_sections['l']['iteration']++):
$this->_sections['l']['rownum'] = $this->_sections['l']['iteration'];
$this->_sections['l']['index_prev'] = $this->_sections['l']['index'] - $this->_sections['l']['step'];
$this->_sections['l']['index_next'] = $this->_sections['l']['index'] + $this->_sections['l']['step'];
$this->_sections['l']['first']      = ($this->_sections['l']['iteration'] == 1);
$this->_sections['l']['last']       = ($this->_sections['l']['iteration'] == $this->_sections['l']['total']);
?>
<tr><td><a href="<?php echo ((is_array($_tmp="?a=directory&out=".($this->_tpl_vars['links'][$this->_sections['l']['index']]['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><b><?php echo ((is_array($_tmp=$this->_tpl_vars['links'][$this->_sections['l']['index']]['title'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
</b></a>
   (Added: <?php echo ((is_array($_tmp=$this->_tpl_vars['links'][$this->_sections['l']['index']]['fdate'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
 - In/Out: <?php echo $this->_tpl_vars['links'][$this->_sections['l']['index']]['t_in']; ?>
/<?php echo $this->_tpl_vars['links'][$this->_sections['l']['index']]['t_out']; ?>
)<br>
   <?php echo ((is_array($_tmp=$this->_tpl_vars['links'][$this->_sections['l']['index']]['description'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
<br>
   <small><?php echo ((is_array($_tmp=$this->_tpl_vars['links'][$this->_sections['l']['index']]['url'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
</small><br><?php if ($this->_tpl_vars['links'][$this->_sections['l']['index']]['button_url']): ?>
<a href="<?php echo ((is_array($_tmp="?a=directory&out=".($this->_tpl_vars['links'][$this->_sections['l']['index']]['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><img src="<?php echo ((is_array($_tmp=$this->_tpl_vars['links'][$this->_sections['l']['index']]['button_url'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" width="120" height="60" border="0"></a><?php endif; ?></td></tr>
<?php endfor; endif; ?>
</table>
<?php elseif ($this->_tpl_vars['cat']): ?>
<br>
<div align="center">No listings in this category.</div>
<?php endif; ?>

<?php if ($this->_tpl_vars['cats'] && ! $this->_tpl_vars['frm']['cat']): ?>
<form method="post" action="">
<input type=hidden name="a" value="directory">
<input type=hidden name="action" value="add">
<table width="100%" cellspacing="1" cellpadding="2" border="0" style="border: 1px dotted #CCCCCC;">
<tr><td colspan="2">To add link into our directory you should place our  <a href="<?php echo ((is_array($_tmp="?a=partners")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">link code</a> on your site.<br><br></td></tr>
<tr><td>Category</td><td><select name="cat" class="inpts">
<option value="0">- Your Category -</option>
<?php if (isset($this->_sections['ac'])) unset($this->_sections['ac']);
$this->_sections['ac']['name'] = 'ac';
$this->_sections['ac']['loop'] = is_array($_loop=$this->_tpl_vars['cats']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['ac']['show'] = true;
$this->_sections['ac']['max'] = $this->_sections['ac']['loop'];
$this->_sections['ac']['step'] = 1;
$this->_sections['ac']['start'] = $this->_sections['ac']['step'] > 0 ? 0 : $this->_sections['ac']['loop']-1;
if ($this->_sections['ac']['show']) {
    $this->_sections['ac']['total'] = $this->_sections['ac']['loop'];
    if ($this->_sections['ac']['total'] == 0)
        $this->_sections['ac']['show'] = false;
} else
    $this->_sections['ac']['total'] = 0;
if ($this->_sections['ac']['show']):

            for ($this->_sections['ac']['index'] = $this->_sections['ac']['start'], $this->_sections['ac']['iteration'] = 1;
                 $this->_sections['ac']['iteration'] <= $this->_sections['ac']['total'];
                 $this->_sections['ac']['index'] += $this->_sections['ac']['step'], $this->_sections['ac']['iteration']++):
$this->_sections['ac']['rownum'] = $this->_sections['ac']['iteration'];
$this->_sections['ac']['index_prev'] = $this->_sections['ac']['index'] - $this->_sections['ac']['step'];
$this->_sections['ac']['index_next'] = $this->_sections['ac']['index'] + $this->_sections['ac']['step'];
$this->_sections['ac']['first']      = ($this->_sections['ac']['iteration'] == 1);
$this->_sections['ac']['last']       = ($this->_sections['ac']['iteration'] == $this->_sections['ac']['total']);
?>
<option value="<?php echo $this->_tpl_vars['cats'][$this->_sections['ac']['index']]['id']; ?>
"><?php echo $this->_tpl_vars['cats'][$this->_sections['ac']['index']]['name']; ?>
</option>
<?php endfor; endif; ?></td></tr>
<tr>
  <td>Site Title</td>
  <td><input type=text name="title" maxlength="255" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['title'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
  <td>Site Description</td>
  <td><input type=text name="description" maxlength="1024" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['description'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
  <td>Site URL</td>
  <td><input type=text name="url" maxlength="255" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['url'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
  <td>Button URL</td>
  <td><input type=text name="button_url" maxlength="255" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['button_url'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
  <td>Back Link</td>
  <td><input type=text name="back_link" maxlength="255" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['back_link'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
  <td>E-mail</td>
  <td><input type=text name="email" maxlength="255" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['email'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<?php if ($this->_tpl_vars['settings']['use_turing']): ?>
<tr>
  <th><img src="<?php echo ((is_array($_tmp="?a=turing&".($this->_tpl_vars['sesname'])."=".($this->_tpl_vars['sesid'])."&r=".($this->_tpl_vars['rand']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="turing code"></th>
  <td><input type=text name="turing" maxlength=6 size="10" class="inpts"></td>
</tr>
<?php endif; ?>
<tr>
  <td></td>
  <td><input type=submit value="Add Site" class="sbmt"></td>
</tr>
</table>
</form>
<?php endif; ?>
</div></div>

<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>