<?php /* Smarty version 2.6.2, created on 2012-05-23 22:17:45
         compiled from details_report_scam.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'default', 'details_report_scam.tpl', 25, false),array('modifier', 'escape', 'details_report_scam.tpl', 25, false),array('modifier', 'encurl', 'details_report_scam.tpl', 33, false),)), $this); ?>
<table cellspacing=1 cellpadding=2 border=0 width="100%">
<tr><td><b style="color:red">Report scam</b></td></tr>
<tr><td>
<?php if ($this->_tpl_vars['errors']): ?>
<ul style="color:red">
<?php if ($this->_tpl_vars['errors']['turing']): ?><li> Invalid turing image.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['email']): ?><li> Please enter your e-mail addresss.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['invalid_email']): ?><li> Please enter valid e-mail address.</li><?php endif; ?>
</ul>
<?php elseif ($this->_tpl_vars['frm']['display'] == 'sent'): ?>
<div style="color:green">Thank you. Your report has been sent to administrator.</div>
<br><br>
<?php endif; ?>
</td></tr>
</table>

<form method="post" name="reportscam">
<input type="hidden" name="a" value="details">
<input type=hidden name="aj" value="report_scam">
<input type=hidden name="action" value="send">
<input type=hidden name="lid" value="<?php echo $this->_tpl_vars['listing']['id']; ?>
">
<table cellspacing=1 cellpadding=2 border=0 width="100%">
<tr>
 <td>Your E-mail</td>
 <td><input type="text" name="email" value="<?php echo ((is_array($_tmp=((is_array($_tmp=@$this->_tpl_vars['frm']['email'])) ? $this->_run_mod_handler('default', true, $_tmp, @$this->_tpl_vars['userinfo']['email']) : smarty_modifier_default($_tmp, @$this->_tpl_vars['userinfo']['email'])))) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
 <td>Report</td>
 <td><textarea name="report" cols="50" rows="4" class="inpts"><?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['report'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
</textarea></td>
</tr>
<?php if ($this->_tpl_vars['settings']['use_turing']): ?>
<tr>
  <td><img src="<?php echo ((is_array($_tmp="?a=turing&".($this->_tpl_vars['sesname'])."=".($this->_tpl_vars['sesid'])."&r=".($this->_tpl_vars['rand']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="turing code"></td>
  <td><input type="text" name="turing" maxlength=6 size="10" class="inpts"></td>
</tr>
<?php endif; ?>
<tr>
 <td></td>
 <td><input type="submit" value="Submit" class="sbmt"></td>
</tr>
</form>
</table>
