<?php /* Smarty version 2.6.2, created on 2012-05-23 20:13:44
         compiled from info_latestpayout.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'info_latestpayout.tpl', 4, false),)), $this); ?>
<?php if ($this->_tpl_vars['latestpayouts']): ?>
<table border="0">
<?php if (isset($this->_sections['lp'])) unset($this->_sections['lp']);
$this->_sections['lp']['name'] = 'lp';
$this->_sections['lp']['loop'] = is_array($_loop=$this->_tpl_vars['latestpayouts']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['lp']['show'] = true;
$this->_sections['lp']['max'] = $this->_sections['lp']['loop'];
$this->_sections['lp']['step'] = 1;
$this->_sections['lp']['start'] = $this->_sections['lp']['step'] > 0 ? 0 : $this->_sections['lp']['loop']-1;
if ($this->_sections['lp']['show']) {
    $this->_sections['lp']['total'] = $this->_sections['lp']['loop'];
    if ($this->_sections['lp']['total'] == 0)
        $this->_sections['lp']['show'] = false;
} else
    $this->_sections['lp']['total'] = 0;
if ($this->_sections['lp']['show']):

            for ($this->_sections['lp']['index'] = $this->_sections['lp']['start'], $this->_sections['lp']['iteration'] = 1;
                 $this->_sections['lp']['iteration'] <= $this->_sections['lp']['total'];
                 $this->_sections['lp']['index'] += $this->_sections['lp']['step'], $this->_sections['lp']['iteration']++):
$this->_sections['lp']['rownum'] = $this->_sections['lp']['iteration'];
$this->_sections['lp']['index_prev'] = $this->_sections['lp']['index'] - $this->_sections['lp']['step'];
$this->_sections['lp']['index_next'] = $this->_sections['lp']['index'] + $this->_sections['lp']['step'];
$this->_sections['lp']['first']      = ($this->_sections['lp']['iteration'] == 1);
$this->_sections['lp']['last']       = ($this->_sections['lp']['iteration'] == $this->_sections['lp']['total']);
?>
<tr><td align="left"><img src="<?php echo ((is_array($_tmp="images/left.png")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" border="0"> <a href="<?php echo ((is_array($_tmp="?a=details&aj=paystat&lid=".($this->_tpl_vars['latestpayouts'][$this->_sections['lp']['index']]['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><b><?php echo $this->_tpl_vars['latestpayouts'][$this->_sections['lp']['index']]['sub_name']; ?>
</b></a></td>
<td align="right"><font color="#009900" style="font-size:7pt">$<?php echo $this->_tpl_vars['latestpayouts'][$this->_sections['lp']['index']]['amount']; ?>
</font></td></tr>
<tr><td colspan="2"><small style="color:#999999">Date: <?php echo $this->_tpl_vars['latestpayouts'][$this->_sections['lp']['index']]['pdate']; ?>
</small></td></tr>
<?php endfor; endif; ?>
</table><br>
<?php else: ?>No data find in database<br>
<?php endif; ?>







