<div class="box">
<div class="box_title">New Listings</div>
<div class="box_body">
{section name=l loop=$new_listings}
{if $new_listings[l].data_type == 'date'}
<div style="border-bottom:#666666 1px dotted" align="left" class="nlt"><b>{$new_listings[l].date} </b></div>
{else}
<div class="arr" align="left"><a href="{"?a=go&lid=`$new_listings[l].id`"|encurl}" target="_blank"><b>{$new_listings[l].name}</b></a> &nbsp;<small><i>{if $new_listings[l].hyip_status == 1}<font color="#009900">PAYING</font>{/if}
   {if $new_listings[l].hyip_status == 2}<font color="brown">WAITING</font>{/if}
   {if $new_listings[l].hyip_status == 3}<font color="orange">PROBLEM</font>{/if}
   {if $new_listings[l].hyip_status == 4}<font color="red">NOT PAYING</font>{/if}</i></small></div>
<div align="left">{$new_listings[l].percents}</div><br>
{/if}
{/section}
</div>
</div>