<?php /* Smarty version 2.6.2, created on 2012-05-23 22:18:05
         compiled from user_login.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'escape', 'user_login.tpl', 34, false),array('modifier', 'encurl', 'user_login.tpl', 42, false),)), $this); ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>

<?php echo '
<script type="text/javascript">
function checkform() {
  if (document.mainform.username.value==\'\') {
    alert("Please type your username!");
    document.mainform.username.focus();
    return false;
  }
  if (document.mainform.password.value==\'\') {
    alert("Please type your password!");
    document.mainform.password.focus();
    return false;
  }
  return true;
}
</script>
'; ?>

<div class="box">
<div class="box_title" id="tba">User Login</div>
<div class="box_body">

<?php if ($this->_tpl_vars['frm']['display'] == 'invalid_login'): ?>
<div style="color:red" align="center">Your login or password<?php if ($this->_tpl_vars['settings']['use_turing']): ?> or turing image code<?php endif; ?> is wrong. Please check this information.</div>
<?php endif; ?>

<form method="post" name="mainform" onsubmit="return checkform()">
<input type=hidden name="a" value="do_login">
<input type=hidden name="referrer" value="<?php echo $this->_tpl_vars['login_referrer']; ?>
">
<table width="100%" border="0" cellspacing="1" cellpadding="3">
<tr>
 <td>Username:</td>
 <td><input type="text" name="username" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['username'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'html') : smarty_modifier_escape($_tmp, 'html')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
 <td>Password:</td>
 <td><input type="password" name="password" value="" class="inpts" size="45"></td>
</tr>
<?php if ($this->_tpl_vars['settings']['use_turing']): ?>
<tr>
 <th><img src="<?php echo ((is_array($_tmp="?a=turing&".($this->_tpl_vars['sesname'])."=".($this->_tpl_vars['sesid'])."&r=".($this->_tpl_vars['rand']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="turing code"></th>
 <td><input type="text" name="turing" size="12" class="inpts"></td>
</tr>
<?php endif; ?>
<tr>
 <td></td>
 <td><input type="submit" value="Login" class="sbmt"></td>
</tr></table>
</form>
<div align="right"><a href="<?php echo ((is_array($_tmp="?a=forgot_password")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" style="color:red">Remind your login information</a></div>
</div></div>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
