{php}
global $settings;
$this->_tpl_vars[payments_box] = preg_split ('/\s*,\s*/', $settings['payments']);
{/php}
<div class="box">
	<div class="box_title">PAYMENT SYSTEMS</div>
	<div class="box_body">
<table cellpadding="0" cellspacing="2" border="0">
{section name=pb loop=$payments_box}
<tr><td width="60" align="right"><img src="{"images/`$payments_box[pb]`.gif"|encurl}" border=0 alt="{$payments_box[pb]}" title="{$payments_box[pb]}"></td><td align=left>List <a class=smalllink href="{"?pfilter=`$payments_box[pb]`"|encurl}">{$payments_box[pb]}</a><br> program</td></tr>
{/section}
</table>
</div>
</div>