<?php /* Smarty version 2.6.2, created on 2012-03-23 20:12:39
         compiled from monitorstats_box.tpl */ ?>
<div class="box">
<div class="box_title">MONITOR STATISTICS</div>
<div class="box_body">
<?php if ($this->_tpl_vars['settings']['topprofitable_box']): ?>
<b><a href="#" onclick="GetData('info','troi','','mstROI');return false;">TOP <?php if ($this->_tpl_vars['settings']['topprofitable_count']):  echo $this->_tpl_vars['settings']['topprofitable_count'];  else: ?>10<?php endif; ?> PROFITABLE</a></b><div style="padding-top:6px;" id="mstROI"></div>
<?php endif; ?>

<?php if ($this->_tpl_vars['settings']['topmonitored_box']): ?>
<b><a href="#" onclick="GetData('info','tmonitors','','mstMT');return false;">TOP <?php if ($this->_tpl_vars['settings']['topmonitored_count']):  echo $this->_tpl_vars['settings']['topmonitored_count'];  else: ?>10<?php endif; ?> MONITORED</a></b><div style="padding-top:6px;" id="mstMT"></div>
<?php endif; ?>

<?php if ($this->_tpl_vars['settings']['latestpayout_box']): ?>
<b><a href="#" onclick="GetData('info','lpayouts','','mstPT');return false;">LATEST PAYOUTS</a></b><div style="padding-top:6px;" id="mstPT"></div>
<?php endif; ?>

<?php if ($this->_tpl_vars['settings']['latestvote_box']): ?>
<b><a href="#" onclick="GetData('info','lvotes','','mstVT');return false;">LATEST VOTES</a></b><div style="padding-top:6px;" id="mstVT"></div>
<?php endif; ?>

<?php if ($this->_tpl_vars['settings']['latestscam_box']): ?>
<b><a href="#" onclick="GetData('info','lscams','','mstSM');return false;">LATEST SCAMS</a></b><div style="padding-top:6px;" id="mstSM"></div>
<?php endif; ?>
</div>
</div>
