<?php /* Smarty version 2.6.2, created on 2012-03-23 20:12:39
         compiled from login_box.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'login_box.tpl', 37, false),)), $this); ?>
<div class="box">
<div class="box_title"><?php if ($this->_tpl_vars['userinfo']['logged']): ?>Menu<?php else: ?>Members<?php endif; ?></div>
<div class="box_body">

<?php if ($this->_tpl_vars['userinfo']['logged'] != 1): ?>
<?php echo '
<script type="text/javascript">
function checklogin() {   
  if (document.loginform.username.value==\'\') {
    alert("Please enter your username!");
    document.loginform.username.focus();
    return false;
  }
  if (document.loginform.password.value==\'\') {
    alert("Please enter your password!");
    document.loginform.password.focus();
    return false;
  }
  return true;
}
</script>
'; ?>

<form method="post" name="loginform" onsubmit="return checklogin()" action="">
<input type=hidden name="a" value="do_login">
<input type=hidden name="referrer" value="<?php echo $this->_tpl_vars['login_referrer']; ?>
">
<table cellpadding="1" cellspacing="1" border="0">
<tr>
 <td>Username:</td>
 <td><input type="text" name="username" class="inpts" size="20"></td>
</tr>
<tr>
 <td>Password:</td>
 <td><input type="password" name="password" class="inpts" size="20"></td>
</tr>
<?php if ($this->_tpl_vars['settings']['use_turing']): ?>
<tr>
  <th><img src="<?php echo ((is_array($_tmp="?a=turing&".($this->_tpl_vars['sesname'])."=".($this->_tpl_vars['sesid'])."&r=".($this->_tpl_vars['rand']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="turing code"></th>
  <td><input type=text name="turing" maxlength="6" class="inpts" size="10"></td>
</tr>
<?php endif; ?>
<tr>
 <td>&nbsp;</td>
 <td><input type="submit" value="Login" class="sbmt"></td>
</tr>
</table>
</form>
<p class="links"><a href="<?php echo ((is_array($_tmp="?a=signup")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">Sign Up</a> | <a href="<?php echo ((is_array($_tmp="?a=forgot_password")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">Forgot Password?</a></p>

<?php else: ?>
<table cellpadding="2" cellspacing="2" border="0">
<tr>
 <td>
<ul class="menu">
<li><a href="<?php echo ((is_array($_tmp="?a=bookmarks")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">My HYIP List</a></li>
<li><a href="<?php echo ((is_array($_tmp="?a=refback_requests")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">RCB Requests</a></li>
<li><a href="<?php echo ((is_array($_tmp="?a=profile")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">Edit Profile</a></li>
<li><a href="<?php echo ((is_array($_tmp="?a=logout")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">Logout</a></li></td>
</tr>
</table>
<?php endif; ?>
</div></div>