{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">Vote Confirm</div>
<div class="box_body">
<table cellspacing=1 cellpadding=2 border=0 width=100%>
<tr>
 <td align=center>Thank you for voting for <b>{$listing.name}</b></td>
</tr>
<tr>
 <td align=center><b>Please check your e-mail to confirm your vote.</b></td>
</tr>
</table>
</div></div>
{include file="footer.tpl"}