<?php /* Smarty version 2.6.2, created on 2012-03-23 20:12:39
         compiled from ads_side600_banners.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'ads_side600_banners.tpl', 7, false),)), $this); ?>
<div class="box">
<div class="box_title">Sidebar Banner(160x600)</div>
<div class="box_body">
<div style="text-align: center">
<?php if (isset($this->_sections['b8'])) unset($this->_sections['b8']);
$this->_sections['b8']['name'] = 'b8';
$this->_sections['b8']['loop'] = is_array($_loop=$this->_tpl_vars['ads']['8']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['b8']['show'] = true;
$this->_sections['b8']['max'] = $this->_sections['b8']['loop'];
$this->_sections['b8']['step'] = 1;
$this->_sections['b8']['start'] = $this->_sections['b8']['step'] > 0 ? 0 : $this->_sections['b8']['loop']-1;
if ($this->_sections['b8']['show']) {
    $this->_sections['b8']['total'] = $this->_sections['b8']['loop'];
    if ($this->_sections['b8']['total'] == 0)
        $this->_sections['b8']['show'] = false;
} else
    $this->_sections['b8']['total'] = 0;
if ($this->_sections['b8']['show']):

            for ($this->_sections['b8']['index'] = $this->_sections['b8']['start'], $this->_sections['b8']['iteration'] = 1;
                 $this->_sections['b8']['iteration'] <= $this->_sections['b8']['total'];
                 $this->_sections['b8']['index'] += $this->_sections['b8']['step'], $this->_sections['b8']['iteration']++):
$this->_sections['b8']['rownum'] = $this->_sections['b8']['iteration'];
$this->_sections['b8']['index_prev'] = $this->_sections['b8']['index'] - $this->_sections['b8']['step'];
$this->_sections['b8']['index_next'] = $this->_sections['b8']['index'] + $this->_sections['b8']['step'];
$this->_sections['b8']['first']      = ($this->_sections['b8']['iteration'] == 1);
$this->_sections['b8']['last']       = ($this->_sections['b8']['iteration'] == $this->_sections['b8']['total']);
?>
<?php if ($this->_tpl_vars['ads']['8'][$this->_sections['b8']['index']]['no']): ?>
<a href="<?php echo ((is_array($_tmp="?a=goads&aid=8&id=".($this->_tpl_vars['ads']['8'][$this->_sections['b8']['index']]['no']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" target="_blank" title="<?php echo $this->_tpl_vars['ads']['8'][$this->_sections['b8']['index']]['desc']; ?>
"><?php if ($this->_tpl_vars['ads']['8'][$this->_sections['b8']['index']]['format'] == 'flash'): ?><embed width="125" height="125" src="<?php echo $this->_tpl_vars['ads']['8'][$this->_sections['b8']['index']]['imgurl']; ?>
"><noembed><?php echo ((is_array($_tmp="?a=goads&aid=8&id=".($this->_tpl_vars['ads']['8'][$this->_sections['b8']['index']]['no']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
</noembed><?php else: ?><img src="<?php echo $this->_tpl_vars['ads']['8'][$this->_sections['b8']['index']]['imgurl']; ?>
" alt="<?php echo $this->_tpl_vars['ads']['8'][$this->_sections['b8']['index']]['desc']; ?>
" border="0"><?php endif; ?></a><br><a href="<?php echo ((is_array($_tmp="?a=advertise&ad=8")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">Cost of Ad - $<?php echo $this->_tpl_vars['ads']['8'][$this->_sections['b8']['index']]['price']; ?>
</a><br>Expires: <?php echo $this->_tpl_vars['ads']['8'][$this->_sections['b8']['index']]['expired']; ?>

<?php else: ?>
<a href="<?php echo ((is_array($_tmp="?a=advertise&ad=8")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" title="Advertise your banner here."><img src="<?php echo ((is_array($_tmp="images/125.png")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="125" height="125" alt="Place Your AD Here" border="0"></a><br><a href="<?php echo ((is_array($_tmp="?a=advertise&ad=8")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">Place AD Here - $<?php echo $this->_tpl_vars['ads']['8'][$this->_sections['b8']['index']]['price']; ?>
</a>
<?php endif; ?><br><br>
<?php endfor; endif; ?>
</div></div>
</div>