<?php /* Smarty version 2.6.2, created on 2012-03-23 20:12:39
         compiled from footer.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'date_format', 'footer.tpl', 9, false),)), $this); ?>
</td>
  </tr>
</table>
</div></div>

<div class="footerz">
<div align="center"><strong>DISCLAIMER:</strong> We do not own or promote any programs listed here.The information provided here is for your own use. Some programs, investments or any listings here may be illegal depending on your country's laws.We do not recommend you to spend what you cannot afford to lose.         
</br></br>
&copy;Copyright 2011-<?php echo ((is_array($_tmp=time())) ? $this->_run_mod_handler('date_format', true, $_tmp, "%Y") : smarty_modifier_date_format($_tmp, "%Y")); ?>
 by <a href="<?php echo $this->_tpl_vars['settings']['site_url']; ?>
"><font color=blue><?php echo $this->_tpl_vars['settings']['site_name']; ?>
</font></a> - All rights reserved. 
</div></div></div>
</center>
<?php if (! $this->_tpl_vars['settings']['hidehn9']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "ads_bottomleft_banners.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>
<?php if (! $this->_tpl_vars['settings']['hidehn10']):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "ads_bottomright_banners.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
  endif; ?>
</body>
</html>
