{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">Vote Confirmed</div>
<div class="box_body">

{if $success == 0}
<b>Vote is not confirmed:</b><br><br>

Please check thelink you received. It seems like the link is broken.
{else}
<b>Vote is confirmed:</b><br><br>

{if $success == 1}
Your vote has been successfully added.
{/if}
{if $success == 2}
Your vote has been successfully updated.
{/if}
<br><br>
<a href="{"?a=details&lid=`$listing_id`"|encurl}">Return to the listing details</a>
{/if}

</div></div>
{include file="footer.tpl"}
