{if $latestscams}
{section name=ls loop=$latestscams}
<img src="{"images/scam.png"|encurl}" align="absmiddle" border="0" alt="scam" title="scam"> <a href="{"?a=details&lid=`$latestscams[ls].id`"|encurl}" style="color:#a80e12"><b>{$latestscams[ls].sub_name}</b></a><br>
{/section}<br>
{else}No data find in database
{/if}


