<table cellspacing=0 cellpadding=1 border=0 width=100%>
<tr>
<td>
<table cellspacing=0 cellpadding=0 border=0 width=100%>
<tr valign="middle" height="30" class="listtitle">
<td width="20">&nbsp;</td>
<td valign="middle" class="groupname">{$groups[g].name}</td>
<td valign="middle">
{if $groups[g].reg_enabled}

{/if}
</td>
<td width="10" valign="bottom">&nbsp;</td>
</tr>
 </table>
 </td>
</tr>
{section name=l loop=$groups[g].listings}
<tr>
 <td>
{assign var='listing' value=$groups[g].listings[l]}
{include file="details_closed.tpl"}
 </td>
</tr>

{/section}
</table>


{php}
$q = 'SELECT * FROM hl_listings WHERE group_id =7';   
  if (!($sth = mysql_query ($q)))
  {
    print mysql_error ();
    ;
  }

  $count_all = mysql_num_rows($sth);
  $onpage = 50;
  $colpages = ceil ($count_all / $onpage);

 echo '<center>';
 for ($i = 1; $i <= $colpages-1; ++$i)
  {
  echo '<a href="/close-' . $i .'.html">';
  echo $i;
  echo '</a> ' ;
  }
 echo  '</center><br>';

{/php}