</td>
  </tr>
</table>
</div></div>

<div class="footerz">
<div align="center"><strong>DISCLAIMER:</strong> We do not own or promote any programs listed here.The information provided here is for your own use. Some programs, investments or any listings here may be illegal depending on your country's laws.We do not recommend you to spend what you cannot afford to lose.         
</br></br>
&copy;Copyright 2011-{$smarty.now|date_format:"%Y"} by <a href="{$settings.site_url}"><font color=blue>{$settings.site_name}</font></a> - All rights reserved. 
</div></div></div>
</center>
{if !$settings.hidehn9}{include file="ads_bottomleft_banners.tpl"}{/if}
{if !$settings.hidehn10}{include file="ads_bottomright_banners.tpl"}{/if}
</body>
</html>
