<html>
<head>
<META HTTP-EQUIV=Refresh CONTENT="0; URL={$referrer|escape:html}">
</head>
<body>
<center>
Hello {$userinfo.username}. You have logged in.
<a href="{$referer|escape:html}">click here to continue</a>.
<body>
</html>