{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">Preview Your Ad</div>
<div class="box_body">

<b>Please Preview and confirm your Advertise</b>
<hr size=1 noshade="noshade" style="border:1px #cccccc dotted">
<fieldset>
<legend><font color="#A70000">&nbsp;Preview&nbsp;</font></legend>
<table cellSpacing=0 cellPadding=3 width="100%" border=0>

<tr><td align="center"><a href="{$frm.ad_site_url}" target="_blank" title="{$frm.ad_desc}"><img src="{$frm.ad_banner_url}" border="0" alt="{$frm.ad_desc}"></a></td></tr>

</table></fieldset>

<fieldset>
<legend><font color="#A70000">&nbsp;Details of Advertise&nbsp;</font></legend>
<table cellSpacing=0 cellPadding=3 width="100%" border=0>
<form name="payfee" method="post"> 
<input type="hidden" name="a" value="send_payment">
<input type="hidden" name="code" value="{$session}">
<tr><td align="right" width="33%"><b>Program Name :</b></td><td>{$frm.ad_site_name}</td></tr>
<tr><td align="right"><b>Website Url :</b></td><td>{$frm.ad_site_url}</td></tr>
<tr><td align="right"><b>Banner Url :</b></td><td>{$frm.ad_banner_url}</td></tr>
<tr><td align="right"><b>Program Description :</b></td><td>{$frm.ad_desc}</td></tr>
<tr><td align="right"><b>Advertiser Email :</b></td><td>{$frm.ader_mail}</td></tr>
<tr><td align="right"><b>Ad Type :</b></td><td>{$adinfo.type}</td></tr>
{if $adinfo.place}<tr><td align="right"><b>Ad Place :</b></td><td>{$adinfo.place}</td></tr>{/if}
<tr><td align="right"><b>Ad Period :</b></td><td>{$adinfo.period}</td></tr>
<tr><td align="right"><b>Price :</b></td>
<td><b>${$adinfo.fee}</b></td></tr>

<tr><td align="right"><b>Expired Date :</b></td><td>{$adinfo.expired}</td></tr>

<tr><td align="right"><b>Payment System :</b></td>
<td><img src="{"images/`$frm.processor`.gif"|encurl}" border="0" align="absmiddle"> 
</td></tr>
<tr><td>&nbsp;</td><td><br><input type=submit value=" Confirm "> &nbsp<input type=button value=" Cancel " onclick="javascript:history.go(-1)"><br></td></tr>
</table></form></fieldset>
</div></div>

{include file="footer.tpl"}