<?php /* Smarty version 2.6.2, created on 2012-03-23 20:13:48
         compiled from allrcb.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'allrcb.tpl', 8, false),)), $this); ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div class="box">
<div class="box_title" id="tba">All Referral Commission Back Programs</div>
<div class="box_body">

<?php if (isset($this->_sections['n'])) unset($this->_sections['n']);
$this->_sections['n']['name'] = 'n';
$this->_sections['n']['loop'] = is_array($_loop=$this->_tpl_vars['allrcbs']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['n']['show'] = true;
$this->_sections['n']['max'] = $this->_sections['n']['loop'];
$this->_sections['n']['step'] = 1;
$this->_sections['n']['start'] = $this->_sections['n']['step'] > 0 ? 0 : $this->_sections['n']['loop']-1;
if ($this->_sections['n']['show']) {
    $this->_sections['n']['total'] = $this->_sections['n']['loop'];
    if ($this->_sections['n']['total'] == 0)
        $this->_sections['n']['show'] = false;
} else
    $this->_sections['n']['total'] = 0;
if ($this->_sections['n']['show']):

            for ($this->_sections['n']['index'] = $this->_sections['n']['start'], $this->_sections['n']['iteration'] = 1;
                 $this->_sections['n']['iteration'] <= $this->_sections['n']['total'];
                 $this->_sections['n']['index'] += $this->_sections['n']['step'], $this->_sections['n']['iteration']++):
$this->_sections['n']['rownum'] = $this->_sections['n']['iteration'];
$this->_sections['n']['index_prev'] = $this->_sections['n']['index'] - $this->_sections['n']['step'];
$this->_sections['n']['index_next'] = $this->_sections['n']['index'] + $this->_sections['n']['step'];
$this->_sections['n']['first']      = ($this->_sections['n']['iteration'] == 1);
$this->_sections['n']['last']       = ($this->_sections['n']['iteration'] == $this->_sections['n']['total']);
?>
<table cellspacing=1 cellpadding=2 border=0 width="100%">
<tr><td><div class="arr"><a href="<?php echo ((is_array($_tmp="?a=go&lid=".($this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['lid']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" target="_blank" style="color:#a70000"><b><?php echo $this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['name']; ?>
</b></a></div></td><td align="right"><a href="<?php echo ((is_array($_tmp="?a=details&aj=rcb&lid=".($this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['lid']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" style="color:green">Request RCB</a></td></tr></table>
<table cellspacing=1 cellpadding=2 width="100%" style="border: 1px dotted #CCCCCC;" align="center">
<tr bgcolor="#EEEEEE">
<td width=25% align="center" rowspan="2">Deposit Amount</td>
<td width=15% align="center" rowspan="2">Referral</td>
<td width="30%" align="center" colspan="2">1st Deposit</td>
<td width="30%" align="center" colspan="2">Re-Invested</td>
</tr>
<tr bgcolor="#EEEEEE">
<td width=15% align="center">RCB</td>
<td width=15% align="center">BONUS</td>
<td width=15% align="center">RCB</td>
<td width=15% align="center">BONUS</td>
</tr>
<?php if (isset($this->_sections['l'])) unset($this->_sections['l']);
$this->_sections['l']['name'] = 'l';
$this->_sections['l']['loop'] = is_array($_loop=$this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['l']['show'] = true;
$this->_sections['l']['max'] = $this->_sections['l']['loop'];
$this->_sections['l']['step'] = 1;
$this->_sections['l']['start'] = $this->_sections['l']['step'] > 0 ? 0 : $this->_sections['l']['loop']-1;
if ($this->_sections['l']['show']) {
    $this->_sections['l']['total'] = $this->_sections['l']['loop'];
    if ($this->_sections['l']['total'] == 0)
        $this->_sections['l']['show'] = false;
} else
    $this->_sections['l']['total'] = 0;
if ($this->_sections['l']['show']):

            for ($this->_sections['l']['index'] = $this->_sections['l']['start'], $this->_sections['l']['iteration'] = 1;
                 $this->_sections['l']['iteration'] <= $this->_sections['l']['total'];
                 $this->_sections['l']['index'] += $this->_sections['l']['step'], $this->_sections['l']['iteration']++):
$this->_sections['l']['rownum'] = $this->_sections['l']['iteration'];
$this->_sections['l']['index_prev'] = $this->_sections['l']['index'] - $this->_sections['l']['step'];
$this->_sections['l']['index_next'] = $this->_sections['l']['index'] + $this->_sections['l']['step'];
$this->_sections['l']['first']      = ($this->_sections['l']['iteration'] == 1);
$this->_sections['l']['last']       = ($this->_sections['l']['iteration'] == $this->_sections['l']['total']);
?>
<tr bgcolor="#CCFF99">
<td align="center">$<?php echo $this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['min_deposit']; ?>
-$<?php echo $this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['max_deposit']; ?>
</td>
<td align="center"><?php if ($this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['ref'] > 0): ?> <?php echo $this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['ref']; ?>
% <?php else: ?> -- <?php endif; ?></td>
<td align="center"><?php if ($this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['rcb'] > 0): ?> <?php echo $this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['rcb']; ?>
% <?php else: ?> -- <?php endif; ?></td>
<td align="center"><?php if ($this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['bonus'] > 0): ?> $<?php echo $this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['bonus']; ?>
 <?php else: ?> -- <?php endif; ?></td>
<td align="center"><?php if ($this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['rcb2'] > 0): ?> <?php echo $this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['rcb2']; ?>
% <?php else: ?> -- <?php endif; ?></td>
<td align="center"><?php if ($this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['bonus2'] > 0): ?> $<?php echo $this->_tpl_vars['allrcbs'][$this->_sections['n']['index']]['rates'][$this->_sections['l']['index']]['bonus2']; ?>
 <?php else: ?> -- <?php endif; ?></td>
</tr>
<?php endfor; endif; ?>
</table>
<br>
<?php endfor; endif; ?>
</div></div>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>