<?php /* Smarty version 2.6.2, created on 2012-03-23 20:12:39
         compiled from partners_box.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'partners_box.tpl', 11, false),)), $this); ?>
<div class="box">
<div class="box_title">Partner Links</div>
<div class="box_body">
<div align="center">
<table cellpadding="1" cellspacing="2" border="0">
<?php if ($this->_tpl_vars['ipartners']): ?>
<?php if (isset($this->_sections['ipa'])) unset($this->_sections['ipa']);
$this->_sections['ipa']['name'] = 'ipa';
$this->_sections['ipa']['loop'] = is_array($_loop=$this->_tpl_vars['ipartners']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['ipa']['show'] = true;
$this->_sections['ipa']['max'] = $this->_sections['ipa']['loop'];
$this->_sections['ipa']['step'] = 1;
$this->_sections['ipa']['start'] = $this->_sections['ipa']['step'] > 0 ? 0 : $this->_sections['ipa']['loop']-1;
if ($this->_sections['ipa']['show']) {
    $this->_sections['ipa']['total'] = $this->_sections['ipa']['loop'];
    if ($this->_sections['ipa']['total'] == 0)
        $this->_sections['ipa']['show'] = false;
} else
    $this->_sections['ipa']['total'] = 0;
if ($this->_sections['ipa']['show']):

            for ($this->_sections['ipa']['index'] = $this->_sections['ipa']['start'], $this->_sections['ipa']['iteration'] = 1;
                 $this->_sections['ipa']['iteration'] <= $this->_sections['ipa']['total'];
                 $this->_sections['ipa']['index'] += $this->_sections['ipa']['step'], $this->_sections['ipa']['iteration']++):
$this->_sections['ipa']['rownum'] = $this->_sections['ipa']['iteration'];
$this->_sections['ipa']['index_prev'] = $this->_sections['ipa']['index'] - $this->_sections['ipa']['step'];
$this->_sections['ipa']['index_next'] = $this->_sections['ipa']['index'] + $this->_sections['ipa']['step'];
$this->_sections['ipa']['first']      = ($this->_sections['ipa']['iteration'] == 1);
$this->_sections['ipa']['last']       = ($this->_sections['ipa']['iteration'] == $this->_sections['ipa']['total']);
?>
<tr><td align="center"><a href="<?php echo $this->_tpl_vars['ipartners'][$this->_sections['ipa']['index']]['url']; ?>
" target="_blank"><?php if ($this->_tpl_vars['ipartners'][$this->_sections['ipa']['index']]['logo']): ?><img src="<?php echo $this->_tpl_vars['ipartners'][$this->_sections['ipa']['index']]['logo']; ?>
" border="0" alt="<?php echo $this->_tpl_vars['ipartners'][$this->_sections['ipa']['index']]['name']; ?>
"><?php else:  echo $this->_tpl_vars['ipartners'][$this->_sections['ipa']['index']]['name'];  endif; ?></a></td></tr>
<?php endfor; endif;  endif; ?>
</table><br>
<a href="<?php echo ((is_array($_tmp="?a=partners")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class=smalllink>All Partners</a></div>
</div>
</div>