<?php /* Smarty version 2.6.2, created on 2012-05-23 20:10:53
         compiled from newlistings_box.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'newlistings_box.tpl', 8, false),)), $this); ?>
<div class="box">
<div class="box_title">New Listings</div>
<div class="box_body">
<?php if (isset($this->_sections['l'])) unset($this->_sections['l']);
$this->_sections['l']['name'] = 'l';
$this->_sections['l']['loop'] = is_array($_loop=$this->_tpl_vars['new_listings']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['l']['show'] = true;
$this->_sections['l']['max'] = $this->_sections['l']['loop'];
$this->_sections['l']['step'] = 1;
$this->_sections['l']['start'] = $this->_sections['l']['step'] > 0 ? 0 : $this->_sections['l']['loop']-1;
if ($this->_sections['l']['show']) {
    $this->_sections['l']['total'] = $this->_sections['l']['loop'];
    if ($this->_sections['l']['total'] == 0)
        $this->_sections['l']['show'] = false;
} else
    $this->_sections['l']['total'] = 0;
if ($this->_sections['l']['show']):

            for ($this->_sections['l']['index'] = $this->_sections['l']['start'], $this->_sections['l']['iteration'] = 1;
                 $this->_sections['l']['iteration'] <= $this->_sections['l']['total'];
                 $this->_sections['l']['index'] += $this->_sections['l']['step'], $this->_sections['l']['iteration']++):
$this->_sections['l']['rownum'] = $this->_sections['l']['iteration'];
$this->_sections['l']['index_prev'] = $this->_sections['l']['index'] - $this->_sections['l']['step'];
$this->_sections['l']['index_next'] = $this->_sections['l']['index'] + $this->_sections['l']['step'];
$this->_sections['l']['first']      = ($this->_sections['l']['iteration'] == 1);
$this->_sections['l']['last']       = ($this->_sections['l']['iteration'] == $this->_sections['l']['total']);
?>
<?php if ($this->_tpl_vars['new_listings'][$this->_sections['l']['index']]['data_type'] == 'date'): ?>
<div style="border-bottom:#666666 1px dotted" align="left" class="nlt"><b><?php echo $this->_tpl_vars['new_listings'][$this->_sections['l']['index']]['date']; ?>
 </b></div>
<?php else: ?>
<div class="arr" align="left"><a href="<?php echo ((is_array($_tmp="?a=go&lid=".($this->_tpl_vars['new_listings'][$this->_sections['l']['index']]['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" target="_blank"><b><?php echo $this->_tpl_vars['new_listings'][$this->_sections['l']['index']]['name']; ?>
</b></a> &nbsp;<small><i><?php if ($this->_tpl_vars['new_listings'][$this->_sections['l']['index']]['hyip_status'] == 1): ?><font color="#009900">PAYING</font><?php endif; ?>
   <?php if ($this->_tpl_vars['new_listings'][$this->_sections['l']['index']]['hyip_status'] == 2): ?><font color="brown">WAITING</font><?php endif; ?>
   <?php if ($this->_tpl_vars['new_listings'][$this->_sections['l']['index']]['hyip_status'] == 3): ?><font color="orange">PROBLEM</font><?php endif; ?>
   <?php if ($this->_tpl_vars['new_listings'][$this->_sections['l']['index']]['hyip_status'] == 4): ?><font color="red">NOT PAYING</font><?php endif; ?></i></small></div>
<div align="left"><?php echo $this->_tpl_vars['new_listings'][$this->_sections['l']['index']]['percents']; ?>
</div><br>
<?php endif; ?>
<?php endfor; endif; ?>
</div>
</div>