<?php /* Smarty version 2.6.2, created on 2012-05-23 20:11:53
         compiled from allrcbrequest.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'allrcbrequest.tpl', 23, false),)), $this); ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div class="box">
<div class="box_title" id="tba">All RCB Requests History</div>
<div class="box_body">
<div style="background:gold;padding:4px 0 6px 1px;">Total User Deposited: <b style="color:green">$<?php echo $this->_tpl_vars['deposits']; ?>
</b> &nbsp; Total RCB: <b style="color:green">$<?php echo $this->_tpl_vars['rcbs']; ?>
</b> &nbsp; Total Paid RCB: <b style="color:green">$<?php echo $this->_tpl_vars['paidrcb']; ?>
</b></div><br>
<?php if ($this->_tpl_vars['allrcbdata']): ?>
<?php if (isset($this->_sections['d'])) unset($this->_sections['d']);
$this->_sections['d']['name'] = 'd';
$this->_sections['d']['loop'] = is_array($_loop=$this->_tpl_vars['allrcbdata']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['d']['show'] = true;
$this->_sections['d']['max'] = $this->_sections['d']['loop'];
$this->_sections['d']['step'] = 1;
$this->_sections['d']['start'] = $this->_sections['d']['step'] > 0 ? 0 : $this->_sections['d']['loop']-1;
if ($this->_sections['d']['show']) {
    $this->_sections['d']['total'] = $this->_sections['d']['loop'];
    if ($this->_sections['d']['total'] == 0)
        $this->_sections['d']['show'] = false;
} else
    $this->_sections['d']['total'] = 0;
if ($this->_sections['d']['show']):

            for ($this->_sections['d']['index'] = $this->_sections['d']['start'], $this->_sections['d']['iteration'] = 1;
                 $this->_sections['d']['iteration'] <= $this->_sections['d']['total'];
                 $this->_sections['d']['index'] += $this->_sections['d']['step'], $this->_sections['d']['iteration']++):
$this->_sections['d']['rownum'] = $this->_sections['d']['iteration'];
$this->_sections['d']['index_prev'] = $this->_sections['d']['index'] - $this->_sections['d']['step'];
$this->_sections['d']['index_next'] = $this->_sections['d']['index'] + $this->_sections['d']['step'];
$this->_sections['d']['first']      = ($this->_sections['d']['iteration'] == 1);
$this->_sections['d']['last']       = ($this->_sections['d']['iteration'] == $this->_sections['d']['total']);
?>
<table cellspacing=0 cellpadding=0 border=0 width=100%>  
<tr><td width=50% align="left"><font color="green"><?php echo $this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['rdate']; ?>
</font></td></tr>
</table>
<table cellspacing=0 cellpadding=0 width=100% style="border: 1px dotted #CCCCCC;">
<tr bgcolor="#EEEEEE">
<td align="center">#</td>
<td align="center">Program</td>
<td align="center">Deposit/RCB</td>
<td align="center">User</td>
<td align="center">eCurrency A/C</td>
<td align="center">Status</td>
</tr>
<?php if (isset($this->_sections['t'])) unset($this->_sections['t']);
$this->_sections['t']['name'] = 't';
$this->_sections['t']['loop'] = is_array($_loop=$this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['t']['show'] = true;
$this->_sections['t']['max'] = $this->_sections['t']['loop'];
$this->_sections['t']['step'] = 1;
$this->_sections['t']['start'] = $this->_sections['t']['step'] > 0 ? 0 : $this->_sections['t']['loop']-1;
if ($this->_sections['t']['show']) {
    $this->_sections['t']['total'] = $this->_sections['t']['loop'];
    if ($this->_sections['t']['total'] == 0)
        $this->_sections['t']['show'] = false;
} else
    $this->_sections['t']['total'] = 0;
if ($this->_sections['t']['show']):

            for ($this->_sections['t']['index'] = $this->_sections['t']['start'], $this->_sections['t']['iteration'] = 1;
                 $this->_sections['t']['iteration'] <= $this->_sections['t']['total'];
                 $this->_sections['t']['index'] += $this->_sections['t']['step'], $this->_sections['t']['iteration']++):
$this->_sections['t']['rownum'] = $this->_sections['t']['iteration'];
$this->_sections['t']['index_prev'] = $this->_sections['t']['index'] - $this->_sections['t']['step'];
$this->_sections['t']['index_next'] = $this->_sections['t']['index'] + $this->_sections['t']['step'];
$this->_sections['t']['first']      = ($this->_sections['t']['iteration'] == 1);
$this->_sections['t']['last']       = ($this->_sections['t']['iteration'] == $this->_sections['t']['total']);
?>
<tr bgcolor=<?php if ($this->_sections['t']['rownum'] % 2 == 0): ?>#FFFFF2<?php else: ?>#CCFF99<?php endif; ?>>
<td align="center"><?php echo $this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['no']; ?>
.</td>
<td align="center"><a href="<?php echo ((is_array($_tmp="?a=go&lid=".($this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['lid']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" target="_blank"><?php echo $this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['name']; ?>
</td>
<td align="center">$<?php echo $this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['deposit']; ?>
/<font color="green">$<?php echo $this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['rcb']; ?>
</font></td>
<td align="center"><?php echo $this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['username']; ?>
</td>
<td align="center"><?php echo $this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['ec']; ?>
(<?php echo $this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['ecno']; ?>
)</td>
<td align="center"><?php if ($this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['status'] == 0): ?>Waiting For Check...<?php elseif ($this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['status'] == 1): ?>Paid<?php if ($this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['batch']): ?>(batch=<?php echo $this->_tpl_vars['allrcbdata'][$this->_sections['d']['index']]['data'][$this->_sections['t']['index']]['batch']; ?>
)<?php endif;  else: ?>Declined<?php endif; ?></td>
</tr>
<?php endfor; endif; ?>
</table>
<br>
<?php endfor; endif; ?>
<?php else: ?>
<table cellspacing=0 cellpadding=0 border=0 width=100%>  
<tr><td align="center">Currently there are no data in database</td></tr>
</table>
<?php endif; ?>

<?php if ($this->_tpl_vars['colpages'] > 1): ?>
<center>
<?php if ($this->_tpl_vars['prev_page'] > 0): ?> <a href="/?a=allrcbrequestinfo&page=<?php echo $this->_tpl_vars['prev_page']; ?>
">&lt;&lt;</a> <?php endif; ?>
<?php if (isset($this->_sections['p'])) unset($this->_sections['p']);
$this->_sections['p']['name'] = 'p';
$this->_sections['p']['loop'] = is_array($_loop=$this->_tpl_vars['pages']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['p']['show'] = true;
$this->_sections['p']['max'] = $this->_sections['p']['loop'];
$this->_sections['p']['step'] = 1;
$this->_sections['p']['start'] = $this->_sections['p']['step'] > 0 ? 0 : $this->_sections['p']['loop']-1;
if ($this->_sections['p']['show']) {
    $this->_sections['p']['total'] = $this->_sections['p']['loop'];
    if ($this->_sections['p']['total'] == 0)
        $this->_sections['p']['show'] = false;
} else
    $this->_sections['p']['total'] = 0;
if ($this->_sections['p']['show']):

            for ($this->_sections['p']['index'] = $this->_sections['p']['start'], $this->_sections['p']['iteration'] = 1;
                 $this->_sections['p']['iteration'] <= $this->_sections['p']['total'];
                 $this->_sections['p']['index'] += $this->_sections['p']['step'], $this->_sections['p']['iteration']++):
$this->_sections['p']['rownum'] = $this->_sections['p']['iteration'];
$this->_sections['p']['index_prev'] = $this->_sections['p']['index'] - $this->_sections['p']['step'];
$this->_sections['p']['index_next'] = $this->_sections['p']['index'] + $this->_sections['p']['step'];
$this->_sections['p']['first']      = ($this->_sections['p']['iteration'] == 1);
$this->_sections['p']['last']       = ($this->_sections['p']['iteration'] == $this->_sections['p']['total']);
?>
<?php if ($this->_tpl_vars['pages'][$this->_sections['p']['index']]['current'] == 1): ?>
 <?php echo $this->_tpl_vars['pages'][$this->_sections['p']['index']]['page']; ?>

<?php else: ?> <a href="/?a=allrcbrequestinfo&page=<?php echo $this->_tpl_vars['pages'][$this->_sections['p']['index']]['page']; ?>
"><?php echo $this->_tpl_vars['pages'][$this->_sections['p']['index']]['page']; ?>
</a> <?php endif; ?>
<?php endfor; endif; ?>
<?php if ($this->_tpl_vars['next_page'] > 0): ?> <a href="/?a=allrcbrequestinfo&page=<?php echo $this->_tpl_vars['next_page']; ?>
">&gt;&gt;</a> <?php endif; ?>
</center>
<?php endif; ?>

</div></div>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>