{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">Support Form:</div>
<div class="box_body">

{if $say eq 'send'}
<div style="color:green" align="center">Message has been successfully sent. We will back to you in next 24 hours. Thank you.</div><br><br>
{else}
{if $errors}
<ul style="color:red">
{if $errors.turing}<li> Invalid turing image.</li>{/if}
{if $errors.email}<li> Please enter your e-mail addresss.</li>{/if}
{if $errors.invalid_email}<li> Please enter valid e-mail address.</li>{/if}
</ul>
{/if}

<script language=javascript>
{literal}
function checkform() {
  if (document.mainform.name.value == '') {
    alert("Please type your full name!");
    document.mainform.name.focus();
    return false;
  }
  if (document.mainform.email.value == '') {
    alert("Please enter your e-mail address!");
    document.mainform.email.focus();
    return false;
  }
  if (document.mainform.message.value == '') {
    alert("Please type your message!");
    document.mainform.message.focus();
    return false;
  }
  return true;
}
{/literal}
</script>
<form method=post name=mainform onsubmit="return checkform()">
<input type=hidden name="a" value="support">
<input type=hidden name="action" value="send">
<table cellspacing=0 cellpadding=2 border=0 align="center">
<tr>
 <td>Your Name:</td>
 <td><input type="text" name="name" size=30 class=inpts></td>
</tr>
<tr>
 <td>Your Email:</td>
 <td><input type="text" name="email" size=30 class=inpts></td>
</tr>
<tr>
 <td>Message:</td>
 <td><textarea name=message class=inpts cols=65 rows=6></textarea>
</tr>
{if $settings.use_turing}
<tr>
  <td><img src="{"?a=turing&`$sesname`=`$sesid`&r=`$rand`"|encurl}" alt="turing code" align="absmiddle"></td>
 <td><input type=text name="turing" maxlength="6" size="10" class="inpts"></td>
</tr>
{/if}
<tr>
 <td>&nbsp;</td>
 <td><input type=submit value="Send" class=sbmt></td>
</tr></table>
</form>
{/if}
</div></div>
{include file="footer.tpl"}