<div class="box">
<div class="box_title">{if $userinfo.logged}Menu{else}Members{/if}</div>
<div class="box_body">

{if $userinfo.logged != 1}
{literal}
<script type="text/javascript">
function checklogin() {   
  if (document.loginform.username.value=='') {
    alert("Please enter your username!");
    document.loginform.username.focus();
    return false;
  }
  if (document.loginform.password.value=='') {
    alert("Please enter your password!");
    document.loginform.password.focus();
    return false;
  }
  return true;
}
</script>
{/literal}
<form method="post" name="loginform" onsubmit="return checklogin()" action="">
<input type=hidden name="a" value="do_login">
<input type=hidden name="referrer" value="{$login_referrer}">
<table cellpadding="1" cellspacing="1" border="0">
<tr>
 <td>Username:</td>
 <td><input type="text" name="username" class="inpts" size="20"></td>
</tr>
<tr>
 <td>Password:</td>
 <td><input type="password" name="password" class="inpts" size="20"></td>
</tr>
{if $settings.use_turing}
<tr>
  <th><img src="{"?a=turing&`$sesname`=`$sesid`&r=`$rand`"|encurl}" alt="turing code"></th>
  <td><input type=text name="turing" maxlength="6" class="inpts" size="10"></td>
</tr>
{/if}
<tr>
 <td>&nbsp;</td>
 <td><input type="submit" value="Login" class="sbmt"></td>
</tr>
</table>
</form>
<p class="links"><a href="{"?a=signup"|encurl}">Sign Up</a> | <a href="{"?a=forgot_password"|encurl}">Forgot Password?</a></p>

{else}
<table cellpadding="2" cellspacing="2" border="0">
<tr>
 <td>
<ul class="menu">
<li><a href="{"?a=bookmarks"|encurl}">My HYIP List</a></li>
<li><a href="{"?a=refback_requests"|encurl}">RCB Requests</a></li>
<li><a href="{"?a=profile"|encurl}">Edit Profile</a></li>
<li><a href="{"?a=logout"|encurl}">Logout</a></li></td>
</tr>
</table>
{/if}
</div></div>