{include file="header.tpl"}

{literal}
<script language=javascript><!--
function viewStatistics(id)
{
  w = 400; h = 600;
  t = (screen.height-h-30)/2;
  l = (screen.width-w-30)/2;
  window.open('?a=view_statistics&lid=' + id, 'view_statistics' + id, "top="+t+",left="+l+",width="+w+",height="+h+",resizable=1,scrollbars=1");
}
--></script>
{/literal}
<div class="box">
<div class="box_title">My HYIP List</div>
<div class="box_body">

{section name=l loop=$listings}
{assign var="listing" value=$listings[l]}

{if $listing.type == 'Exclusive'}
{include file="details_exclusive.tpl"}
{/if}
{if $listing.type == 'Premium'}
{include file="details_premium.tpl"}
{/if}
{if $listing.type == 'Normal'}
{include file="details_normal.tpl"}
{/if}
{if $listing.type == 'Trial'}
{include file="details_trial.tpl"}
{/if}
{if $listing.type == 'Autosurf'}
{include file="details_autosurf.tpl"}
{/if}
{if $listing.type == 'Free'}
{include file="details_free.tpl"}
{/if}
{if $listing.type == 'Games'}
{include file="details_games.tpl"}
{/if}
{if $listing.type == 'Scam'}
{include file="details_scam.tpl"}
{/if}
{if $listing.type == 'Closed'}
{include file="details_closed.tpl"}
{/if}
{sectionelse}
<br>
<div align="center">You have not added any programs to your bookmarks yet.</div>
<br><br>
{/section}
</div></div>
{include file="footer.tpl"}