<?php /* Smarty version 2.6.2, created on 2012-03-23 20:12:39
         compiled from paysystems_box.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'paysystems_box.tpl', 10, false),)), $this); ?>
<?php 
global $settings;
$this->_tpl_vars[payments_box] = preg_split ('/\s*,\s*/', $settings['payments']);
 ?>
<div class="box">
	<div class="box_title">PAYMENT SYSTEMS</div>
	<div class="box_body">
<table cellpadding="0" cellspacing="2" border="0">
<?php if (isset($this->_sections['pb'])) unset($this->_sections['pb']);
$this->_sections['pb']['name'] = 'pb';
$this->_sections['pb']['loop'] = is_array($_loop=$this->_tpl_vars['payments_box']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['pb']['show'] = true;
$this->_sections['pb']['max'] = $this->_sections['pb']['loop'];
$this->_sections['pb']['step'] = 1;
$this->_sections['pb']['start'] = $this->_sections['pb']['step'] > 0 ? 0 : $this->_sections['pb']['loop']-1;
if ($this->_sections['pb']['show']) {
    $this->_sections['pb']['total'] = $this->_sections['pb']['loop'];
    if ($this->_sections['pb']['total'] == 0)
        $this->_sections['pb']['show'] = false;
} else
    $this->_sections['pb']['total'] = 0;
if ($this->_sections['pb']['show']):

            for ($this->_sections['pb']['index'] = $this->_sections['pb']['start'], $this->_sections['pb']['iteration'] = 1;
                 $this->_sections['pb']['iteration'] <= $this->_sections['pb']['total'];
                 $this->_sections['pb']['index'] += $this->_sections['pb']['step'], $this->_sections['pb']['iteration']++):
$this->_sections['pb']['rownum'] = $this->_sections['pb']['iteration'];
$this->_sections['pb']['index_prev'] = $this->_sections['pb']['index'] - $this->_sections['pb']['step'];
$this->_sections['pb']['index_next'] = $this->_sections['pb']['index'] + $this->_sections['pb']['step'];
$this->_sections['pb']['first']      = ($this->_sections['pb']['iteration'] == 1);
$this->_sections['pb']['last']       = ($this->_sections['pb']['iteration'] == $this->_sections['pb']['total']);
?>
<tr><td width="60" align="right"><img src="<?php echo ((is_array($_tmp="images/".($this->_tpl_vars['payments_box'][$this->_sections['pb']['index']]).".gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" border=0 alt="<?php echo $this->_tpl_vars['payments_box'][$this->_sections['pb']['index']]; ?>
" title="<?php echo $this->_tpl_vars['payments_box'][$this->_sections['pb']['index']]; ?>
"></td><td align=left>List <a class=smalllink href="<?php echo ((is_array($_tmp="?pfilter=".($this->_tpl_vars['payments_box'][$this->_sections['pb']['index']]))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><?php echo $this->_tpl_vars['payments_box'][$this->_sections['pb']['index']]; ?>
</a><br> program</td></tr>
<?php endfor; endif; ?>
</table>
</div>
</div>