<div class="box">
<div class="box_title" id="tep">{$groups[g].name} Listing</div>
<div class="box_body">
{if !$settings.hidehn3}
<div style="background:#FFFFF2;border-bottom:#ececec 1px solid;">{include file="ads_exclusive_banners.tpl"}</div>
{/if}
{section name=l loop=$groups[g].listings}
{assign var='listing' value=$groups[g].listings[l]}
{include file="details_exclusive.tpl"}
{/section}
</div></div>