<?php /* Smarty version 2.6.2, created on 2012-05-23 20:13:00
         compiled from details.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'details.tpl', 127, false),)), $this); ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<script language="javascript">
userAccounts = Array();
<?php if (isset($this->_sections['p'])) unset($this->_sections['p']);
$this->_sections['p']['name'] = 'p';
$this->_sections['p']['loop'] = is_array($_loop=$this->_tpl_vars['useracs']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['p']['show'] = true;
$this->_sections['p']['max'] = $this->_sections['p']['loop'];
$this->_sections['p']['step'] = 1;
$this->_sections['p']['start'] = $this->_sections['p']['step'] > 0 ? 0 : $this->_sections['p']['loop']-1;
if ($this->_sections['p']['show']) {
    $this->_sections['p']['total'] = $this->_sections['p']['loop'];
    if ($this->_sections['p']['total'] == 0)
        $this->_sections['p']['show'] = false;
} else
    $this->_sections['p']['total'] = 0;
if ($this->_sections['p']['show']):

            for ($this->_sections['p']['index'] = $this->_sections['p']['start'], $this->_sections['p']['iteration'] = 1;
                 $this->_sections['p']['iteration'] <= $this->_sections['p']['total'];
                 $this->_sections['p']['index'] += $this->_sections['p']['step'], $this->_sections['p']['iteration']++):
$this->_sections['p']['rownum'] = $this->_sections['p']['iteration'];
$this->_sections['p']['index_prev'] = $this->_sections['p']['index'] - $this->_sections['p']['step'];
$this->_sections['p']['index_next'] = $this->_sections['p']['index'] + $this->_sections['p']['step'];
$this->_sections['p']['first']      = ($this->_sections['p']['iteration'] == 1);
$this->_sections['p']['last']       = ($this->_sections['p']['iteration'] == $this->_sections['p']['total']);
?>
userAccounts['<?php echo $this->_tpl_vars['useracs'][$this->_sections['p']['index']]['name']; ?>
'] = '<?php echo $this->_tpl_vars['useracs'][$this->_sections['p']['index']]['account']; ?>
';
<?php endfor; endif; ?>

<?php echo '
function procVote()
{
  d = document.vote;
  if (!d.email) return true;

  if (!d.email.value)
  {
    alert(\'Please, enter your E-Mail address!\');
    d.email.focus();
    return false;
  }
  else
  {
    a = d.email.value.indexOf(\'@\');
    b = d.email.value.indexOf(\'@\', a+1);
    c = d.email.value.lastIndexOf(\'.\');
    if (c < a+1) { c = -1; }
    if (a == -1 || b != -1 || c <= a + 2 || a < 1 || c + 2 >= d.email.value.length || c + 4 < d.email.value.length)
    {
      alert(\'Please, enter a valid E-Mail Address\');
      d.email.focus();
      return false;
    }
  }
  return true;
}
function textCounter(field, countfield, maxlimit) {
 if (field.value.length > maxlimit){
    field.value = field.value.substring(0, maxlimit);
 }
 else {
       countfield.value = maxlimit - field.value.length;
     }
 }

function vrcbdate() {
  var d = document.rcb_form;
  if (!d.username.value) {
    alert(\'Please enter your user name.\');
    d.username.focus();
    return false;
  }
  if (!d.psaccount.value) {
    alert(\'Please enter your Payment System Account\');
    d.psaccount.focus();
    return false;
  }
  if (!d.deposit.value) {
    alert(\'Please enter your deposit.\');
    d.deposit.focus();
    return false;
  }
  if (isNaN(d.deposit.value)) {
    alert(\'Please enter Number only.\');
    d.deposit.select();
    return false;
   }   
  if (!d.email.value) {
    alert(\'Please, enter your E-Mail address!\');
    d.email.focus();
    return false;
  }
  return true;
}

function setDefAccount() {
  obj = document.rcb_form.paysystem;
  objd = document.rcb_form.psaccount;
  if (!obj) return;
  i = obj.selectedIndex; o = obj.options;
  n = o[i].value;
  if (userAccounts[n]) objd.value = userAccounts[n];
  else objd.value = \'\';
}

'; ?>

</script>
<div class="box">
<div class="box_title" id="tba">PROGRAM DETAILS</div>
<div class="box_body">
<?php if ($this->_tpl_vars['group']['type'] == 'Exclusive'): ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_exclusive.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php endif; ?>
<?php if ($this->_tpl_vars['group']['type'] == 'Premium'): ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_premium.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php endif; ?>
<?php if ($this->_tpl_vars['group']['type'] == 'Normal'): ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_normal.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php endif; ?>
<?php if ($this->_tpl_vars['group']['type'] == 'Trial'): ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_trial.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php endif; ?>
<?php if ($this->_tpl_vars['group']['type'] == 'Free'): ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_free.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php endif; ?>
<?php if ($this->_tpl_vars['group']['type'] == 'Games'): ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_games.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php endif; ?>
<?php if ($this->_tpl_vars['group']['type'] == 'Scam'): ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_scam.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php endif; ?>
<?php if ($this->_tpl_vars['group']['type'] == 'Closed'): ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_closed.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php endif; ?>
<div class="dline"></div>
<div id="data_type">
<?php if ($this->_tpl_vars['aj'] == 'button'):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_button.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php elseif ($this->_tpl_vars['aj'] == 'votes'):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_vote.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php elseif ($this->_tpl_vars['aj'] == 'paystat'):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_paystat.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php elseif ($this->_tpl_vars['aj'] == 'rcb'):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_rcb.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<script>setDefAccount();</script>
<?php elseif ($this->_tpl_vars['aj'] == 'whois'):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_whois.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php elseif ($this->_tpl_vars['aj'] == 'report_scam'):  $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "details_report_scam.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<?php else: ?>
<table width=100% border=0 align="center" cellpadding=3 cellspacing=0>
<tr><td colspan="2"><b>Ratings stats of <?php echo $this->_tpl_vars['listing']['name']; ?>
</b></td>
</tr>
<tr>
  <td width="12%" align="right">Very Good:</td><td width="13%"><img src="<?php echo ((is_array($_tmp="images/r3.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Very Good" title="Very Good" align="absmiddle"> <?php echo $this->_tpl_vars['listing']['votes_summary']['3']['count']; ?>
 votes</td>
  <td><img src="<?php echo ((is_array($_tmp="images/r_dot.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="<?php echo $this->_tpl_vars['listing']['votes_summary']['3']['percent']; ?>
" height="10" align="absmiddle" title="<?php echo $this->_tpl_vars['listing']['votes_summary']['3']['count']; ?>
 votes (<?php echo $this->_tpl_vars['listing']['votes_summary']['3']['percent']; ?>
%)"> (<?php echo $this->_tpl_vars['listing']['votes_summary']['3']['percent']; ?>
%)</td>
</tr>
<tr>
  <td align="right">Good:</td><td><img src="<?php echo ((is_array($_tmp="images/r2.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Good" title="Good" align="absmiddle"> <?php echo $this->_tpl_vars['listing']['votes_summary']['2']['count']; ?>
 votes</td>
  <td><img src="<?php echo ((is_array($_tmp="images/y_dot.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="<?php echo $this->_tpl_vars['listing']['votes_summary']['2']['percent']; ?>
" height="10" align="absmiddle" title="<?php echo $this->_tpl_vars['listing']['votes_summary']['2']['count']; ?>
 votes (<?php echo $this->_tpl_vars['listing']['votes_summary']['2']['percent']; ?>
%)"> (<?php echo $this->_tpl_vars['listing']['votes_summary']['2']['percent']; ?>
%)</td>
  </tr>
  <tr>
    <td align="right">bad:</td><td><img src="<?php echo ((is_array($_tmp="images/r1.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Bad" title="Bad" align="absmiddle"> <?php echo $this->_tpl_vars['listing']['votes_summary']['1']['count']; ?>
 votes</td>
    <td><img src="<?php echo ((is_array($_tmp="images/g_dot.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="<?php echo $this->_tpl_vars['listing']['votes_summary']['1']['percent']; ?>
" height="10" align="absmiddle" title="<?php echo $this->_tpl_vars['listing']['votes_summary']['1']['count']; ?>
 votes (<?php echo $this->_tpl_vars['listing']['votes_summary']['1']['percent']; ?>
%)"> (<?php echo $this->_tpl_vars['listing']['votes_summary']['1']['percent']; ?>
%)</td>
  </tr>
  <tr>
    <td align="right">very bad:</td><td><img src="<?php echo ((is_array($_tmp="images/r0.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Very Bad" title="Very Bad" align="absmiddle"> <?php echo $this->_tpl_vars['listing']['votes_summary']['0']['count']; ?>
 votes</td>
    <td><img src="<?php echo ((is_array($_tmp="images/b_dot.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" width="<?php echo $this->_tpl_vars['listing']['votes_summary']['0']['percent']; ?>
" height="10" align="absmiddle" title="<?php echo $this->_tpl_vars['listing']['votes_summary']['0']['count']; ?>
 votes (<?php echo $this->_tpl_vars['listing']['votes_summary']['0']['percent']; ?>
%)"> (<?php echo $this->_tpl_vars['listing']['votes_summary']['0']['percent']; ?>
%)</td>
</tr>
</table>

<br />
<?php if ($this->_tpl_vars['votes']): ?>
<table cellspacing=0 cellpadding=2 border=0 width=100%>
<tr><td colspan="4" class="newlistingsdatetitle"><strong>User Votes</strong></td>
</tr>
<tr>
  <td align=center class=title><strong>Rating</strong></td>
  <td align=center class=title><strong>Voter IP</strong></td>
  <td align=center class=title><strong>User E-Mail</strong></td>
  <td align=center class=title><strong>Vote Date</strong></td>
</tr>

<?php if (isset($this->_sections['v'])) unset($this->_sections['v']);
$this->_sections['v']['name'] = 'v';
$this->_sections['v']['loop'] = is_array($_loop=$this->_tpl_vars['votes']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['v']['show'] = true;
$this->_sections['v']['max'] = $this->_sections['v']['loop'];
$this->_sections['v']['step'] = 1;
$this->_sections['v']['start'] = $this->_sections['v']['step'] > 0 ? 0 : $this->_sections['v']['loop']-1;
if ($this->_sections['v']['show']) {
    $this->_sections['v']['total'] = $this->_sections['v']['loop'];
    if ($this->_sections['v']['total'] == 0)
        $this->_sections['v']['show'] = false;
} else
    $this->_sections['v']['total'] = 0;
if ($this->_sections['v']['show']):

            for ($this->_sections['v']['index'] = $this->_sections['v']['start'], $this->_sections['v']['iteration'] = 1;
                 $this->_sections['v']['iteration'] <= $this->_sections['v']['total'];
                 $this->_sections['v']['index'] += $this->_sections['v']['step'], $this->_sections['v']['iteration']++):
$this->_sections['v']['rownum'] = $this->_sections['v']['iteration'];
$this->_sections['v']['index_prev'] = $this->_sections['v']['index'] - $this->_sections['v']['step'];
$this->_sections['v']['index_next'] = $this->_sections['v']['index'] + $this->_sections['v']['step'];
$this->_sections['v']['first']      = ($this->_sections['v']['iteration'] == 1);
$this->_sections['v']['last']       = ($this->_sections['v']['iteration'] == $this->_sections['v']['total']);
?>
<tr class=<?php if ($this->_sections['v']['rownum'] % 2 == 0): ?>detailsbg1<?php else: ?>detailsbg2<?php endif; ?>>
  <td align=center>
   <?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 0): ?><img src="<?php echo ((is_array($_tmp="images/r0.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Very Bad" title="Very Bad"><?php endif; ?>
   <?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 1): ?><img src="<?php echo ((is_array($_tmp="images/r1.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Bad" title="Bad"><?php endif; ?>
   <?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 2): ?><img src="<?php echo ((is_array($_tmp="images/r2.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Good" title="Good"><?php endif; ?>
   <?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 3): ?><img src="<?php echo ((is_array($_tmp="images/r3.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="Very Good" title="Very Good"><?php endif; ?>
  </td>
  <td align=center><img src="<?php echo ((is_array($_tmp="images/c/".($this->_tpl_vars['votes'][$this->_sections['v']['index']]['flag']).".gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" align="absmiddle" alt="<?php echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['flag']; ?>
" title="<?php echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['flag']; ?>
" style="cursor:help;"> <?php echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['ip']; ?>
</td>
  <td align=center><?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['username']):  echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['username'];  else:  echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['email'];  endif; ?></td>
  <td align=center><?php echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['fdate']; ?>
</td>
</tr>
<?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['comment']): ?>
<tr>
  <td colspan=4><img src="<?php echo ((is_array($_tmp="images/vcom.gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt=""> <font color="<?php if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 0): ?>red<?php endif;  if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 1): ?>orange<?php endif;  if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 2): ?>#CBA903<?php endif;  if ($this->_tpl_vars['votes'][$this->_sections['v']['index']]['vote'] == 3): ?>#008800<?php endif; ?>"><?php echo $this->_tpl_vars['votes'][$this->_sections['v']['index']]['comment']; ?>
</td>
</tr>
<?php endif; ?>
<?php endfor; endif; ?>
</table>
<?php endif; ?>
<?php endif; ?>

</div>
</div></div>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>