{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">Vote Accepted</div>
<div class="box_body">
<table cellspacing=1 cellpadding=2 border=0 width=100%>
<tr>
 <td align=center>
 Thank you for voting for <b>{$listing.name}</b><br>
{if $frm.success == 1}
Your vote has been successfully added.
{/if}
{if $frm.success == 2}
Your vote has been successfully updated.
{/if}
 <br><br>
<a href="{"?a=details&lid=`$frm.lid`"|encurl}">Return to the listing details</a>
 </td>
</tr>
</table>
</div></div>
{include file="footer.tpl"}