<script src="{"js/ads_box_l.js"|encurl}"></script>

{if $ads.9[0].no}
<script>left_ads("{"?gotoads=9&id=`$ads.9[0].no`"|encurl}","{$ads.9[0].imgurl}","{$ads.9[0].desc}","{if $ads.9[0].format == 'flash'}f{else}p{/if}")</script>
{else}
<script>left_ads("{"?a=advertise&ad=9"|encurl}","{"images/125.png"|encurl}","Advertise your banner here","p")</script>
{/if}
