<?php /* Smarty version 2.6.2, created on 2012-05-23 20:12:53
         compiled from support.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'support.tpl', 57, false),)), $this); ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div class="box">
<div class="box_title" id="tba">Support Form:</div>
<div class="box_body">

<?php if ($this->_tpl_vars['say'] == 'send'): ?>
<div style="color:green" align="center">Message has been successfully sent. We will back to you in next 24 hours. Thank you.</div><br><br>
<?php else: ?>
<?php if ($this->_tpl_vars['errors']): ?>
<ul style="color:red">
<?php if ($this->_tpl_vars['errors']['turing']): ?><li> Invalid turing image.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['email']): ?><li> Please enter your e-mail addresss.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['invalid_email']): ?><li> Please enter valid e-mail address.</li><?php endif; ?>
</ul>
<?php endif; ?>

<script language=javascript>
<?php echo '
function checkform() {
  if (document.mainform.name.value == \'\') {
    alert("Please type your full name!");
    document.mainform.name.focus();
    return false;
  }
  if (document.mainform.email.value == \'\') {
    alert("Please enter your e-mail address!");
    document.mainform.email.focus();
    return false;
  }
  if (document.mainform.message.value == \'\') {
    alert("Please type your message!");
    document.mainform.message.focus();
    return false;
  }
  return true;
}
'; ?>

</script>
<form method=post name=mainform onsubmit="return checkform()">
<input type=hidden name="a" value="support">
<input type=hidden name="action" value="send">
<table cellspacing=0 cellpadding=2 border=0 align="center">
<tr>
 <td>Your Name:</td>
 <td><input type="text" name="name" size=30 class=inpts></td>
</tr>
<tr>
 <td>Your Email:</td>
 <td><input type="text" name="email" size=30 class=inpts></td>
</tr>
<tr>
 <td>Message:</td>
 <td><textarea name=message class=inpts cols=65 rows=6></textarea>
</tr>
<?php if ($this->_tpl_vars['settings']['use_turing']): ?>
<tr>
  <td><img src="<?php echo ((is_array($_tmp="?a=turing&".($this->_tpl_vars['sesname'])."=".($this->_tpl_vars['sesid'])."&r=".($this->_tpl_vars['rand']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="turing code" align="absmiddle"></td>
 <td><input type=text name="turing" maxlength="6" size="10" class="inpts"></td>
</tr>
<?php endif; ?>
<tr>
 <td>&nbsp;</td>
 <td><input type=submit value="Send" class=sbmt></td>
</tr></table>
</form>
<?php endif; ?>
</div></div>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>