<table width=100% border=0 align="center" cellpadding=3 cellspacing=0>
<tr><td colspan="2"><b>Whois Record of {$listing.name}</b></td></tr>
<tr><td>{section name=l loop=$whois_data}{$whois_data[l]}{/section}</td></tr>
</table><br>