<?php /* Smarty version 2.6.2, created on 2012-03-23 20:12:39
         compiled from toprcb_box.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'toprcb_box.tpl', 8, false),)), $this); ?>
<div class="box">
<div class="box_title">Top <?php echo $this->_tpl_vars['settings']['toprcb_count']; ?>
 RCB</div>
<div class="box_body">
<table border="0">
<tr><td>
<?php if ($this->_tpl_vars['toprcbs']): ?>
<?php if (isset($this->_sections['t'])) unset($this->_sections['t']);
$this->_sections['t']['name'] = 't';
$this->_sections['t']['loop'] = is_array($_loop=$this->_tpl_vars['toprcbs']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['t']['show'] = true;
$this->_sections['t']['max'] = $this->_sections['t']['loop'];
$this->_sections['t']['step'] = 1;
$this->_sections['t']['start'] = $this->_sections['t']['step'] > 0 ? 0 : $this->_sections['t']['loop']-1;
if ($this->_sections['t']['show']) {
    $this->_sections['t']['total'] = $this->_sections['t']['loop'];
    if ($this->_sections['t']['total'] == 0)
        $this->_sections['t']['show'] = false;
} else
    $this->_sections['t']['total'] = 0;
if ($this->_sections['t']['show']):

            for ($this->_sections['t']['index'] = $this->_sections['t']['start'], $this->_sections['t']['iteration'] = 1;
                 $this->_sections['t']['iteration'] <= $this->_sections['t']['total'];
                 $this->_sections['t']['index'] += $this->_sections['t']['step'], $this->_sections['t']['iteration']++):
$this->_sections['t']['rownum'] = $this->_sections['t']['iteration'];
$this->_sections['t']['index_prev'] = $this->_sections['t']['index'] - $this->_sections['t']['step'];
$this->_sections['t']['index_next'] = $this->_sections['t']['index'] + $this->_sections['t']['step'];
$this->_sections['t']['first']      = ($this->_sections['t']['iteration'] == 1);
$this->_sections['t']['last']       = ($this->_sections['t']['iteration'] == $this->_sections['t']['total']);
?>
<div class="arr" align="left"><a href="<?php echo ((is_array($_tmp="?a=details&aj=rcb&lid=".($this->_tpl_vars['toprcbs'][$this->_sections['t']['index']]['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><b><?php echo $this->_tpl_vars['toprcbs'][$this->_sections['t']['index']]['name']; ?>
</b></a> <font color="green"><?php echo $this->_tpl_vars['toprcbs'][$this->_sections['t']['index']]['mrcb']; ?>
%</font></div>
<?php endfor; endif; ?><br>
<a href="<?php echo ((is_array($_tmp="?a=allrcblist")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">All RCB Programs</a><br>
<a href="<?php echo ((is_array($_tmp="?a=allrcbrequest")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">All RCB Requests</a><br>
<?php else: ?>No data find in database<?php endif; ?>
</td></tr>
</table></div>
</div>



