<div class="banz_b">
{section name=b6 loop=$ads.6}
{if $ads.6[b6].no}
<a href="{"?a=goads&aid=6&id=`$ads.6[b6].no`"|encurl}" target="_blank" title="{$ads.6[b6].desc}">{if $ads.6[b6].format == 'flash'}<embed width="468" height="60" src="{$ads.6[b6].imgurl}"><noembed>{"?a=goads&aid=6&id=`$ads.6[b6].no`"|encurl}</noembed>{else}<img src="{$ads.6[b6].imgurl}" width="468" height="60" alt="{$ads.6[b6].desc}" border="0">{/if}</a><br><a href="{"?a=advertise&ad=6"|encurl}">Advertise your banner here</a> | Expires: {$ads.6[b6].expired}
{else}
<a href="{"?a=advertise&ad=6"|encurl}" title="Advertise your banner here."><img src="{"images/468.gif"|encurl}" width="468" height="60" alt="Advertise your banner here." border="0"></a><br><a href="{"?a=advertise&ad=6"|encurl}">Advertise your banner here</a> | Available Now!</font>
{/if}<br>
{/section}
</div>