{if $topprofitable}
<table border="0">
{section name=tp loop=$topprofitable}
<tr><td align="left"><font color="#999999">{$topprofitable[tp].no}.</font> <a href="{"?a=details&lid=`$topprofitable[tp].id`"|encurl}" target="_blank"><b>{$topprofitable[tp].sub_name}</b></a></td>
<td align="right"><font color="#009900">{$topprofitable[tp].ratio*100|intval}%</font></td></tr>
{/section}
</table><br>
{else}No data find in database<br>
{/if}

