<?php /* Smarty version 2.6.2, created on 2012-05-24 21:22:14
         compiled from paylistfee.tpl */ ?>
<?php if ($this->_tpl_vars['ec'] == 'LR'): ?>
<h2>Redirecting to Liberty Reserve Payment Processing page...</h2>
<form name="lrpaid" method="POST" action="https://sci.libertyreserve.com">
<input type="hidden" name="type" value="<?php echo $this->_tpl_vars['group']['id']; ?>
">
<input type="hidden" name="code" value="<?php echo $this->_tpl_vars['code']; ?>
">
<input type="hidden" name="action" value="checkstatus">
<input type="hidden" name="lr_acc" value="<?php echo $this->_tpl_vars['settings']['lracc']; ?>
">
<input type="hidden" name="lr_store" value="<?php echo $this->_tpl_vars['settings']['lr_storename']; ?>
">
<input type="hidden" name="lr_amnt" value="<?php echo $this->_tpl_vars['amount']; ?>
">
<input type="hidden" name="lr_currency" value="LRUSD">
<input type="hidden" name="lr_comments" value="List: <?php echo $this->_tpl_vars['group']['name']; ?>
">
<input type="hidden" name="lr_success_url" value="<?php echo $this->_tpl_vars['settings']['site_url']; ?>
?a=addprogram&step=2">
<input type="hidden" name="lr_success_url_method" value="POST">
<input type="hidden" name="lr_fail_url" value="<?php echo $this->_tpl_vars['settings']['site_url']; ?>
?a=addprogram">
<input type="hidden" name="lr_fail_url_method" value="POST">
<input type="hidden" name="lr_status_url" value="<?php echo $this->_tpl_vars['settings']['site_url']; ?>
LR_processing.php">
<input type="hidden" name="lr_status_url_method" value="POST">
</form>
<script language="JavaScript">
document.lrpaid.submit();
</script>

<?php elseif ($this->_tpl_vars['ec'] == 'PM'): ?>
<h2>Redirecting to Perfect Money Payment Processing page...</h2>
<form name="pmpaid" action="https://perfectmoney.com/api/step1.asp" method="POST">
    <input type="hidden" name="action" value="checkstatus">
    <input type="hidden" name="type" value="<?php echo $this->_tpl_vars['group']['id']; ?>
">
    <input type="hidden" name="code" value="<?php echo $this->_tpl_vars['code']; ?>
">
    <input type="hidden" name="PAYEE_ACCOUNT" value="<?php echo $this->_tpl_vars['settings']['perfectmoney_acc']; ?>
">
    <input type="hidden" name="PAYEE_NAME" value="<?php echo $this->_tpl_vars['settings']['site_name']; ?>
">
    <input type="hidden" name="PAYMENT_AMOUNT" value="<?php echo $this->_tpl_vars['amount']; ?>
">
    <input type="hidden" name="PAYMENT_UNITS" value="USD">
    <input type="hidden" name="PAYMENT_URL" value="<?php echo $this->_tpl_vars['settings']['site_url']; ?>
?a=addprogram&step=2">
    <input type="hidden" name="NOPAYMENT_URL" value="<?php echo $this->_tpl_vars['settings']['site_url']; ?>
?a=addprogram"">
    <input type="hidden" name="STATUS_URL"  value="<?php echo $this->_tpl_vars['settings']['site_url']; ?>
PM_processing.php">
    <input type="hidden" name="SUGGESTED_MEMO" value="List: <?php echo $this->_tpl_vars['group']['name']; ?>
">
    <input type="hidden" name="BAGGAGE_FIELDS"  value="type action code">
</form>
<script language="JavaScript">
document.pmpaid.submit();
</script>

<?php else: ?>
<script language="JavaScript">
alert("Please choose a Processor!");
history.go(-1);
</script>
<?php endif; ?>