{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">All Referral Commission Back Programs</div>
<div class="box_body">

{section name=n loop=$allrcbs}
<table cellspacing=1 cellpadding=2 border=0 width="100%">
<tr><td><div class="arr"><a href="{"?a=go&lid=`$allrcbs[n].lid`"|encurl}" target="_blank" style="color:#a70000"><b>{$allrcbs[n].name}</b></a></div></td><td align="right"><a href="{"?a=details&aj=rcb&lid=`$allrcbs[n].lid`"|encurl}" style="color:green">Request RCB</a></td></tr></table>
<table cellspacing=1 cellpadding=2 width="100%" style="border: 1px dotted #CCCCCC;" align="center">
<tr bgcolor="#EEEEEE">
<td width=25% align="center" rowspan="2">Deposit Amount</td>
<td width=15% align="center" rowspan="2">Referral</td>
<td width="30%" align="center" colspan="2">1st Deposit</td>
<td width="30%" align="center" colspan="2">Re-Invested</td>
</tr>
<tr bgcolor="#EEEEEE">
<td width=15% align="center">RCB</td>
<td width=15% align="center">BONUS</td>
<td width=15% align="center">RCB</td>
<td width=15% align="center">BONUS</td>
</tr>
{section name=l loop=$allrcbs[n].rates}
<tr bgcolor="#CCFF99">
<td align="center">${$allrcbs[n].rates[l].min_deposit}-${$allrcbs[n].rates[l].max_deposit}</td>
<td align="center">{if $allrcbs[n].rates[l].ref>0} {$allrcbs[n].rates[l].ref}% {else} -- {/if}</td>
<td align="center">{if $allrcbs[n].rates[l].rcb>0} {$allrcbs[n].rates[l].rcb}% {else} -- {/if}</td>
<td align="center">{if $allrcbs[n].rates[l].bonus>0} ${$allrcbs[n].rates[l].bonus} {else} -- {/if}</td>
<td align="center">{if $allrcbs[n].rates[l].rcb2>0} {$allrcbs[n].rates[l].rcb2}% {else} -- {/if}</td>
<td align="center">{if $allrcbs[n].rates[l].bonus2>0} ${$allrcbs[n].rates[l].bonus2} {else} -- {/if}</td>
</tr>
{/section}
</table>
<br>
{/section}
</div></div>
{include file="footer.tpl"}