<?php /* Smarty version 2.6.2, created on 2012-03-23 20:12:39
         compiled from logo_box.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'logo_box.tpl', 4, false),)), $this); ?>
<div class="box">
<div class="box_title">Our Logo</div>
<div class="box_body">
<div align=center><a href="<?php echo $this->_tpl_vars['settings']['site_url']; ?>
"><img src="<?php echo ((is_array($_tmp=($this->_tpl_vars['settings']['site_logo_url']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" border="0"></a><br><a href="<?php echo ((is_array($_tmp="?a=partners")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" class=smalllink>Put this logo on your site!</a></div>
</div>
</div>