body {
	background-position: center top;
	background-image:url(images/bg.png);
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #000000;
	margin: 0px;
	background-repeat: repeat-x;
	background-color: #333333;
     }


a:link, a:visited, a:active {
	font-family: Verdana, Arial, Helvetica;
	color: #444444;
	text-decoration:none;
     }  
a:hover{
	color:#FF0000;
	text-decoration:underline;
}
.wall {
	width: 960px;
}
A.menulink:link, A.menulink:visited, A.menulink:active {
	font-family: Arial, Helvetica, sans-serif;
	color: #006600; 
	text-decoration:none;
	font-size: 12px;
        font-weight: bold;
	display: block;
	height: 30px;
	padding-right: 12px;
	padding-left: 12px;
	float: left;
	line-height: 30px;
     }  
A.menulink:hover{
	color:#000000;
	background-image: url(images/menu_v.png);
	background-repeat: repeat-x;
	background-position: center center;
}



tr.title{
	height:30px;
	background-color:#8FAAE1;
}
.title2{
	height:30px;
	background-color:#0099CC;	
}

th {
	height:20px;
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #FFFFFF;
}
th.title {
	background-color:#0066CC;
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #ffffff;
}
th.title_box{
	background-color:#3263b9;
	/* border:1px solid #adc5ed; */
	padding:1px  0px  0px  9px; 
        height:24px;
	font-family: Verdana, Arial, Helvetica;
	font-size: 12px;
	color: #FFFFFF;
}
.dwmcurve {font-size:2px;height:15px;background-image:url(images/dwn-curve.jpg);background-repeat:no-repeat;background-position:center top;}
.tblbdr {border-left:1px solid #0a3777;border-right:1px solid #0a3777;background:#FFFFFF;}
td {
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #000000;
     }
td.welcome {
	font-family: Verdana, Arial, Helvetica;
	font-size:11px;
	color:#003300;
}
td.green{
	height:30;
	background-color:#3263b9;
}
td.green1{
	height:32;
	background-image:url(images/medio1.gif);
}

td.darkgreen{
	height:30;
	background-color:#0f3b95;
}
td.darkgreen1{
	height:30;
	background-color:#000080;
}

td.greentitle{
	height:25;
	background-color:#8FAAE1;
}
td.greybackground{
	background-color:#2975b0;
}
td.grey{
	height:20px;
	background-color:#f4f4f4;
}
td.listmenu{
	height:37px;
	background-image:url(images/medio.gif);
}

td.shadow{
height:7px;
background-image:url(images/shadow.gif);
	
}
td.adtop{
	font-family: Verdana, Arial, Helvetica;
	font-size:11px;
	color:#0c4b7b;
}
td.ad{
	font-family: Verdana, Arial, Helvetica;
	font-size: 9px;
	color: #000000;
	border-bottom-width: 1px;
	border-bottom-style: solid;
	border-bottom-color: #99CCFF;
}
ad{
	font-family: Verdana, Arial, Helvetica;
	font-size: 9px;
	color: #000000;
}
span.ad{
	font-family: Verdana, Arial, Helvetica;
	font-size: 9px;
	color: #000000;
}
a.ad{
	font-family: Verdana, Arial, Helvetica;
	font-size: 9px;
}



h3 {
	font-family: Verdana, Arial, Helvetica;
	font-size: 15px;
	color: #000000;
     }
a.newlistingslink {
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #444444;
     }
 
a.newlistingslink:visited, a.newlistingslink:active {
	color: #444444;
     }  
 a.newlistingslink:hover{
 	color:#FF0000;
	text-decoration:underline;
 }

.newlistings {
        padding-top: 4px;
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #000000;
     }
.newlistingsdate {
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #000000;
	font-weight: bold;
     }
.news {
	text-align: justify;
     }
.newsspons {
	text-align: justify;
	background-color: #f1ffcc; 
     }
.newsdate {
	font-family: Verdana, Arial, Helvetica;
	font-size: 10px;
	color: #999999;
	font-style: italic;
     }

.smallnews {
	text-align: justify;
	background:#E8ECF8;
     }
.smallnewsspons {
	text-align: justify;
	background-color:#f7ffe0; 
     }
.smallnewstitle {
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #000000;
	font-weight: bold;
     }
.smallnewstext {
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #000000;
     }
.smallnewsdate {
	font-family: Verdana, Arial, Helvetica;
	font-size: 8px;
	color: #000000;
	font-style: italic;
     }


form {
	margin-top: 0px;
	margin-bottom: 0px;
	margin-left: 0px;
	margin-right: 0px;
     }
td.toplink{
	color: white;
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	text-decoration: none;
}
td.groupname{
	color:#FFFFFF;
	font-family: Verdana, Arial, Helvetica;
	font-size: 14px;
	font-weight:bold;
	text-decoration: none;
}

table.listtitle{line-height:100%; font-size:80%;}
tr.listtitle{padding:4px 6px 3px 6px;color:#FFFFFF;font-family:Verdana, Arial, Helvetica; font-size:80%; background:url(images/title-bg.jpg);background-position:center top;background-repeat:reapeat-x;height:34px;}

table.adtitle{line-height:120%; font-size:100%;}
tr.adtitle{padding:4px 6px 3px 6px;color:#5F5F5F;font-family:Verdana, Arial, Helvetica; font-size:100%; background-color:#6CB6FF;}
tr.adtitle2{padding:0px 0px 0px 0px;color:#5F5F5F;font-family:Verdana, Arial, Helvetica; font-size:100%; background-color:#8FAAE1;}

table.adbody{line-height:120%; font-size:100%;border-color:#8FAAE1;border-style:solid;border-width:0px 0px 0px 0px;}
tr.adbody{padding:4px 6px 3px 6px;color:#5F5F5F;font-family:Verdana, Arial, Helvetica; font-size:100%; }

table.listbody{line-height:120%; font-size:100%;border-color:#8FAAE1;border-style:solid;border-width:1px 1px 1px 1px;}
tr.listbody{padding:4px 6px 3px 6px;color:#5F5F5F;font-family:Verdana, Arial, Helvetica; font-size:100%; }

span.toplink{
	color: white;
}
span.toplink1{
	color: black;
}
a.toplink, a.toplink:visited, a.toplink:active {
	color: white;
	font-family: Arial;
	font-size: 12px;
	text-decoration: none;
	font-weight:bold;
}

a.toplink:hover{
	color:white;
	font-family:Arial;
	font-size: 12px;
	text-decoration: none;
	font-weight:bold;
}

a.toplink1,a.toplink1:visited, a.toplink1:active {
	color:white;
	font-family:Arial;
	font-size: 12px;
	text-decoration: none;
	font-weight:bold;
	border:0px solid #CC0000;
	padding:5px 5px 5px 5px;
}
a.toplink1:hover{
	color:#000000;
	font-family:Arial;
	font-size: 12px;
	text-decoration: none;
	font-weight:bold;
	height:20px;
	padding:5px 5px 5px 5px;
	background:#9fca2c;
}
.forCopyright, .forCopyright:hover, .forCopyright:visited, .forCopyright:active {
	font-family: arial;
	font-size: 12px;
	background-color:#ADC5ED;
	font-weight:bold;
	color: #FFFFFF;
	height:20px;
	padding:5px 10px 5px 10px;
	background:#9fca2c;
}
.DISCLAIMER {
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #FFFFFF;
    background-color: #ADC5ED;
	padding-left:5px;
	padding-right:5px;
	text-align: justify;
     }

.menutxt {
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #000000;
}
.bgcolor {
	background-color: #BCD89F
       }
.rightmenu {
	background-color: #FFFFFF
 }
 
.line {
background-color:#779b32;

background-repeat: repeat-y;
width: 1px;
       }

.bg-vertline {
background-image: url(images/bg-vertiline.gif);
background-repeat: repeat-y;
width: 1px;
}
.bg-horline {
background-image: url(images/bg-horiline.gif);
width: 1px;
background-repeat: repeat-x;
  }
.bg-menu {
	background-color: #779b32;
	background-repeat: repeat-x;
	height: 30px;
}

.newlistingsdatetitle {
	font-family: Verdana, Arial, Helvetica;
	font-size: 11px;
	color: #777777;
        background-color: #F4F4F4;
}
.detailsbg1 {
	background-color: #FFFFF2;
      }
.detailsbg2 {
	background-color: #F8F8F8;
      }
.inpts {
	font-family: Verdana, Arial, Helvetica;
	font-size: 10px;
	color: #000000;
	background-color: #FFFFCC;
	border: 1px inset #999999;
	border-color: #999999;
	border-style: solid;
}
.sbmt {
	font-family: Verdana, Arial, Helvetica;
	font-size: 10px;
	color: #FFFFFF;
	border: 1px outset #CD9B9B;
	background-color: #A70000;
	display: block;
	padding: 2px;
}
a.hlp, a.hlp:active, a.hlp:visited, a.hlp:hover { 
	font-family: verdana;
	font-size: 11px;
	color: black;
	text-decoration: none;
	cursor: help;
      }
.smalllink {
font-size: 10px;
color:grey;
text-decoration:none;
}
.adblack {background-color:#dbe7f5}/*8FAAE1*/
.adlight {background-color:#FFFFFF; text-align: left}/*c6e2ff*/
a.adlink, a.adlink:hover, a.adlink:visited, a.adlink:active {color: #006633; font-size: 11px; text-decoration: none}
.adtext  {color: #000000; font-size: 10px}

.emptystars {
	float: left;
	background: url('images/0star.gif');
	position: relative;
	width: 60px;
	height: 16px;
}
.fullstars {
	background: url('images/5star.gif');
	position: absolute;
	height: 16px;
	top: 0;
	left: 0;
}
.expiresdate {
	color: #ff0000;
	font-size: 9px;
      }

.topz {

	height: 101px; 
}
.menuz {
	height: 30px;
}

.menuz span {
	z-index: 1000;
}
ul#Rl {	left: 25px; }
ul#Rr {	left: 325px; }
.menuz ul {
	z-index: 1000;
	position: absolute;
	height: 30px;
	top: 118px;
	list-style: none;
        VISIBILITY:hidden;
	background: #F4F4F4;
}
.menuz ul li{
	text-align: center;
	text-decoration: none;
	padding: 8px 6px;
        float: left;
}

.menuz ul A.submenulink:link, A.submenulink:visited, A.submenulink:active {
	font-family: Arial, Helvetica, sans-serif;
	color: #006600; 
        float: left;
	text-decoration:none;
	font-size: 12px;
	padding-right: 8px;
	padding-left: 8px;
     }  
.menuz ul A.submenulink:hover{
	color:#000000;
	background: orange url(images/menu_v.png) top left repeat-x;
}

.search {
	float: right;
	height: 28px;
	width: 250px;
	padding: 1px;
}

.search submit {
	height: 28px;
}


.bodyz {
	background-image: url(images/menu_d.png);
	background-repeat: repeat-x;
	background-position: center top;
	background-color: #EEF7D9;
}
.footerz {
	background-color: #99CC66;
	padding: 10px;
}
.banz_a {
	text-align: center;
	padding: 10px;
}
.banz_b {
	text-align: center;
	margin-bottom: 10px;
}

.mainz {
	padding: 10px;
}

.leftbar {
	width: 200px;
}
.mspace {
	width: 10px;
}
.mainbar {
}
.box {
        border: 1px solid #AAAAAA;
	background-color: #FFFFFF;
	margin-bottom: 10px;
	padding-top: 3px;
}
.box .box_title {
	line-height: 36px;
	height: 36px;
	background-image: url(images/box_t2.png);
	background-repeat: no-repeat;
	background-position: right center;
	font-family: "Times New Roman", Times, serif;
	color: #FFFFFF;
	font-size: 13px;
	text-transform: uppercase;
	padding-left: 10px;
	text-align: left;
}
.box .box_body {
	background-image: url(images/box_bg.png);
	background-repeat: no-repeat;
	background-position: right bottom;
	padding: 5px;
	text-align: left;
}
.box #tba {
	background-image: url(images/box_t2.png);
}
.box #tep {
	background-image: url(images/box_t4.png);
}
.box #tpp {
	background-image: url(images/box_t1.png);
}
.box #tnp {
	background-image: url(images/box_t3.png);
}
.dpz {
	border-bottom-width: 1px;
	border-bottom-style: dotted;
	border-bottom-color: #CCCCCC;
	margin-bottom: 15px;
	background-color: #FFFFFF;
}
.dp_title {
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 12px;
	font-weight: bold;
	padding: 2px;
	border-bottom-width: 2px;
	border-bottom-style: solid;
	border-bottom-color: #0066CC;
}
.dp_imgz {
	text-align: center;
	width: 170px;
}
.dp_info1z {
	width: 285px;
	padding-right: 5px;
}
.dp_info2z {
	width: 250px;
	padding-left: 5px;
	border-left-width: 1px;
	border-left-style: dotted;
	border-left-color: #999999;
}
.pimg {
	border: 2px solid #0066CC;
}
.dp_text {
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 10px;
	color: #333333;
	text-align: left;
	line-height: 18px;
}
.dp_subz {
	text-align: left;
}
A.dp_link {
	font-family: Arial, Helvetica, sans-serif;
	font-size: 12px;
	text-decoration: none;
}
.rankz {
	text-align: right;
	font-family: "Times New Roman", Times, serif;
	color: #0066CC;
	font-size: 13px;
	font-weight: bold;
}
A.dp_tlink{
	text-align: right;
	font-family: "Times New Roman", Times, serif;
	color: #000000;
	font-size: 14px;
	font-weight: bold;
	text-decoration: none;
}

.dline {
padding-bottom:8px;
border-bottom:#bbbbbb 1px solid;
}
td.arr{
background: url(images/v.png) no-repeat  0 12px; 
padding:7px 9px 6px 12px;
}

div.arr{
background: url(images/left.png) no-repeat  0 0px; 
padding:1px 3px 2px 12px;
}


div.nlt{
background: url(images/00.gif) no-repeat  0 0px; 
padding:0px 3px 1px 16px;
}

/* Fix IE. Hide from IE Mac \*/
* html .menuz ul { top: 126px; left: 0px; }
* html A.dp_link { font-size: 11px; font-weight:550; }
/* End */