{include file="header.tpl"}

{section name=g loop=$groups}
{if !$groups[g].listings}
<div class="box"><div class="box_title" id="tep">{$groups[g].name} LISTING</div>
<div class="box_body">
<table width="100%" border="0" cellspacing="0" cellpadding="0">
<tr><td align=center>Currently there are no items in the {$groups[g].name} listing {if $frm.pfilter}using {$frm.pfilter}{/if}<br><br>
{if $groups[g].reg_enabled}<a href="{"?a=addprogram"|encurl}">List your program in the {$groups[g].name} listing</a><br><br>{/if}
</td></tr></table></div></div>
{else}
{if $groups[g].type == 'Exclusive'}
{include file="list_exclusive.tpl"}
{/if}
{if $groups[g].type == 'Premium'}
{include file="list_premium.tpl"}
{/if}
{if $groups[g].type == 'Normal'}
{include file="list_normal.tpl"}
{/if}
{if $groups[g].type == 'Trial'}
{include file="list_trial.tpl"}
{/if}
{if $groups[g].type == 'Autosurf'}
{include file="list_autosurf.tpl"}
{/if}
{if $groups[g].type == 'Free'}
{include file="list_free.tpl"}
{/if}
{if $groups[g].type == 'Games'}
{include file="list_games.tpl"}
{/if}
{if $groups[g].type == 'Scam'}
{include file="list_scam.tpl"}
{/if}
{if $groups[g].type == 'Closed'}
{include file="list_closed.tpl"}
{/if}
{/if}
{/section}

{include file="footer.tpl"}
