{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">Subscribed:</div>
<div class="box_body">
<table cellspacing=1 cellpadding=2 border=0 width=100%>
<tr><td align="center">
{if $errors}
{section name=e loop=$errors}
{if $errors[e].name == 'email'}
<li style="color: red"> Please enter your E-mail<br>
{/if}
{if $errors[e].name == 'invalid_email'}
<li style="color: red"> Please enter a valid E-mail<br>
{/if}
{/section}
{else}
<b style="color:green">Thank you.<br>
Your have been successfully subscribed.</b>
{/if}
<br><br>
<a href="{$settings.site_url}">Return to the home page</a>
 </td>
</tr>
</table></div></div>
{include file="footer.tpl"}