{include file="header.tpl"}
<div class="box">
<div class="box_title" id="tba">confirm your request</div>
<div class="box_body">
{if $success == 0}
<b>Listing not confirmed:</b><br><br>

Please check the link you received. It seems like the link is broken.
{else}
<b>Listing confirmed:</b><br><br>

 Thank you for using our system.<br>
 Your listing has been successfully added and will be listed after administrator approval.

<br><br>
<a href="{$settings.site_url}">Return to the home page</a>
{/if}
</div></div>

{include file="footer.tpl"}
