<div class="box">
<div class="box_title">Partner Links</div>
<div class="box_body">
<div align="center">
<table cellpadding="1" cellspacing="2" border="0">
{if $ipartners}
{section name=ipa loop=$ipartners}
<tr><td align="center"><a href="{$ipartners[ipa].url}" target="_blank">{if $ipartners[ipa].logo}<img src="{$ipartners[ipa].logo}" border="0" alt="{$ipartners[ipa].name}">{else}{$ipartners[ipa].name}{/if}</a></td></tr>
{/section}{/if}
</table><br>
<a href="{"?a=partners"|encurl}" class=smalllink>All Partners</a></div>
</div>
</div>