<?php /* Smarty version 2.6.2, created on 2012-05-23 20:13:43
         compiled from info_latestvote.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'info_latestvote.tpl', 3, false),)), $this); ?>
<?php if ($this->_tpl_vars['latestvotes']): ?>
<?php if (isset($this->_sections['lv'])) unset($this->_sections['lv']);
$this->_sections['lv']['name'] = 'lv';
$this->_sections['lv']['loop'] = is_array($_loop=$this->_tpl_vars['latestvotes']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['lv']['show'] = true;
$this->_sections['lv']['max'] = $this->_sections['lv']['loop'];
$this->_sections['lv']['step'] = 1;
$this->_sections['lv']['start'] = $this->_sections['lv']['step'] > 0 ? 0 : $this->_sections['lv']['loop']-1;
if ($this->_sections['lv']['show']) {
    $this->_sections['lv']['total'] = $this->_sections['lv']['loop'];
    if ($this->_sections['lv']['total'] == 0)
        $this->_sections['lv']['show'] = false;
} else
    $this->_sections['lv']['total'] = 0;
if ($this->_sections['lv']['show']):

            for ($this->_sections['lv']['index'] = $this->_sections['lv']['start'], $this->_sections['lv']['iteration'] = 1;
                 $this->_sections['lv']['iteration'] <= $this->_sections['lv']['total'];
                 $this->_sections['lv']['index'] += $this->_sections['lv']['step'], $this->_sections['lv']['iteration']++):
$this->_sections['lv']['rownum'] = $this->_sections['lv']['iteration'];
$this->_sections['lv']['index_prev'] = $this->_sections['lv']['index'] - $this->_sections['lv']['step'];
$this->_sections['lv']['index_next'] = $this->_sections['lv']['index'] + $this->_sections['lv']['step'];
$this->_sections['lv']['first']      = ($this->_sections['lv']['iteration'] == 1);
$this->_sections['lv']['last']       = ($this->_sections['lv']['iteration'] == $this->_sections['lv']['total']);
?>
<img src="<?php echo ((is_array($_tmp="images/c/".($this->_tpl_vars['latestvotes'][$this->_sections['lv']['index']]['flag']).".gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" align="absmiddle" alt="<?php echo $this->_tpl_vars['latestvotes'][$this->_sections['lv']['index']]['flag']; ?>
" title="<?php echo $this->_tpl_vars['latestvotes'][$this->_sections['lv']['index']]['flag']; ?>
" style="cursor:help;"> <img src="<?php echo ((is_array($_tmp="images/r".($this->_tpl_vars['latestvotes'][$this->_sections['lv']['index']]['vote']).".gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" align="absmiddle" alt="<?php echo $this->_tpl_vars['latestvotes'][$this->_sections['lv']['index']]['comment']; ?>
" title="<?php echo $this->_tpl_vars['latestvotes'][$this->_sections['lv']['index']]['comment']; ?>
" style="cursor:help;"> <a href="<?php echo ((is_array($_tmp="?a=details&lid=".($this->_tpl_vars['latestvotes'][$this->_sections['lv']['index']]['id']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
"><b><?php echo $this->_tpl_vars['latestvotes'][$this->_sections['lv']['index']]['sub_name']; ?>
</b></a><br>
<?php endfor; endif; ?><br>
<?php else: ?>No data find in database
<?php endif; ?>






