<div class="dpz">
  <table width="100%" border="0" cellspacing="0" cellpadding="0">
    <tr>
      <td colspan="2" class="dp_title">  	  
	  <table width="100%" border="0" cellspacing="0" cellpadding="0">
          <tr><td align="left"><a href="{"?a=go&lid=`$listing.id`"|encurl}" target="_blank" class="do_tlink"><b>{$listing.name}</b></a>{if $listing.new} <i style="color:red">new</i>{/if} &nbsp; {section name=r loop=$listing.hhot}{if $listing.hhot[r].star}<img src="{"images/hot1.gif"|encurl}" align="absmiddle">{/if}{/section}</td>
<td class="rankz" align="right">Rank: <b>{$listing.ordering}</b></td></tr>
</table></td><td class="dp_title" align="right">{section name=p loop=$listing.options}<img src="{"images/`$listing.options[p].name`.gif"|encurl}" alt="{$listing.options[p].name}" title="{$listing.options[p].name}" align="absmiddle"> {/section}&nbsp;</td>
    </tr>
<tr><td colspan="3" valign="top" class="dp_imgz"><img src="{"images/spacer.gif"|encurl}" width="1" height="5" /></td></tr>
    <tr>
      <td rowspan="2" valign="top" class="dp_imgz"><table width="100%" border="0" cellspacing="0" cellpadding="2">
  <tr>
    <td align="center"><a href="{"?a=go&lid=`$listing.id`"|encurl}" target="_blank"><img src="{$listing.hyip_image}" width=160 height=100 class="pimg"></a></td></tr>
  <tr>
    <td align="center"><img src="{"images/stat`$listing.hyip_status`.png"|encurl}" width="132" height="27" /></td>
  </tr>
  <tr>
    <td align="center" class="dp_text"><div align="center">Added: {$listing.added}</div></td>
  </tr>
</table></td>
      <td valign="top" class="dp_info1z"><table width="100%" border="0" cellspacing="0" cellpadding="0">
        <tr>
          <td class="dp_text"><strong>Our Rating:</strong> <img src="{"images/`$listing.rating`star.gif"|encurl}" border="0" align="absmiddle" title="{$listing.rating} star"></td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Interest:</strong> {$listing.percents}</td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Our Investment:</strong> {if $listing.spend > 0}${$listing.spend}{else}No{/if}</td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Payout Ratio:</strong> {$listing.ratio*100}% {if $listing.ratio >= 1}<font color="green"><i>in profit</i></font>{/if}</td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Payment methods:</strong></td>
        </tr>
        <tr>
          <td class="dp_text">{section name=p loop=$listing.payments}<img src="{"images/`$listing.payments[p].system`.gif"|encurl}" align="absmiddle" alt="{$listing.payments[p].system}" title="{$listing.payments[p].system}" /> {/section}</td>
        </tr>
      </table></td>
      <td valign="top" class="dp_info2z">
<table width="100%" border="0" cellspacing="0" cellpadding="0">
<tr><td>
<table width="100%" border="0" cellspacing="0" cellpadding="0">
<tr><td class="dp_text" width="30%"><b>User Rating: </b></td>
<td> <span class="emptystars"><span class="fullstars" style="width: {$listing.usrrating}%" title="{$listing.avg_vote} / {$listing.cvotes} votes"></span></span></td>
        </tr>
</table></td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Monitored:</strong> {$listing.monitored} days</td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Minimal/Maximal Spend:</strong> {$listing.min_spend}/{if $listing.max_spend}{$listing.max_spend}{else}No Limit{/if}</td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Withdrawal:</strong>  {if $listing.withdrawal_type == 1}Manual{/if}{if $listing.withdrawal_type == 2}Instant{/if}{if $listing.withdrawal_type == 3}Automatic{/if}</td>
        </tr>
        <tr>
          <td class="dp_text"><strong>Referral:</strong> {if $listing.referral}{$listing.referral}{else}No{/if}</td>
        </tr>
        {if $listing.support_email || $listing.support_form || $listing.support_phone || $listing.support_aim}
        <tr>
          <td class="dp_text"><strong>Support:</strong> {if $listing.support_email}<a href="mailto:{$listing.support_email}"><img src="{"images/smail.gif"|encurl}" border=0 alt="Support E-Mail" title="Support E-Mail" align=absmiddle></a>{/if} {if $listing.support_form}<a href="{$listing.support_form}" target=_blank><img src="{"images/sform.gif"|encurl}" border=0 alt="Support Form" title="Support Form" align=absmiddle></a>{/if} {if $listing.support_phone}<img src="{"images/sphone.gif"|encurl}" border=0 alt="Phone: {$listing.support_phone}" title="Phone: {$listing.support_phone}" align=absmiddle>{/if} {if $listing.support_aim}<img src="{"images/smsn.gif"|encurl}" border=0 alt="{$listing.support_aim}" title="{$listing.support_aim}" align=absmiddle>{/if}</td>
        </tr>{/if}{if $listing.forums}
        <tr>
          <td class="dp_text"><strong>Forum:</strong> {section name=p loop=$listing.forums}<a href="{$listing.forums[p].url|escape:htmlall}" target=_blank>{$listing.forums[p].name}</a> {/section}</td>
        </tr>{/if}
      </table></td>
    </tr>
    <tr>
      <td colspan="2" class="dp_subz">
       <table border="0" cellspacing="0" cellpadding="7">
        <tr>
          
{if $detailed}
<td class="arr"><a href="#" class="dp_link" onclick="GetData('','votes','{$listing.id}','');return false;">Vote</a></td>
<td class="arr"><a href="#" class="dp_link" onclick="GetData('','paystat','{$listing.id}','');return false;">Payouts</a></td>
<td class="arr"><a href="#" class="dp_link" onclick="GetData('','whois','{$listing.id}','');return false;">Whois</a></td>                   
<td class="arr"><a href="#" class="dp_link" onclick="GetData('','button','{$listing.id}','');return false;">Button</a></td>
{if $listing.rcb > 0}<td class="arr"><a href="#" class="dp_link" style="color:green" onclick="GetData('','rcb','{$listing.id}','');return false;">RCB {$listing.rcb}%</a></td>{/if}
<td class="arr"><a href="#" class="dp_link" style="color:red" onclick="GetData('','report_scam','{$listing.id}','');return false;">Report Scam</a></td>
{else}

<td class="arr"><a href="{"?a=details&lid=`$listing.id`"|encurl}" class="dp_link">Program Details</a></td>
<td class="arr"><a href="{"?a=details&aj=paystat&lid=`$listing.id`"|encurl}" class="dp_link">Payouts</a></td>
<td class="arr"><a href="{"?a=details&aj=votes&lid=`$listing.id`"|encurl}" class="dp_link">Vote</a></td>

{if $listing.rcb > 0}<td class="arr"><a href="{"?a=details&aj=rcb&lid=`$listing.id`"|encurl}" class="dp_link" style="color:green">RCB {$listing.rcb}%</a></td>{/if}
<td class="arr"><a href="{"?a=details&aj=report_scam&lid=`$listing.id`"|encurl}" class="dp_link" style="color:red">Report Scam</a></td>
{/if}

<td class="arr">{if $listing.bookmark}<a href="{"?a=bookmarks&action=remove&lid=`$listing.id`"|encurl}" onclick="return confirm('Do you really want to remove the program from bookmarks?')" class="dp_link">Remove</a>{else}<a href="{"?a=bookmarks&action=add&lid=`$listing.id`"|encurl}" class="dp_link">Bookmark</a>{/if}</td>

</tr>
      </table></td>
    </tr>
  </table>
</div>
{if $detailed}<div align="left"><strong>Program Discription:</strong><br>{$listing.description}</div>{/if}
