<?php /* Smarty version 2.6.2, created on 2012-05-23 22:19:19
         compiled from user_signup.tpl */ ?>
<?php require_once(SMARTY_DIR . 'core' . DIRECTORY_SEPARATOR . 'core.load_plugins.php');
smarty_core_load_plugins(array('plugins' => array(array('modifier', 'encurl', 'user_signup.tpl', 9, false),array('modifier', 'escape', 'user_signup.tpl', 39, false),)), $this); ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div class="box">
<div class="box_title" id="tba">User Signup</div>
<div class="box_body">


<?php if ($this->_tpl_vars['frm']['display'] == 'confirmation'): ?>
 <?php if ($this->_tpl_vars['frm']['say'] == 'confirmed'): ?>
<div style="color:green" align="center">Thank you. Your account has been successfully confirmed. You can <a href="<?php echo ((is_array($_tmp="?a=login")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">login</a> now.</div>
 <?php else: ?>
<div style="color:red" align="center">Sorry, confirmation code was not found. It means you have used broken link or your account was already confirmed.</div>
 <?php endif; ?>
<?php elseif ($this->_tpl_vars['frm']['display'] == 'added'): ?>
<div style="color:green" align="center">Thank you. Your account has been successfully created. You can <a href="<?php echo ((is_array($_tmp="?a=login")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
">login</a> now.</div>
<?php elseif ($this->_tpl_vars['frm']['display'] == 'confirm'): ?>
<div style="color:green" align="center">
Thank you. Your account has been successfully created.<br>
You should confirm your e-mail address by following link we have sent to you.
</div>
<?php else: ?>

<?php if ($this->_tpl_vars['errors']): ?>
<ul style="color:red">                                                                      
<?php if ($this->_tpl_vars['errors']['turing']): ?><li> Invalid turing image provided</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['username']): ?><li> Please, enter your Username.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['username_exists']): ?><li> Username already exists. Please, enter another one.</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['email']): ?><li> Please, enter your email</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['invalid_email']): ?><li> Please, enter your valid email</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['password']): ?><li> Please, define your password</li><?php endif; ?>
<?php if ($this->_tpl_vars['errors']['password2']): ?><li> Please, verify passwords you have entered. Both passwords shoudl be equal</li><?php endif; ?>
</ul>
<?php endif; ?>

<form method="post" action="">
<input type="hidden" name="action" value="signup">
<table width="100%" border="0" cellspacing="1" cellpadding="3">
<tr>
 <td>Username</td>
 <td><input type="text" name="username" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['username'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="35"></td>
</tr>
<tr>
 <td>Email</td>
 <td><input type="text" name="email" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['email'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
 <td>Password</td>
 <td><input type="password" name="password" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['password'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>
<tr>
 <td>Confirm Password</td>
 <td><input type="password" name="password2" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['password2'])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="45"></td>
</tr>

<?php if (count($_from = (array)$this->_tpl_vars['ecs'])):
    foreach ($_from as $this->_tpl_vars['i'] => $this->_tpl_vars['data']):
?>
<tr>
 <td><?php echo $this->_tpl_vars['data']['name']; ?>
</td>
 <td><input type="text" name="account[<?php echo $this->_tpl_vars['i']; ?>
]" value="<?php echo ((is_array($_tmp=$this->_tpl_vars['frm']['account'][$this->_tpl_vars['i']])) ? $this->_run_mod_handler('escape', true, $_tmp, 'htmlall') : smarty_modifier_escape($_tmp, 'htmlall')); ?>
" class="inpts" size="32"> <img src="<?php echo ((is_array($_tmp="images/".($this->_tpl_vars['data']['name']).".gif")) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" title="<?php echo $this->_tpl_vars['data']['name']; ?>
" align="absmiddle"></td>
</tr>
<?php endforeach; unset($_from); endif; ?>

<?php if ($this->_tpl_vars['settings']['use_turing']): ?>
<tr>
  <td><img src="<?php echo ((is_array($_tmp="?a=turing&".($this->_tpl_vars['sesname'])."=".($this->_tpl_vars['sesid'])."&r=".($this->_tpl_vars['rand']))) ? $this->_run_mod_handler('encurl', true, $_tmp) : smarty_modifier_encurl($_tmp)); ?>
" alt="turing code"></td>
  <td><input type=text name="turing" maxlength="6" size="10" class="inpts"></td>
</tr>
<?php endif; ?>
<tr>
 <td></td>
 <td><input type="submit" value="Signup" class="sbmt"></td>
</tr>
</table>
</form>

<?php endif; ?>

</div></div>

<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>