<?exit;?>
0_num	1
0_max	15
0_step	0
0_enable_1	1
0_name_1	phphyip
0_url_1	http://localhost
0_imgurl_1	http://localhost/02SMUO9_Rajascript/images/banner.gif
0_expired_1	2011-12-12
0_desc_1	
0_enable_2	1
0_name_2	
0_url_2	
0_imgurl_2	
0_expired_2	2010-01-01
0_desc_2	
0_type	0
2_num	1
2_type	1
2_max	0.01
2_step	0
2_enable_1	1
2_name_1	
2_url_1	
2_imgurl_1	
2_expired_1	
2_desc_1	
1_num	3
1_type	1
1_max	100
1_step	5
1_enable_1	1
1_name_1	hothyipscript.com
1_url_1	http://www.hothyipscript.com/
1_imgurl_1	http://www.hothyipscript.com/banners/hhs728x90.gif
1_expired_1	2011-01-04
1_desc_1	hothyipscript.com
10_num	1
10_type	0
10_max	20
10_step	0
10_enable_1	1
10_name_1	Hot HYIP Script
10_url_1	http://www.hothyipscript.com
10_imgurl_1	http://www.hothyipscript.com/banners/hhs125x125.gif
10_expired_1	2012-11-27
10_desc_1	Hot HYIP Script
3_num	2
3_type	1
3_max	18
3_step	0
3_enable_1	0
3_name_1	hothyipscript
3_url_1	http://www.hothyipscript.com/
3_imgurl_1	http://www.hothyipscript.com/banners/hhs468x60.gif
3_expired_1	2012-01-01
3_desc_1	hothyipscript
4_num	2
4_type	1
4_max	16
4_step	0
4_enable_1	1
4_name_1	
4_url_1	
4_imgurl_1	
4_expired_1	2010-01-01
4_desc_1	
5_num	1
5_type	1
5_max	14
5_step	0
5_enable_1	0
5_name_1	
5_url_1	
5_imgurl_1	
5_expired_1	2010-01-01
5_desc_1	
6_num	2
6_type	1
6_max	10
6_step	0
6_enable_1	1
6_name_1	
6_url_1	
6_imgurl_1	
6_expired_1	2010-01-01
6_desc_1	
7_num	2
7_type	1
7_max	20
7_step	0
7_enable_1	1
7_name_1	hothyipscript
7_url_1	http://www.hothyipscript.com/
7_imgurl_1	http://www.hothyipscript.com/banners/hhs125x125.gif
7_expired_1	2010-12-12
7_desc_1	hothyipscript
8_num	2
8_type	0
8_max	25
8_step	0
8_enable_1	1
8_name_1	Hot HYIP Script
8_url_1	http://www.hothyipscript.com/
8_imgurl_1	http://www.hothyipscript.com/banners/hhs120x600.gif
8_expired_1	2012-01-01
8_desc_1	hothyipscript.com
9_num	1
9_type	0
9_max	20
9_step	0
9_enable_1	1
9_name_1	
9_url_1	
9_imgurl_1	
9_expired_1	
9_desc_1	
1_enable_2	1
1_name_2	
1_url_2	
1_imgurl_2	
1_expired_2	2010-01-01
1_desc_2	
2_enable_2	1
2_name_2	test
2_url_2	http://google.com
2_imgurl_2	http://www.hothyipscript.com/banners/hhs468x60.gif
2_expired_2	2010-11-13
2_desc_2	test
2_enable_3	0
2_name_3	
2_url_3	
2_imgurl_3	
2_expired_3	2010-01-01
2_desc_3	
3_enable_2	0
3_name_2	
3_url_2	
3_imgurl_2	
3_expired_2	2010-01-01
3_desc_2	
7_enable_2	1
7_name_2	
7_url_2	
7_imgurl_2	
7_expired_2	2010-01-01
7_desc_2	
7_enable_3	1
7_name_3	
7_url_3	
7_imgurl_3	
7_expired_3	2010-01-01
7_desc_3	
8_enable_2	1
8_name_2	
8_url_2	
8_imgurl_2	
8_expired_2	
8_desc_2	
10_enable_2	1
10_name_2	
10_url_2	
10_imgurl_2	
10_expired_2	2010-01-01
10_desc_2	
10_enable_3	1
10_name_3	
10_url_3	
10_imgurl_3	
10_expired_3	2010-01-01
10_desc_3	
1_enable_3	0
1_name_3	
1_url_3	
1_imgurl_3	
1_expired_3	2010-01-01
1_desc_3	
1_enable_4	0
1_name_4	forexcompanyonline
1_url_4	http://forexcompanyonline.com
1_imgurl_4	http://forexcompanyonline.com/banners/f720x90_eng.swf
1_expired_4	2011-01-01
1_desc_4	forexcompanyonline.com
1_enable_5	0
1_name_5	
1_url_5	
1_imgurl_5	
1_expired_5	2010-01-01
1_desc_5	
0_enable_3	1
0_name_3	
0_url_3	
0_imgurl_3	
0_expired_3	2010-01-01
0_desc_3	
0_enable_4	1
0_name_4	okhyips.com
0_url_4	http://www.okhyips.com
0_imgurl_4	http://www.okhyips.com/images/banner.gif
0_expired_4	2010-11-19
0_desc_4	
0_enable_5	1
0_name_5	MY BEST TEST
0_url_5	http://www.7inv.com
0_imgurl_5	http://www.gold2ex.com/images/banner.gif
0_expired_5	2010-12-04
0_desc_5	
0_enable_6	1
0_name_6	Hot HYIP Script
0_url_6	http://www.okhyips.com
0_imgurl_6	http://www.okhyips.com/ads/HotHYIPScript_Toprotating.gif
0_expired_6	2010-12-04
0_desc_6	Hot Hyip Script - Run your OWN HYIP Site in 5 minutes!
0_enable_7	0
0_name_7	
0_url_7	
0_imgurl_7	
0_expired_7	2010-01-01
0_desc_7	
0_enable_8	0
0_name_8	
0_url_8	
0_imgurl_8	
0_expired_8	2010-01-01
0_desc_8	
0_enable_9	0
0_name_9	
0_url_9	
0_imgurl_9	
0_expired_9	2010-01-01
0_desc_9	
0_enable_10	0
0_name_10	
0_url_10	
0_imgurl_10	
0_expired_10	2010-01-01
0_desc_10	
8_enable_3	0
8_name_3	
8_url_3	
8_imgurl_3	
8_expired_3	
8_desc_3	
1_enable_6	1
1_name_6	CherryShares
1_url_6	http://www.google.com/
1_imgurl_6	http://www.okhyips.com/images/banner.gif
1_expired_6	2010-11-01
1_desc_6	
1_enable_7	1
1_name_7	CherryShares
1_url_7	http://www.google.com/
1_imgurl_7	http://www.okhyips.com/images/banner.gif
1_expired_7	2010-11-01
1_desc_7	
1_enable_8	1
1_name_8	CherryShares
1_url_8	http://www.google.com/
1_imgurl_8	http://www.okhyips.com/images/banner.gif
1_expired_8	2010-11-01
1_desc_8	
1_enable_9	0
1_name_9	
1_url_9	
1_imgurl_9	
1_expired_9	2010-01-01
1_desc_9	
1_enable_10	0
1_name_10	
1_url_10	
1_imgurl_10	
1_expired_10	2010-01-01
1_desc_10	
_desc_1	ex
_desc_2	aaa
_desc_4	best
0_enable_	1
0_name_	Hot HYIP Script
0_url_	http://www.hothyipscript.com/?ref=okhyips.com
0_imgurl_	http://www.okhyips.com/ads/HotHYIPScript_Toprotating.gif
0_expired_	2011-02-04
0_desc_	Hot Hyip Script - Run your OWN HYIP Site in 5 minutes!
4_enable_2	0
4_name_2	
4_url_2	
4_imgurl_2	
4_expired_2	
4_desc_2	
6_enable_2	0
6_name_2	
6_url_2	
6_imgurl_2	
6_expired_2	2010-01-01
6_desc_2	
