<?php /* Smarty version 2.6.2, created on 2012-03-24 09:30:02
         compiled from addprogram.tpl */ ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div class="box">
<div class="box_title" id="tba">Add Your Program (1/2)</div>
<div class="box_body">
<?php if ($this->_tpl_vars['msg'] == 'error'): ?>
<div align="center"><b style="color:red">Sorry, your confirmation code has expired.</b></div>
<?php else: ?>
<script language="JavaScript">
var listfee = new Array();
<?php if (isset($this->_sections['fe'])) unset($this->_sections['fe']);
$this->_sections['fe']['name'] = 'fe';
$this->_sections['fe']['loop'] = is_array($_loop=$this->_tpl_vars['lfees']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['fe']['show'] = true;
$this->_sections['fe']['max'] = $this->_sections['fe']['loop'];
$this->_sections['fe']['step'] = 1;
$this->_sections['fe']['start'] = $this->_sections['fe']['step'] > 0 ? 0 : $this->_sections['fe']['loop']-1;
if ($this->_sections['fe']['show']) {
    $this->_sections['fe']['total'] = $this->_sections['fe']['loop'];
    if ($this->_sections['fe']['total'] == 0)
        $this->_sections['fe']['show'] = false;
} else
    $this->_sections['fe']['total'] = 0;
if ($this->_sections['fe']['show']):

            for ($this->_sections['fe']['index'] = $this->_sections['fe']['start'], $this->_sections['fe']['iteration'] = 1;
                 $this->_sections['fe']['iteration'] <= $this->_sections['fe']['total'];
                 $this->_sections['fe']['index'] += $this->_sections['fe']['step'], $this->_sections['fe']['iteration']++):
$this->_sections['fe']['rownum'] = $this->_sections['fe']['iteration'];
$this->_sections['fe']['index_prev'] = $this->_sections['fe']['index'] - $this->_sections['fe']['step'];
$this->_sections['fe']['index_next'] = $this->_sections['fe']['index'] + $this->_sections['fe']['step'];
$this->_sections['fe']['first']      = ($this->_sections['fe']['iteration'] == 1);
$this->_sections['fe']['last']       = ($this->_sections['fe']['iteration'] == $this->_sections['fe']['total']);
?>
listfee[<?php echo $this->_tpl_vars['lfees'][$this->_sections['fe']['index']]['id']; ?>
] = '<?php echo $this->_tpl_vars['lfees'][$this->_sections['fe']['index']]['fee']; ?>
';
<?php endfor; endif; ?>
<?php echo '
function DoChe(S) { document.getElementById("amount_").value=listfee[S]; }
'; ?>

</script>
<table cellspacing=0 cellpadding=2 border=0 width=100%>
<tr><td><b>Your Description here</b></td></tr>
<tr><td width="96%">
<form name="addsite" method="POST">
<input type="hidden" name="a" value="send_payment">
<fieldset>
<legend><b style="color:#A70000">&nbsp;Listing Options&nbsp;</b></legend>
<table width="100%" border="0" cellpadding="1" cellspacing="8">
<tr><td align="right" width="40%"><b>List Type:</b></td>
<td><select name="type" class="inpts" onchange="DoChe(this.value);">
<?php if (isset($this->_sections['ga'])) unset($this->_sections['ga']);
$this->_sections['ga']['name'] = 'ga';
$this->_sections['ga']['loop'] = is_array($_loop=$this->_tpl_vars['groups_nav']) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['ga']['show'] = true;
$this->_sections['ga']['max'] = $this->_sections['ga']['loop'];
$this->_sections['ga']['step'] = 1;
$this->_sections['ga']['start'] = $this->_sections['ga']['step'] > 0 ? 0 : $this->_sections['ga']['loop']-1;
if ($this->_sections['ga']['show']) {
    $this->_sections['ga']['total'] = $this->_sections['ga']['loop'];
    if ($this->_sections['ga']['total'] == 0)
        $this->_sections['ga']['show'] = false;
} else
    $this->_sections['ga']['total'] = 0;
if ($this->_sections['ga']['show']):

            for ($this->_sections['ga']['index'] = $this->_sections['ga']['start'], $this->_sections['ga']['iteration'] = 1;
                 $this->_sections['ga']['iteration'] <= $this->_sections['ga']['total'];
                 $this->_sections['ga']['index'] += $this->_sections['ga']['step'], $this->_sections['ga']['iteration']++):
$this->_sections['ga']['rownum'] = $this->_sections['ga']['iteration'];
$this->_sections['ga']['index_prev'] = $this->_sections['ga']['index'] - $this->_sections['ga']['step'];
$this->_sections['ga']['index_next'] = $this->_sections['ga']['index'] + $this->_sections['ga']['step'];
$this->_sections['ga']['first']      = ($this->_sections['ga']['iteration'] == 1);
$this->_sections['ga']['last']       = ($this->_sections['ga']['iteration'] == $this->_sections['ga']['total']);
?>
<?php if ($this->_tpl_vars['groups_nav'][$this->_sections['ga']['index']]['reg_enabled']): ?>
<option value="<?php echo $this->_tpl_vars['groups_nav'][$this->_sections['ga']['index']]['id']; ?>
"><?php echo $this->_tpl_vars['groups_nav'][$this->_sections['ga']['index']]['nav_name']; ?>
 Listing</option>
<?php endif; ?>
<?php endfor; endif; ?></select></td></tr>
<tr><td align="right"><b>Processor:</b></td>
<td><?php if ($this->_tpl_vars['settings']['lr_enable']): ?><input type='radio' name='payec' value='LR' checked>LibertyReserve &nbsp;<?php endif;  if ($this->_tpl_vars['settings']['pm_enable']): ?>  <input type='radio' name='payec' value='PM'>PerfectMoney<?php endif; ?>
</td></tr>
<tr><td align="right"><b>Spend Amount:</b></td>
<td align=left><input readonly type="text" name="amount" id="amount_" value="<?php echo $this->_tpl_vars['fee1']; ?>
" size="8" class="inpts"> <font color="#45BA00">USD</font></td></tr>
<tr><td></td><td><input type="submit" name="spend" value=" Pay Now " class="sbmt"></td></tr>
</table></fieldset>
</form>
</td></tr>
</table>
<?php endif; ?>
</div></div>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>