<div class="box">
<div class="box_title">Top {$settings.toprcb_count} RCB</div>
<div class="box_body">
<table border="0">
<tr><td>
{if $toprcbs}
{section name=t loop=$toprcbs}
<div class="arr" align="left"><a href="{"?a=details&aj=rcb&lid=`$toprcbs[t].id`"|encurl}"><b>{$toprcbs[t].name}</b></a> <font color="green">{$toprcbs[t].mrcb}%</font></div>
{/section}<br>
<a href="{"?a=allrcblist"|encurl}">All RCB Programs</a><br>
<a href="{"?a=allrcbrequest"|encurl}">All RCB Requests</a><br>
{else}No data find in database{/if}
</td></tr>
</table></div>
</div>



